/*******************************************************************************
 * Copyright (c) 2007, 2008 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
module dwt.internal.cocoa.OS;

// NSScroller.h
enum NSScrollerPart
{
    NSScrollerNoPart = 0,
    NSScrollerDecrementPage = 1,
    NSScrollerKnob = 2,
    NSScrollerIncrementPage = 3,
    NSScrollerDecrementLine = 4,
    NSScrollerIncrementLine = 5,
    NSScrollerKnobSlot = 6
}

// NSView.h
enum NSBorderType
{
    NSNoBorder = 0,
    NSLineBorder = 1,
    NSBezelBorder = 2,
    NSGrooveBorder = 3
}

import dwt.dwthelper.utils;

import dwt.internal.C;
import dwt.internal.Library;

import unistd = tango.stdc.posix.unistd;
import stdc = tango.stdc.string;

import Carbon = dwt.internal.c.Carbon;
import custom = dwt.internal.c.custom;
import dwt.internal.cocoa.CGPoint;
import dwt.internal.cocoa.CGRect;
import dwt.internal.cocoa.CGSize;
import dwt.internal.cocoa.NSAffineTransformStruct;
import dwt.internal.cocoa.NSAlert;
import dwt.internal.cocoa.NSApplication;
import dwt.internal.cocoa.NSBezierPath;
import dwt.internal.cocoa.NSBitmapImageRep;
import dwt.internal.cocoa.NSBox;
import dwt.internal.cocoa.NSButtonCell;
import dwt.internal.cocoa.NSCell;
import dwt.internal.cocoa.NSDatePicker;
import dwt.internal.cocoa.NSEvent;
import dwt.internal.cocoa.NSGradient;
import dwt.internal.cocoa.NSGraphicsContext;
import dwt.internal.cocoa.NSImage;
import dwt.internal.cocoa.NSNumberFormatter;
import dwt.internal.cocoa.NSParagraphStyle;
import dwt.internal.cocoa.NSPoint;
import dwt.internal.cocoa.NSRange;
import dwt.internal.cocoa.NSRect;
import dwt.internal.cocoa.NSScrollView;
import dwt.internal.cocoa.NSScroller;
import dwt.internal.cocoa.NSSize;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.NSTabView;
import dwt.internal.cocoa.NSTableView;
import dwt.internal.cocoa.NSText;
import dwt.internal.cocoa.NSView;
import NSWindowTypes = dwt.internal.cocoa.NSWindow;
import Cocoa = dwt.internal.objc.cocoa.Cocoa;
import objc = dwt.internal.objc.runtime;

public class OS : C {
    /*static this (){
        Library.loadLibrary("swt-pi"); //$NON-NLS-1$
    }*/
    
    public static const int VERSION;
    static this () {
        int [1] response;
        OS.Gestalt (OS.gestaltSystemVersion, response.ptr);
        VERSION = response [0] & 0xffff;
        
        sel_sendSelection = sel_registerName("sendSelection");
        sel_sendDoubleSelection = sel_registerName("sendDoubleSelection");
        sel_sendVerticalSelection = sel_registerName("sendVerticalSelection");
        sel_sendHorizontalSelection = sel_registerName("sendHorizontalSelection");
        sel_timerProc_ = sel_registerName("timerProc:");
        sel_handleNotification_ = sel_registerName("handleNotification:");
        
        class_DOMDocument = objc_getClass("DOMDocument");
        class_DOMEvent = objc_getClass("DOMEvent");
        class_DOMKeyboardEvent = objc_getClass("DOMKeyboardEvent");
        class_DOMMouseEvent = objc_getClass("DOMMouseEvent");
        class_DOMUIEvent = objc_getClass("DOMUIEvent");
        class_DOMWheelEvent = objc_getClass("DOMWheelEvent");
        class_NSActionCell = objc_getClass("NSActionCell");
        class_NSAffineTransform = objc_getClass("NSAffineTransform");
        class_NSAlert = objc_getClass("NSAlert");
        class_NSAppleEventDescriptor = objc_getClass("NSAppleEventDescriptor");
        class_NSApplication = objc_getClass("NSApplication");
        class_NSArray = objc_getClass("NSArray");
        class_NSAttributedString = objc_getClass("NSAttributedString");
        class_NSAutoreleasePool = objc_getClass("NSAutoreleasePool");
        class_NSBezierPath = objc_getClass("NSBezierPath");
        class_NSBitmapImageRep = objc_getClass("NSBitmapImageRep");
        class_NSBox = objc_getClass("NSBox");
        class_NSBrowserCell = objc_getClass("NSBrowserCell");
        class_NSBundle = objc_getClass("NSBundle");
        class_NSButton = objc_getClass("NSButton");
        class_NSButtonCell = objc_getClass("NSButtonCell");
        class_NSCalendarDate = objc_getClass("NSCalendarDate");
        class_NSCell = objc_getClass("NSCell");
        class_NSCharacterSet = objc_getClass("NSCharacterSet");
        class_NSClipView = objc_getClass("NSClipView");
        class_NSCoder = objc_getClass("NSCoder");
        class_NSColor = objc_getClass("NSColor");
        class_NSColorPanel = objc_getClass("NSColorPanel");
        class_NSColorSpace = objc_getClass("NSColorSpace");
        class_NSComboBox = objc_getClass("NSComboBox");
        class_NSControl = objc_getClass("NSControl");
        class_NSCursor = objc_getClass("NSCursor");
        class_NSData = objc_getClass("NSData");
        class_NSDate = objc_getClass("NSDate");
        class_NSDatePicker = objc_getClass("NSDatePicker");
        class_NSDictionary = objc_getClass("NSDictionary");
        class_NSDirectoryEnumerator = objc_getClass("NSDirectoryEnumerator");
        class_NSEnumerator = objc_getClass("NSEnumerator");
        class_NSError = objc_getClass("NSError");
        class_NSEvent = objc_getClass("NSEvent");
        class_NSFileManager = objc_getClass("NSFileManager");
        class_NSFont = objc_getClass("NSFont");
        class_NSFontManager = objc_getClass("NSFontManager");
        class_NSFontPanel = objc_getClass("NSFontPanel");
        class_NSFormatter = objc_getClass("NSFormatter");
        class_NSGradient = objc_getClass("NSGradient");
        class_NSGraphicsContext = objc_getClass("NSGraphicsContext");
        class_NSHTTPCookie = objc_getClass("NSHTTPCookie");
        class_NSHTTPCookieStorage = objc_getClass("NSHTTPCookieStorage");
        class_NSImage = objc_getClass("NSImage");
        class_NSImageRep = objc_getClass("NSImageRep");
        class_NSImageView = objc_getClass("NSImageView");
        class_NSIndexSet = objc_getClass("NSIndexSet");
        class_NSInputManager = objc_getClass("NSInputManager");
        class_NSKeyedArchiver = objc_getClass("NSKeyedArchiver");
        class_NSKeyedUnarchiver = objc_getClass("NSKeyedUnarchiver");
        class_NSLayoutManager = objc_getClass("NSLayoutManager");
        class_NSMenu = objc_getClass("NSMenu");
        class_NSMenuItem = objc_getClass("NSMenuItem");
        class_NSMutableArray = objc_getClass("NSMutableArray");
        class_NSMutableAttributedString = objc_getClass("NSMutableAttributedString");
        class_NSMutableDictionary = objc_getClass("NSMutableDictionary");
        class_NSMutableIndexSet = objc_getClass("NSMutableIndexSet");
        class_NSMutableParagraphStyle = objc_getClass("NSMutableParagraphStyle");
        class_NSMutableSet = objc_getClass("NSMutableSet");
        class_NSMutableString = objc_getClass("NSMutableString");
        class_NSMutableURLRequest = objc_getClass("NSMutableURLRequest");
        class_NSNotification = objc_getClass("NSNotification");
        class_NSNotificationCenter = objc_getClass("NSNotificationCenter");
        class_NSNumber = objc_getClass("NSNumber");
        class_NSNumberFormatter = objc_getClass("NSNumberFormatter");
        class_NSObject = objc_getClass("NSObject");
        class_NSOpenGLContext = objc_getClass("NSOpenGLContext");
        class_NSOpenGLPixelFormat = objc_getClass("NSOpenGLPixelFormat");
        class_NSOpenGLView = objc_getClass("NSOpenGLView");
        class_NSOpenPanel = objc_getClass("NSOpenPanel");
        class_NSOutlineView = objc_getClass("NSOutlineView");
        class_NSPanel = objc_getClass("NSPanel");
        class_NSParagraphStyle = objc_getClass("NSParagraphStyle");
        class_NSPasteboard = objc_getClass("NSPasteboard");
        class_NSPopUpButton = objc_getClass("NSPopUpButton");
        class_NSPrintInfo = objc_getClass("NSPrintInfo");
        class_NSPrintOperation = objc_getClass("NSPrintOperation");
        class_NSPrintPanel = objc_getClass("NSPrintPanel");
        class_NSPrinter = objc_getClass("NSPrinter");
        class_NSProgressIndicator = objc_getClass("NSProgressIndicator");
        class_NSResponder = objc_getClass("NSResponder");
        class_NSRunLoop = objc_getClass("NSRunLoop");
        class_NSSavePanel = objc_getClass("NSSavePanel");
        class_NSScreen = objc_getClass("NSScreen");
        class_NSScrollView = objc_getClass("NSScrollView");
        class_NSScroller = objc_getClass("NSScroller");
        class_NSSearchField = objc_getClass("NSSearchField");
        class_NSSecureTextField = objc_getClass("NSSecureTextField");
        class_NSSet = objc_getClass("NSSet");
        class_NSSlider = objc_getClass("NSSlider");
        class_NSStatusBar = objc_getClass("NSStatusBar");
        class_NSStatusItem = objc_getClass("NSStatusItem");
        class_NSStepper = objc_getClass("NSStepper");
        class_NSString = objc_getClass("NSString");
        class_NSTabView = objc_getClass("NSTabView");
        class_NSTabViewItem = objc_getClass("NSTabViewItem");
        class_NSTableColumn = objc_getClass("NSTableColumn");
        class_NSTableHeaderCell = objc_getClass("NSTableHeaderCell");
        class_NSTableHeaderView = objc_getClass("NSTableHeaderView");
        class_NSTableView = objc_getClass("NSTableView");
        class_NSText = objc_getClass("NSText");
        class_NSTextContainer = objc_getClass("NSTextContainer");
        class_NSTextField = objc_getClass("NSTextField");
        class_NSTextFieldCell = objc_getClass("NSTextFieldCell");
        class_NSTextStorage = objc_getClass("NSTextStorage");
        class_NSTextTab = objc_getClass("NSTextTab");
        class_NSTextView = objc_getClass("NSTextView");
        class_NSThread = objc_getClass("NSThread");
        class_NSTimeZone = objc_getClass("NSTimeZone");
        class_NSTimer = objc_getClass("NSTimer");
        class_NSTypesetter = objc_getClass("NSTypesetter");
        class_NSURL = objc_getClass("NSURL");
        class_NSURLDownload = objc_getClass("NSURLDownload");
        class_NSURLRequest = objc_getClass("NSURLRequest");
        class_NSValue = objc_getClass("NSValue");
        class_NSView = objc_getClass("NSView");
        class_NSWindow = objc_getClass("NSWindow");
        class_NSWorkspace = objc_getClass("NSWorkspace");
        class_WebDataSource = objc_getClass("WebDataSource");
        class_WebFrame = objc_getClass("WebFrame");
        class_WebFrameView = objc_getClass("WebFrameView");
        class_WebPreferences = objc_getClass("WebPreferences");
        class_WebView = objc_getClass("WebView");
        
        protocol_NSAccessibility = objc_getProtocol("NSAccessibility");
        protocol_NSAccessibilityAdditions = objc_getProtocol("NSAccessibilityAdditions");
        protocol_NSApplicationDelegate = objc_getProtocol("NSApplicationDelegate");
        protocol_NSApplicationNotifications = objc_getProtocol("NSApplicationNotifications");
        protocol_NSColorPanelResponderMethod = objc_getProtocol("NSColorPanelResponderMethod");
        protocol_NSComboBoxNotifications = objc_getProtocol("NSComboBoxNotifications");
        protocol_NSDraggingDestination = objc_getProtocol("NSDraggingDestination");
        protocol_NSDraggingSource = objc_getProtocol("NSDraggingSource");
        protocol_NSFontManagerResponderMethod = objc_getProtocol("NSFontManagerResponderMethod");
        protocol_NSMenuDelegate = objc_getProtocol("NSMenuDelegate");
        protocol_NSOutlineViewDataSource = objc_getProtocol("NSOutlineViewDataSource");
        protocol_NSOutlineViewDelegate = objc_getProtocol("NSOutlineViewDelegate");
        protocol_NSOutlineViewNotifications = objc_getProtocol("NSOutlineViewNotifications");
        protocol_NSPasteboardOwner = objc_getProtocol("NSPasteboardOwner");
        protocol_NSTabViewDelegate = objc_getProtocol("NSTabViewDelegate");
        protocol_NSTableDataSource = objc_getProtocol("NSTableDataSource");
        protocol_NSTableViewDelegate = objc_getProtocol("NSTableViewDelegate");
        protocol_NSTableViewNotifications = objc_getProtocol("NSTableViewNotifications");
        protocol_NSTextDelegate = objc_getProtocol("NSTextDelegate");
        protocol_NSTextInput = objc_getProtocol("NSTextInput");
        protocol_NSTextViewDelegate = objc_getProtocol("NSTextViewDelegate");
        protocol_NSURLDownloadDelegate = objc_getProtocol("NSURLDownloadDelegate");
        protocol_NSWindowDelegate = objc_getProtocol("NSWindowDelegate");
        protocol_NSWindowNotifications = objc_getProtocol("NSWindowNotifications");
        protocol_WebDocumentRepresentation = objc_getProtocol("WebDocumentRepresentation");
        protocol_WebFrameLoadDelegate = objc_getProtocol("WebFrameLoadDelegate");
        protocol_WebOpenPanelResultListener = objc_getProtocol("WebOpenPanelResultListener");
        protocol_WebPolicyDecisionListener = objc_getProtocol("WebPolicyDecisionListener");
        protocol_WebPolicyDelegate = objc_getProtocol("WebPolicyDelegate");
        protocol_WebResourceLoadDelegate = objc_getProtocol("WebResourceLoadDelegate");
        protocol_WebUIDelegate = objc_getProtocol("WebUIDelegate");        
        
        sel_DOMDocument = sel_registerName("DOMDocument");
        sel_IBeamCursor = sel_registerName("IBeamCursor");
        sel_TIFFRepresentation = sel_registerName("TIFFRepresentation");
        sel_URL = sel_registerName("URL");
        sel_URLFromPasteboard_ = sel_registerName("URLFromPasteboard:");
        sel_URLWithString_ = sel_registerName("URLWithString:");
        sel_UTF8String = sel_registerName("UTF8String");
        sel_absoluteString = sel_registerName("absoluteString");
        sel_acceptsFirstResponder = sel_registerName("acceptsFirstResponder");
        sel_accessibilityActionDescription_ = sel_registerName("accessibilityActionDescription:");
        sel_accessibilityActionNames = sel_registerName("accessibilityActionNames");
        sel_accessibilityAttributeNames = sel_registerName("accessibilityAttributeNames");
        sel_accessibilityAttributeValue_ = sel_registerName("accessibilityAttributeValue:");
        sel_accessibilityAttributeValue_forParameter_ = sel_registerName("accessibilityAttributeValue:forParameter:");
        sel_accessibilityFocusedUIElement = sel_registerName("accessibilityFocusedUIElement");
        sel_accessibilityHitTest_ = sel_registerName("accessibilityHitTest:");
        sel_accessibilityIsAttributeSettable_ = sel_registerName("accessibilityIsAttributeSettable:");
        sel_accessibilityIsIgnored = sel_registerName("accessibilityIsIgnored");
        sel_accessibilityParameterizedAttributeNames = sel_registerName("accessibilityParameterizedAttributeNames");
        sel_accessibilityPerformAction_ = sel_registerName("accessibilityPerformAction:");
        sel_accessibilitySetOverrideValue_forAttribute_ = sel_registerName("accessibilitySetOverrideValue:forAttribute:");
        sel_accessibilitySetValue_forAttribute_ = sel_registerName("accessibilitySetValue:forAttribute:");
        sel_action = sel_registerName("action");
        sel_activateIgnoringOtherApps_ = sel_registerName("activateIgnoringOtherApps:");
        sel_addAttribute_value_range_ = sel_registerName("addAttribute:value:range:");
        sel_addClip = sel_registerName("addClip");
        sel_addEventListener_listener_useCapture_ = sel_registerName("addEventListener:listener:useCapture:");
        sel_addIndex_ = sel_registerName("addIndex:");
        sel_addItem_ = sel_registerName("addItem:");
        sel_addItemWithObjectValue_ = sel_registerName("addItemWithObjectValue:");
        sel_addLayoutManager_ = sel_registerName("addLayoutManager:");
        sel_addObject_ = sel_registerName("addObject:");
        sel_addObjectsFromArray_ = sel_registerName("addObjectsFromArray:");
        sel_addObserver_selector_name_object_ = sel_registerName("addObserver:selector:name:object:");
        sel_addRepresentation_ = sel_registerName("addRepresentation:");
        sel_addSubview_ = sel_registerName("addSubview:");
        sel_addSubview_positioned_relativeTo_ = sel_registerName("addSubview:positioned:relativeTo:");
        sel_addTabStop_ = sel_registerName("addTabStop:");
        sel_addTabViewItem_ = sel_registerName("addTabViewItem:");
        sel_addTableColumn_ = sel_registerName("addTableColumn:");
        sel_addTemporaryAttribute_value_forCharacterRange_ = sel_registerName("addTemporaryAttribute:value:forCharacterRange:");
        sel_addTextContainer_ = sel_registerName("addTextContainer:");
        sel_addTypes_owner_ = sel_registerName("addTypes:owner:");
        sel_alertWithMessageText_defaultButton_alternateButton_otherButton_informativeTextWithFormat_ = sel_registerName("alertWithMessageText:defaultButton:alternateButton:otherButton:informativeTextWithFormat:");
        sel_alignment = sel_registerName("alignment");
        sel_allKeys = sel_registerName("allKeys");
        sel_alloc = sel_registerName("alloc");
        sel_allowsFloats = sel_registerName("allowsFloats");
        sel_alphaComponent = sel_registerName("alphaComponent");
        sel_alphaValue = sel_registerName("alphaValue");
        sel_altKey = sel_registerName("altKey");
        sel_alternateSelectedControlTextColor = sel_registerName("alternateSelectedControlTextColor");
        sel_alwaysShowsDecimalSeparator = sel_registerName("alwaysShowsDecimalSeparator");
        sel_appendBezierPath_ = sel_registerName("appendBezierPath:");
        sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_ = sel_registerName("appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:");
        sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_clockwise_ = sel_registerName("appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:clockwise:");
        sel_appendBezierPathWithGlyphs_count_inFont_ = sel_registerName("appendBezierPathWithGlyphs:count:inFont:");
        sel_appendBezierPathWithOvalInRect_ = sel_registerName("appendBezierPathWithOvalInRect:");
        sel_appendBezierPathWithRect_ = sel_registerName("appendBezierPathWithRect:");
        sel_appendBezierPathWithRoundedRect_xRadius_yRadius_ = sel_registerName("appendBezierPathWithRoundedRect:xRadius:yRadius:");
        sel_appendString_ = sel_registerName("appendString:");
        sel_applicationShouldTerminate_ = sel_registerName("applicationShouldTerminate:");
        sel_applicationWillFinishLaunching_ = sel_registerName("applicationWillFinishLaunching:");
        sel_applicationWillResignActive_ = sel_registerName("applicationWillResignActive:");
        sel_applicationWillTerminate_ = sel_registerName("applicationWillTerminate:");
        sel_archivedDataWithRootObject_ = sel_registerName("archivedDataWithRootObject:");
        sel_array = sel_registerName("array");
        sel_arrayWithCapacity_ = sel_registerName("arrayWithCapacity:");
        sel_arrayWithObject_ = sel_registerName("arrayWithObject:");
        sel_arrowCursor = sel_registerName("arrowCursor");
        sel_ascender = sel_registerName("ascender");
        sel_attributedSubstringFromRange_ = sel_registerName("attributedSubstringFromRange:");
        sel_attributesAtIndex_longestEffectiveRange_inRange_ = sel_registerName("attributesAtIndex:longestEffectiveRange:inRange:");
        sel_autorelease = sel_registerName("autorelease");
        sel_availableFontFamilies = sel_registerName("availableFontFamilies");
        sel_availableFonts = sel_registerName("availableFonts");
        sel_availableMembersOfFontFamily_ = sel_registerName("availableMembersOfFontFamily:");
        sel_availableTypeFromArray_ = sel_registerName("availableTypeFromArray:");
        sel_baselineOffsetInLayoutManager_glyphIndex_ = sel_registerName("baselineOffsetInLayoutManager:glyphIndex:");
        sel_becomeFirstResponder = sel_registerName("becomeFirstResponder");
        sel_beginDocument = sel_registerName("beginDocument");
        sel_beginEditing = sel_registerName("beginEditing");
        sel_beginPageInRect_atPlacement_ = sel_registerName("beginPageInRect:atPlacement:");
        sel_bestRepresentationForDevice_ = sel_registerName("bestRepresentationForDevice:");
        sel_bezierPath = sel_registerName("bezierPath");
        sel_bezierPathByFlatteningPath = sel_registerName("bezierPathByFlatteningPath");
        sel_bezierPathWithRect_ = sel_registerName("bezierPathWithRect:");
        sel_bitmapData = sel_registerName("bitmapData");
        sel_bitsPerPixel = sel_registerName("bitsPerPixel");
        sel_bitsPerSample = sel_registerName("bitsPerSample");
        sel_blackColor = sel_registerName("blackColor");
        sel_blueComponent = sel_registerName("blueComponent");
        sel_borderWidth = sel_registerName("borderWidth");
        sel_boundingRectForGlyphRange_inTextContainer_ = sel_registerName("boundingRectForGlyphRange:inTextContainer:");
        sel_bounds = sel_registerName("bounds");
        sel_bundleIdentifier = sel_registerName("bundleIdentifier");
        sel_bundlePath = sel_registerName("bundlePath");
        sel_bundleWithPath_ = sel_registerName("bundleWithPath:");
        sel_button = sel_registerName("button");
        sel_buttonNumber = sel_registerName("buttonNumber");
        sel_bytes = sel_registerName("bytes");
        sel_bytesPerPlane = sel_registerName("bytesPerPlane");
        sel_bytesPerRow = sel_registerName("bytesPerRow");
        sel_calendarDate = sel_registerName("calendarDate");
        sel_canBecomeKeyWindow = sel_registerName("canBecomeKeyWindow");
        sel_canGoBack = sel_registerName("canGoBack");
        sel_canGoForward = sel_registerName("canGoForward");
        sel_canShowMIMEType_ = sel_registerName("canShowMIMEType:");
        sel_cancel = sel_registerName("cancel");
        sel_cancelTracking = sel_registerName("cancelTracking");
        sel_cascadeTopLeftFromPoint_ = sel_registerName("cascadeTopLeftFromPoint:");
        sel_cell = sel_registerName("cell");
        sel_cellClass = sel_registerName("cellClass");
        sel_cellSizeForBounds_ = sel_registerName("cellSizeForBounds:");
        sel_changeColor_ = sel_registerName("changeColor:");
        sel_changeFont_ = sel_registerName("changeFont:");
        sel_charCode = sel_registerName("charCode");
        sel_characterAtIndex_ = sel_registerName("characterAtIndex:");
        sel_characterIndexForGlyphAtIndex_ = sel_registerName("characterIndexForGlyphAtIndex:");
        sel_characterIndexForPoint_ = sel_registerName("characterIndexForPoint:");
        sel_characterIsMember_ = sel_registerName("characterIsMember:");
        sel_characters = sel_registerName("characters");
        sel_charactersIgnoringModifiers = sel_registerName("charactersIgnoringModifiers");
        sel_chooseFilename_ = sel_registerName("chooseFilename:");
        sel_className = sel_registerName("className");
        sel_cleanUpOperation = sel_registerName("cleanUpOperation");
        sel_clearColor = sel_registerName("clearColor");
        sel_clearCurrentContext = sel_registerName("clearCurrentContext");
        sel_clearGLContext = sel_registerName("clearGLContext");
        sel_clickCount = sel_registerName("clickCount");
        sel_clientX = sel_registerName("clientX");
        sel_clientY = sel_registerName("clientY");
        sel_close = sel_registerName("close");
        sel_closePath = sel_registerName("closePath");
        sel_code = sel_registerName("code");
        sel_collapseItem_ = sel_registerName("collapseItem:");
        sel_color = sel_registerName("color");
        sel_colorUsingColorSpace_ = sel_registerName("colorUsingColorSpace:");
        sel_colorUsingColorSpaceName_ = sel_registerName("colorUsingColorSpaceName:");
        sel_colorWithDeviceRed_green_blue_alpha_ = sel_registerName("colorWithDeviceRed:green:blue:alpha:");
        sel_colorWithPatternImage_ = sel_registerName("colorWithPatternImage:");
        sel_columnAtPoint_ = sel_registerName("columnAtPoint:");
        sel_columnAutoresizingStyle = sel_registerName("columnAutoresizingStyle");
        sel_columnIndexesInRect_ = sel_registerName("columnIndexesInRect:");
        sel_columnWithIdentifier_ = sel_registerName("columnWithIdentifier:");
        sel_comboBoxSelectionDidChange_ = sel_registerName("comboBoxSelectionDidChange:");
        sel_concat = sel_registerName("concat");
        sel_conformsToProtocol_ = sel_registerName("conformsToProtocol:");
        sel_containerSize = sel_registerName("containerSize");
        sel_containsObject_ = sel_registerName("containsObject:");
        sel_containsPoint_ = sel_registerName("containsPoint:");
        sel_contentRect = sel_registerName("contentRect");
        sel_contentRectForFrameRect_ = sel_registerName("contentRectForFrameRect:");
        sel_contentSize = sel_registerName("contentSize");
        sel_contentSizeForFrameSize_hasHorizontalScroller_hasVerticalScroller_borderType_ = sel_registerName("contentSizeForFrameSize:hasHorizontalScroller:hasVerticalScroller:borderType:");
        sel_contentView = sel_registerName("contentView");
        sel_contentViewMargins = sel_registerName("contentViewMargins");
        sel_context = sel_registerName("context");
        sel_controlDarkShadowColor = sel_registerName("controlDarkShadowColor");
        sel_controlHighlightColor = sel_registerName("controlHighlightColor");
        sel_controlLightHighlightColor = sel_registerName("controlLightHighlightColor");
        sel_controlPointBounds = sel_registerName("controlPointBounds");
        sel_controlShadowColor = sel_registerName("controlShadowColor");
        sel_controlTextColor = sel_registerName("controlTextColor");
        sel_convertBaseToScreen_ = sel_registerName("convertBaseToScreen:");
        sel_convertPoint_fromView_ = sel_registerName("convertPoint:fromView:");
        sel_convertPoint_toView_ = sel_registerName("convertPoint:toView:");
        sel_convertPointFromBase_ = sel_registerName("convertPointFromBase:");
        sel_convertPointToBase_ = sel_registerName("convertPointToBase:");
        sel_convertRect_fromView_ = sel_registerName("convertRect:fromView:");
        sel_convertRect_toView_ = sel_registerName("convertRect:toView:");
        sel_convertRectFromBase_ = sel_registerName("convertRectFromBase:");
        sel_convertRectToBase_ = sel_registerName("convertRectToBase:");
        sel_convertScreenToBase_ = sel_registerName("convertScreenToBase:");
        sel_convertSize_fromView_ = sel_registerName("convertSize:fromView:");
        sel_convertSize_toView_ = sel_registerName("convertSize:toView:");
        sel_convertSizeFromBase_ = sel_registerName("convertSizeFromBase:");
        sel_convertSizeToBase_ = sel_registerName("convertSizeToBase:");
        sel_cookies = sel_registerName("cookies");
        sel_copy = sel_registerName("copy");
        sel_copy_ = sel_registerName("copy:");
        sel_count = sel_registerName("count");
        sel_createContext = sel_registerName("createContext");
        sel_createFileAtPath_contents_attributes_ = sel_registerName("createFileAtPath:contents:attributes:");
        sel_crosshairCursor = sel_registerName("crosshairCursor");
        sel_ctrlKey = sel_registerName("ctrlKey");
        sel_currentContext = sel_registerName("currentContext");
        sel_currentEditor = sel_registerName("currentEditor");
        sel_currentEvent = sel_registerName("currentEvent");
        sel_currentInputManager = sel_registerName("currentInputManager");
        sel_currentPoint = sel_registerName("currentPoint");
        sel_currentRunLoop = sel_registerName("currentRunLoop");
        sel_currentThread = sel_registerName("currentThread");
        sel_curveToPoint_controlPoint1_controlPoint2_ = sel_registerName("curveToPoint:controlPoint1:controlPoint2:");
        sel_cut_ = sel_registerName("cut:");
        sel_dataForType_ = sel_registerName("dataForType:");
        sel_dataSource = sel_registerName("dataSource");
        sel_dataWithBytes_length_ = sel_registerName("dataWithBytes:length:");
        sel_dateValue = sel_registerName("dateValue");
        sel_dateWithCalendarFormat_timeZone_ = sel_registerName("dateWithCalendarFormat:timeZone:");
        sel_dateWithTimeIntervalSinceNow_ = sel_registerName("dateWithTimeIntervalSinceNow:");
        sel_dateWithYear_month_day_hour_minute_second_timeZone_ = sel_registerName("dateWithYear:month:day:hour:minute:second:timeZone:");
        sel_dayOfMonth = sel_registerName("dayOfMonth");
        sel_decimalDigitCharacterSet = sel_registerName("decimalDigitCharacterSet");
        sel_decimalSeparator = sel_registerName("decimalSeparator");
        sel_declareTypes_owner_ = sel_registerName("declareTypes:owner:");
        sel_defaultCenter = sel_registerName("defaultCenter");
        sel_defaultFlatness = sel_registerName("defaultFlatness");
        sel_defaultLineHeightForFont_ = sel_registerName("defaultLineHeightForFont:");
        sel_defaultManager = sel_registerName("defaultManager");
        sel_defaultPrinter = sel_registerName("defaultPrinter");
        sel_defaultTimeZone = sel_registerName("defaultTimeZone");
        sel_deleteCookie_ = sel_registerName("deleteCookie:");
        sel_deliverResult = sel_registerName("deliverResult");
        sel_deltaX = sel_registerName("deltaX");
        sel_deltaY = sel_registerName("deltaY");
        sel_depth = sel_registerName("depth");
        sel_descender = sel_registerName("descender");
        sel_description = sel_registerName("description");
        sel_deselectAll_ = sel_registerName("deselectAll:");
        sel_deselectItemAtIndex_ = sel_registerName("deselectItemAtIndex:");
        sel_deselectRow_ = sel_registerName("deselectRow:");
        sel_destroyContext = sel_registerName("destroyContext");
        sel_detail = sel_registerName("detail");
        sel_deviceDescription = sel_registerName("deviceDescription");
        sel_deviceRGBColorSpace = sel_registerName("deviceRGBColorSpace");
        sel_dictionary = sel_registerName("dictionary");
        sel_dictionaryWithCapacity_ = sel_registerName("dictionaryWithCapacity:");
        sel_dictionaryWithObject_forKey_ = sel_registerName("dictionaryWithObject:forKey:");
        sel_disableCursorRects = sel_registerName("disableCursorRects");
        sel_disabledControlTextColor = sel_registerName("disabledControlTextColor");
        sel_displayIfNeeded = sel_registerName("displayIfNeeded");
        sel_distantFuture = sel_registerName("distantFuture");
        sel_doCommandBySelector_ = sel_registerName("doCommandBySelector:");
        sel_documentSource = sel_registerName("documentSource");
        sel_documentView = sel_registerName("documentView");
        sel_documentViewShouldHandlePrint = sel_registerName("documentViewShouldHandlePrint");
        sel_documentVisibleRect = sel_registerName("documentVisibleRect");
        sel_doubleClickAtIndex_ = sel_registerName("doubleClickAtIndex:");
        sel_doubleValue = sel_registerName("doubleValue");
        sel_download = sel_registerName("download");
        sel_download_decideDestinationWithSuggestedFilename_ = sel_registerName("download:decideDestinationWithSuggestedFilename:");
        sel_dragImage_at_offset_event_pasteboard_source_slideBack_ = sel_registerName("dragImage:at:offset:event:pasteboard:source:slideBack:");
        sel_draggedImage = sel_registerName("draggedImage");
        sel_draggedImage_beganAt_ = sel_registerName("draggedImage:beganAt:");
        sel_draggedImage_endedAt_operation_ = sel_registerName("draggedImage:endedAt:operation:");
        sel_draggedImageLocation = sel_registerName("draggedImageLocation");
        sel_draggingDestinationWindow = sel_registerName("draggingDestinationWindow");
        sel_draggingEnded_ = sel_registerName("draggingEnded:");
        sel_draggingEntered_ = sel_registerName("draggingEntered:");
        sel_draggingExited_ = sel_registerName("draggingExited:");
        sel_draggingLocation = sel_registerName("draggingLocation");
        sel_draggingPasteboard = sel_registerName("draggingPasteboard");
        sel_draggingSequenceNumber = sel_registerName("draggingSequenceNumber");
        sel_draggingSource = sel_registerName("draggingSource");
        sel_draggingSourceOperationMask = sel_registerName("draggingSourceOperationMask");
        sel_draggingSourceOperationMaskForLocal_ = sel_registerName("draggingSourceOperationMaskForLocal:");
        sel_draggingUpdated_ = sel_registerName("draggingUpdated:");
        sel_drawAtPoint_ = sel_registerName("drawAtPoint:");
        sel_drawAtPoint_fromRect_operation_fraction_ = sel_registerName("drawAtPoint:fromRect:operation:fraction:");
        sel_drawBackgroundForGlyphRange_atPoint_ = sel_registerName("drawBackgroundForGlyphRange:atPoint:");
        sel_drawFromPoint_toPoint_options_ = sel_registerName("drawFromPoint:toPoint:options:");
        sel_drawGlyphsForGlyphRange_atPoint_ = sel_registerName("drawGlyphsForGlyphRange:atPoint:");
        sel_drawInRect_ = sel_registerName("drawInRect:");
        sel_drawInRect_angle_ = sel_registerName("drawInRect:angle:");
        sel_drawInRect_fromRect_operation_fraction_ = sel_registerName("drawInRect:fromRect:operation:fraction:");
        sel_drawInteriorWithFrame_inView_ = sel_registerName("drawInteriorWithFrame:inView:");
        sel_drawRect_ = sel_registerName("drawRect:");
        sel_drawSortIndicatorWithFrame_inView_ascending_priority_ = sel_registerName("drawSortIndicatorWithFrame:inView:ascending:priority:");
        sel_drawStatusBarBackgroundInRect_withHighlight_ = sel_registerName("drawStatusBarBackgroundInRect:withHighlight:");
        sel_drawingRectForBounds_ = sel_registerName("drawingRectForBounds:");
        sel_elementAtIndex_associatedPoints_ = sel_registerName("elementAtIndex:associatedPoints:");
        sel_elementCount = sel_registerName("elementCount");
        sel_enableFreedObjectCheck_ = sel_registerName("enableFreedObjectCheck:");
        sel_endDocument = sel_registerName("endDocument");
        sel_endEditing = sel_registerName("endEditing");
        sel_endPage = sel_registerName("endPage");
        sel_enumeratorAtPath_ = sel_registerName("enumeratorAtPath:");
        sel_expandItem_ = sel_registerName("expandItem:");
        sel_familyName = sel_registerName("familyName");
        sel_fieldEditor_forObject_ = sel_registerName("fieldEditor:forObject:");
        sel_fileURLWithPath_ = sel_registerName("fileURLWithPath:");
        sel_filename = sel_registerName("filename");
        sel_filenames = sel_registerName("filenames");
        sel_fill = sel_registerName("fill");
        sel_fillRect_ = sel_registerName("fillRect:");
        sel_finishLaunching = sel_registerName("finishLaunching");
        sel_firstIndex = sel_registerName("firstIndex");
        sel_firstRectForCharacterRange_ = sel_registerName("firstRectForCharacterRange:");
        sel_firstResponder = sel_registerName("firstResponder");
        sel_flagsChanged_ = sel_registerName("flagsChanged:");
        sel_flushBuffer = sel_registerName("flushBuffer");
        sel_flushGraphics = sel_registerName("flushGraphics");
        sel_font = sel_registerName("font");
        sel_fontName = sel_registerName("fontName");
        sel_fontWithName_size_ = sel_registerName("fontWithName:size:");
        sel_frame = sel_registerName("frame");
        sel_frameOfCellAtColumn_row_ = sel_registerName("frameOfCellAtColumn:row:");
        sel_frameRectForContentRect_ = sel_registerName("frameRectForContentRect:");
        sel_frameSizeForContentSize_hasHorizontalScroller_hasVerticalScroller_borderType_ = sel_registerName("frameSizeForContentSize:hasHorizontalScroller:hasVerticalScroller:borderType:");
        sel_fullPathForApplication_ = sel_registerName("fullPathForApplication:");
        sel_generalPasteboard = sel_registerName("generalPasteboard");
        sel_getBytes_ = sel_registerName("getBytes:");
        sel_getBytes_length_ = sel_registerName("getBytes:length:");
        sel_getCharacters_ = sel_registerName("getCharacters:");
        sel_getCharacters_range_ = sel_registerName("getCharacters:range:");
        sel_getComponents_ = sel_registerName("getComponents:");
        sel_getGlyphs_range_ = sel_registerName("getGlyphs:range:");
        sel_getIndexes_maxCount_inIndexRange_ = sel_registerName("getIndexes:maxCount:inIndexRange:");
        sel_getInfoForFile_application_type_ = sel_registerName("getInfoForFile:application:type:");
        sel_glyphIndexForCharacterAtIndex_ = sel_registerName("glyphIndexForCharacterAtIndex:");
        sel_glyphIndexForPoint_inTextContainer_fractionOfDistanceThroughGlyph_ = sel_registerName("glyphIndexForPoint:inTextContainer:fractionOfDistanceThroughGlyph:");
        sel_glyphRangeForTextContainer_ = sel_registerName("glyphRangeForTextContainer:");
        sel_goBack = sel_registerName("goBack");
        sel_goForward = sel_registerName("goForward");
        sel_graphicsContext = sel_registerName("graphicsContext");
        sel_graphicsContextWithBitmapImageRep_ = sel_registerName("graphicsContextWithBitmapImageRep:");
        sel_graphicsContextWithWindow_ = sel_registerName("graphicsContextWithWindow:");
        sel_greenComponent = sel_registerName("greenComponent");
        sel_handleEvent_ = sel_registerName("handleEvent:");
        sel_handleMouseEvent_ = sel_registerName("handleMouseEvent:");
        sel_hasAlpha = sel_registerName("hasAlpha");
        sel_hasMarkedText = sel_registerName("hasMarkedText");
        sel_headerCell = sel_registerName("headerCell");
        sel_headerRectOfColumn_ = sel_registerName("headerRectOfColumn:");
        sel_headerView = sel_registerName("headerView");
        sel_helpRequested_ = sel_registerName("helpRequested:");
        sel_hide_ = sel_registerName("hide:");
        sel_hideOtherApplications_ = sel_registerName("hideOtherApplications:");
        sel_highlightColorInView_ = sel_registerName("highlightColorInView:");
        sel_highlightSelectionInClipRect_ = sel_registerName("highlightSelectionInClipRect:");
        sel_hitPart = sel_registerName("hitPart");
        sel_hitTest_ = sel_registerName("hitTest:");
        sel_hourOfDay = sel_registerName("hourOfDay");
        sel_iconForFile_ = sel_registerName("iconForFile:");
        sel_iconForFileType_ = sel_registerName("iconForFileType:");
        sel_ignore = sel_registerName("ignore");
        sel_ignoreModifierKeysWhileDragging = sel_registerName("ignoreModifierKeysWhileDragging");
        sel_imageInterpolation = sel_registerName("imageInterpolation");
        sel_imageablePageBounds = sel_registerName("imageablePageBounds");
        sel_increment = sel_registerName("increment");
        sel_indentationPerLevel = sel_registerName("indentationPerLevel");
        sel_indexOfSelectedItem = sel_registerName("indexOfSelectedItem");
        sel_infoDictionary = sel_registerName("infoDictionary");
        sel_init = sel_registerName("init");
        sel_initByReferencingFile_ = sel_registerName("initByReferencingFile:");
        sel_initListDescriptor = sel_registerName("initListDescriptor");
        sel_initWithAttributes_ = sel_registerName("initWithAttributes:");
        sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bitmapFormat_bytesPerRow_bitsPerPixel_ = sel_registerName("initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bitmapFormat:bytesPerRow:bitsPerPixel:");
        sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_ = sel_registerName("initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bytesPerRow:bitsPerPixel:");
        sel_initWithContainerSize_ = sel_registerName("initWithContainerSize:");
        sel_initWithContentRect_styleMask_backing_defer_ = sel_registerName("initWithContentRect:styleMask:backing:defer:");
        sel_initWithContentRect_styleMask_backing_defer_screen_ = sel_registerName("initWithContentRect:styleMask:backing:defer:screen:");
        sel_initWithData_ = sel_registerName("initWithData:");
        sel_initWithDictionary_ = sel_registerName("initWithDictionary:");
        sel_initWithFrame_ = sel_registerName("initWithFrame:");
        sel_initWithFrame_frameName_groupName_ = sel_registerName("initWithFrame:frameName:groupName:");
        sel_initWithFrame_pixelFormat_ = sel_registerName("initWithFrame:pixelFormat:");
        sel_initWithFrame_pullsDown_ = sel_registerName("initWithFrame:pullsDown:");
        sel_initWithIdentifier_ = sel_registerName("initWithIdentifier:");
        sel_initWithImage_hotSpot_ = sel_registerName("initWithImage:hotSpot:");
        sel_initWithIndex_ = sel_registerName("initWithIndex:");
        sel_initWithIndexesInRange_ = sel_registerName("initWithIndexesInRange:");
        sel_initWithSize_ = sel_registerName("initWithSize:");
        sel_initWithStartingColor_endingColor_ = sel_registerName("initWithStartingColor:endingColor:");
        sel_initWithString_ = sel_registerName("initWithString:");
        sel_initWithString_attributes_ = sel_registerName("initWithString:attributes:");
        sel_initWithTitle_ = sel_registerName("initWithTitle:");
        sel_initWithTitle_action_keyEquivalent_ = sel_registerName("initWithTitle:action:keyEquivalent:");
        sel_initWithTransform_ = sel_registerName("initWithTransform:");
        sel_initWithType_location_ = sel_registerName("initWithType:location:");
        sel_initWithURL_ = sel_registerName("initWithURL:");
        sel_insertItem_atIndex_ = sel_registerName("insertItem:atIndex:");
        sel_insertItemWithObjectValue_atIndex_ = sel_registerName("insertItemWithObjectValue:atIndex:");
        sel_insertTabViewItem_atIndex_ = sel_registerName("insertTabViewItem:atIndex:");
        sel_insertText_ = sel_registerName("insertText:");
        sel_intValue = sel_registerName("intValue");
        sel_intercellSpacing = sel_registerName("intercellSpacing");
        sel_interpretKeyEvents_ = sel_registerName("interpretKeyEvents:");
        sel_invalidate = sel_registerName("invalidate");
        sel_invert = sel_registerName("invert");
        sel_isEmpty = sel_registerName("isEmpty");
        sel_isEqual_ = sel_registerName("isEqual:");
        sel_isEqualTo_ = sel_registerName("isEqualTo:");
        sel_isEqualToString_ = sel_registerName("isEqualToString:");
        sel_isFilePackageAtPath_ = sel_registerName("isFilePackageAtPath:");
        sel_isFlipped = sel_registerName("isFlipped");
        sel_isHidden = sel_registerName("isHidden");
        sel_isKeyWindow = sel_registerName("isKeyWindow");
        sel_isKindOfClass_ = sel_registerName("isKindOfClass:");
        sel_isMainThread = sel_registerName("isMainThread");
        sel_isOpaque = sel_registerName("isOpaque");
        sel_isPlanar = sel_registerName("isPlanar");
        sel_isRowSelected_ = sel_registerName("isRowSelected:");
        sel_isRunning = sel_registerName("isRunning");
        sel_isSessionOnly = sel_registerName("isSessionOnly");
        sel_isVisible = sel_registerName("isVisible");
        sel_itemArray = sel_registerName("itemArray");
        sel_itemAtIndex_ = sel_registerName("itemAtIndex:");
        sel_itemAtRow_ = sel_registerName("itemAtRow:");
        sel_itemObjectValueAtIndex_ = sel_registerName("itemObjectValueAtIndex:");
        sel_itemTitleAtIndex_ = sel_registerName("itemTitleAtIndex:");
        sel_jobDisposition = sel_registerName("jobDisposition");
        sel_keyCode = sel_registerName("keyCode");
        sel_keyDown_ = sel_registerName("keyDown:");
        sel_keyEquivalent = sel_registerName("keyEquivalent");
        sel_keyEquivalentModifierMask = sel_registerName("keyEquivalentModifierMask");
        sel_keyUp_ = sel_registerName("keyUp:");
        sel_keyWindow = sel_registerName("keyWindow");
        sel_lastPathComponent = sel_registerName("lastPathComponent");
        sel_leading = sel_registerName("leading");
        sel_length = sel_registerName("length");
        sel_levelForItem_ = sel_registerName("levelForItem:");
        sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_ = sel_registerName("lineFragmentUsedRectForGlyphAtIndex:effectiveRange:");
        sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_withoutAdditionalLayout_ = sel_registerName("lineFragmentUsedRectForGlyphAtIndex:effectiveRange:withoutAdditionalLayout:");
        sel_lineToPoint_ = sel_registerName("lineToPoint:");
        sel_loadHTMLString_baseURL_ = sel_registerName("loadHTMLString:baseURL:");
        sel_loadNibFile_externalNameTable_withZone_ = sel_registerName("loadNibFile:externalNameTable:withZone:");
        sel_loadRequest_ = sel_registerName("loadRequest:");
        sel_localizedDescription = sel_registerName("localizedDescription");
        sel_location = sel_registerName("location");
        sel_locationForGlyphAtIndex_ = sel_registerName("locationForGlyphAtIndex:");
        sel_locationInWindow = sel_registerName("locationInWindow");
        sel_lowercaseString = sel_registerName("lowercaseString");
        sel_mainFrame = sel_registerName("mainFrame");
        sel_mainMenu = sel_registerName("mainMenu");
        sel_mainRunLoop = sel_registerName("mainRunLoop");
        sel_mainScreen = sel_registerName("mainScreen");
        sel_makeCurrentContext = sel_registerName("makeCurrentContext");
        sel_makeFirstResponder_ = sel_registerName("makeFirstResponder:");
        sel_makeKeyAndOrderFront_ = sel_registerName("makeKeyAndOrderFront:");
        sel_markedRange = sel_registerName("markedRange");
        sel_markedTextAttributes = sel_registerName("markedTextAttributes");
        sel_maxValue = sel_registerName("maxValue");
        sel_maximum = sel_registerName("maximum");
        sel_maximumFractionDigits = sel_registerName("maximumFractionDigits");
        sel_maximumIntegerDigits = sel_registerName("maximumIntegerDigits");
        sel_menu = sel_registerName("menu");
        sel_menu_willHighlightItem_ = sel_registerName("menu:willHighlightItem:");
        sel_menuDidClose_ = sel_registerName("menuDidClose:");
        sel_menuForEvent_ = sel_registerName("menuForEvent:");
        sel_menuNeedsUpdate_ = sel_registerName("menuNeedsUpdate:");
        sel_menuWillOpen_ = sel_registerName("menuWillOpen:");
        sel_metaKey = sel_registerName("metaKey");
        sel_minValue = sel_registerName("minValue");
        sel_minimum = sel_registerName("minimum");
        sel_minimumSize = sel_registerName("minimumSize");
        sel_minuteOfHour = sel_registerName("minuteOfHour");
        sel_modifierFlags = sel_registerName("modifierFlags");
        sel_monthOfYear = sel_registerName("monthOfYear");
        sel_mouseDown_ = sel_registerName("mouseDown:");
        sel_mouseDragged_ = sel_registerName("mouseDragged:");
        sel_mouseEntered_ = sel_registerName("mouseEntered:");
        sel_mouseExited_ = sel_registerName("mouseExited:");
        sel_mouseLocation = sel_registerName("mouseLocation");
        sel_mouseLocationOutsideOfEventStream = sel_registerName("mouseLocationOutsideOfEventStream");
        sel_mouseMoved_ = sel_registerName("mouseMoved:");
        sel_mouseUp_ = sel_registerName("mouseUp:");
        sel_moveColumn_toColumn_ = sel_registerName("moveColumn:toColumn:");
        sel_moveToBeginningOfParagraph_ = sel_registerName("moveToBeginningOfParagraph:");
        sel_moveToEndOfParagraph_ = sel_registerName("moveToEndOfParagraph:");
        sel_moveToPoint_ = sel_registerName("moveToPoint:");
        sel_moveUp_ = sel_registerName("moveUp:");
        sel_mutableString = sel_registerName("mutableString");
        sel_name = sel_registerName("name");
        sel_namesOfPromisedFilesDroppedAtDestination_ = sel_registerName("namesOfPromisedFilesDroppedAtDestination:");
        sel_nextEventMatchingMask_untilDate_inMode_dequeue_ = sel_registerName("nextEventMatchingMask:untilDate:inMode:dequeue:");
        sel_nextObject = sel_registerName("nextObject");
        sel_nextWordFromIndex_forward_ = sel_registerName("nextWordFromIndex:forward:");
        sel_noteNumberOfRowsChanged = sel_registerName("noteNumberOfRowsChanged");
        sel_numberOfColumns = sel_registerName("numberOfColumns");
        sel_numberOfComponents = sel_registerName("numberOfComponents");
        sel_numberOfGlyphs = sel_registerName("numberOfGlyphs");
        sel_numberOfItems = sel_registerName("numberOfItems");
        sel_numberOfRows = sel_registerName("numberOfRows");
        sel_numberOfRowsInTableView_ = sel_registerName("numberOfRowsInTableView:");
        sel_numberOfSelectedRows = sel_registerName("numberOfSelectedRows");
        sel_numberOfVisibleItems = sel_registerName("numberOfVisibleItems");
        sel_numberWithBool_ = sel_registerName("numberWithBool:");
        sel_numberWithInt_ = sel_registerName("numberWithInt:");
        sel_numberWithInteger_ = sel_registerName("numberWithInteger:");
        sel_object = sel_registerName("object");
        sel_objectAtIndex_ = sel_registerName("objectAtIndex:");
        sel_objectEnumerator = sel_registerName("objectEnumerator");
        sel_objectForInfoDictionaryKey_ = sel_registerName("objectForInfoDictionaryKey:");
        sel_objectForKey_ = sel_registerName("objectForKey:");
        sel_openFile_withApplication_ = sel_registerName("openFile:withApplication:");
        sel_openGLContext = sel_registerName("openGLContext");
        sel_openPanel = sel_registerName("openPanel");
        sel_openURL_ = sel_registerName("openURL:");
        sel_openURLs_withAppBundleIdentifier_options_additionalEventParamDescriptor_launchIdentifiers_ = sel_registerName("openURLs:withAppBundleIdentifier:options:additionalEventParamDescriptor:launchIdentifiers:");
        sel_options = sel_registerName("options");
        sel_orderFront_ = sel_registerName("orderFront:");
        sel_orderFrontRegardless = sel_registerName("orderFrontRegardless");
        sel_orderFrontStandardAboutPanel_ = sel_registerName("orderFrontStandardAboutPanel:");
        sel_orderOut_ = sel_registerName("orderOut:");
        sel_orderedWindows = sel_registerName("orderedWindows");
        sel_otherEventWithType_location_modifierFlags_timestamp_windowNumber_context_subtype_data1_data2_ = sel_registerName("otherEventWithType:location:modifierFlags:timestamp:windowNumber:context:subtype:data1:data2:");
        sel_otherMouseDown_ = sel_registerName("otherMouseDown:");
        sel_otherMouseDragged_ = sel_registerName("otherMouseDragged:");
        sel_otherMouseUp_ = sel_registerName("otherMouseUp:");
        sel_outlineTableColumn = sel_registerName("outlineTableColumn");
        sel_outlineView_child_ofItem_ = sel_registerName("outlineView:child:ofItem:");
        sel_outlineView_didClickTableColumn_ = sel_registerName("outlineView:didClickTableColumn:");
        sel_outlineView_isItemExpandable_ = sel_registerName("outlineView:isItemExpandable:");
        sel_outlineView_numberOfChildrenOfItem_ = sel_registerName("outlineView:numberOfChildrenOfItem:");
        sel_outlineView_objectValueForTableColumn_byItem_ = sel_registerName("outlineView:objectValueForTableColumn:byItem:");
        sel_outlineView_setObjectValue_forTableColumn_byItem_ = sel_registerName("outlineView:setObjectValue:forTableColumn:byItem:");
        sel_outlineView_shouldCollapseItem_ = sel_registerName("outlineView:shouldCollapseItem:");
        sel_outlineView_shouldExpandItem_ = sel_registerName("outlineView:shouldExpandItem:");
        sel_outlineView_willDisplayCell_forTableColumn_item_ = sel_registerName("outlineView:willDisplayCell:forTableColumn:item:");
        sel_outlineViewColumnDidMove_ = sel_registerName("outlineViewColumnDidMove:");
        sel_outlineViewColumnDidResize_ = sel_registerName("outlineViewColumnDidResize:");
        sel_outlineViewItemDidExpand_ = sel_registerName("outlineViewItemDidExpand:");
        sel_outlineViewSelectionDidChange_ = sel_registerName("outlineViewSelectionDidChange:");
        sel_pageDown_ = sel_registerName("pageDown:");
        sel_pageTitle = sel_registerName("pageTitle");
        sel_pageUp_ = sel_registerName("pageUp:");
        sel_panelConvertFont_ = sel_registerName("panelConvertFont:");
        sel_paperSize = sel_registerName("paperSize");
        sel_paragraphs = sel_registerName("paragraphs");
        sel_paste_ = sel_registerName("paste:");
        sel_pasteboard_provideDataForType_ = sel_registerName("pasteboard:provideDataForType:");
        sel_pasteboardWithName_ = sel_registerName("pasteboardWithName:");
        sel_performDragOperation_ = sel_registerName("performDragOperation:");
        sel_performSelectorOnMainThread_withObject_waitUntilDone_ = sel_registerName("performSelectorOnMainThread:withObject:waitUntilDone:");
        sel_pixelsHigh = sel_registerName("pixelsHigh");
        sel_pixelsWide = sel_registerName("pixelsWide");
        sel_pointSize = sel_registerName("pointSize");
        sel_pointValue = sel_registerName("pointValue");
        sel_pointingHandCursor = sel_registerName("pointingHandCursor");
        sel_popUpContextMenu_withEvent_forView_ = sel_registerName("popUpContextMenu:withEvent:forView:");
        sel_prependTransform_ = sel_registerName("prependTransform:");
        sel_preventDefault = sel_registerName("preventDefault");
        sel_printDocumentView = sel_registerName("printDocumentView");
        sel_printOperationWithPrintInfo_ = sel_registerName("printOperationWithPrintInfo:");
        sel_printOperationWithView_printInfo_ = sel_registerName("printOperationWithView:printInfo:");
        sel_printPanel = sel_registerName("printPanel");
        sel_printer = sel_registerName("printer");
        sel_printerNames = sel_registerName("printerNames");
        sel_printerWithName_ = sel_registerName("printerWithName:");
        sel_propertyListForType_ = sel_registerName("propertyListForType:");
        sel_rangeValue = sel_registerName("rangeValue");
        sel_recentSearches = sel_registerName("recentSearches");
        sel_rectOfColumn_ = sel_registerName("rectOfColumn:");
        sel_rectOfRow_ = sel_registerName("rectOfRow:");
        sel_redComponent = sel_registerName("redComponent");
        sel_reflectScrolledClipView_ = sel_registerName("reflectScrolledClipView:");
        sel_registerForDraggedTypes_ = sel_registerName("registerForDraggedTypes:");
        sel_release = sel_registerName("release");
        sel_reload_ = sel_registerName("reload:");
        sel_reloadData = sel_registerName("reloadData");
        sel_reloadItem_ = sel_registerName("reloadItem:");
        sel_reloadItem_reloadChildren_ = sel_registerName("reloadItem:reloadChildren:");
        sel_removeAllItems = sel_registerName("removeAllItems");
        sel_removeAllPoints = sel_registerName("removeAllPoints");
        sel_removeFromSuperview = sel_registerName("removeFromSuperview");
        sel_removeItem_ = sel_registerName("removeItem:");
        sel_removeItemAtIndex_ = sel_registerName("removeItemAtIndex:");
        sel_removeItemAtPath_error_ = sel_registerName("removeItemAtPath:error:");
        sel_removeObject_ = sel_registerName("removeObject:");
        sel_removeObjectAtIndex_ = sel_registerName("removeObjectAtIndex:");
        sel_removeObserver_ = sel_registerName("removeObserver:");
        sel_removeStatusItem_ = sel_registerName("removeStatusItem:");
        sel_removeTabViewItem_ = sel_registerName("removeTabViewItem:");
        sel_removeTableColumn_ = sel_registerName("removeTableColumn:");
        sel_removeTemporaryAttribute_forCharacterRange_ = sel_registerName("removeTemporaryAttribute:forCharacterRange:");
        sel_replaceCharactersInRange_withString_ = sel_registerName("replaceCharactersInRange:withString:");
        sel_representation = sel_registerName("representation");
        sel_request = sel_registerName("request");
        sel_requestWithURL_ = sel_registerName("requestWithURL:");
        sel_resignFirstResponder = sel_registerName("resignFirstResponder");
        sel_resizeDownCursor = sel_registerName("resizeDownCursor");
        sel_resizeLeftCursor = sel_registerName("resizeLeftCursor");
        sel_resizeLeftRightCursor = sel_registerName("resizeLeftRightCursor");
        sel_resizeRightCursor = sel_registerName("resizeRightCursor");
        sel_resizeUpCursor = sel_registerName("resizeUpCursor");
        sel_resizeUpDownCursor = sel_registerName("resizeUpDownCursor");
        sel_resizingMask = sel_registerName("resizingMask");
        sel_respondsToSelector_ = sel_registerName("respondsToSelector:");
        sel_restoreGraphicsState = sel_registerName("restoreGraphicsState");
        sel_retain = sel_registerName("retain");
        sel_retainCount = sel_registerName("retainCount");
        sel_rightMouseDown_ = sel_registerName("rightMouseDown:");
        sel_rightMouseDragged_ = sel_registerName("rightMouseDragged:");
        sel_rightMouseUp_ = sel_registerName("rightMouseUp:");
        sel_rotateByDegrees_ = sel_registerName("rotateByDegrees:");
        sel_rowAtPoint_ = sel_registerName("rowAtPoint:");
        sel_rowForItem_ = sel_registerName("rowForItem:");
        sel_rowHeight = sel_registerName("rowHeight");
        sel_rowsInRect_ = sel_registerName("rowsInRect:");
        sel_run = sel_registerName("run");
        sel_runModal = sel_registerName("runModal");
        sel_runModalForWindow_ = sel_registerName("runModalForWindow:");
        sel_runModalWithPrintInfo_ = sel_registerName("runModalWithPrintInfo:");
        sel_runMode_beforeDate_ = sel_registerName("runMode:beforeDate:");
        sel_runOperation = sel_registerName("runOperation");
        sel_samplesPerPixel = sel_registerName("samplesPerPixel");
        sel_saveGraphicsState = sel_registerName("saveGraphicsState");
        sel_savePanel = sel_registerName("savePanel");
        sel_scaleXBy_yBy_ = sel_registerName("scaleXBy:yBy:");
        sel_scheduledTimerWithTimeInterval_target_selector_userInfo_repeats_ = sel_registerName("scheduledTimerWithTimeInterval:target:selector:userInfo:repeats:");
        sel_screen = sel_registerName("screen");
        sel_screens = sel_registerName("screens");
        sel_scrollColumnToVisible_ = sel_registerName("scrollColumnToVisible:");
        sel_scrollRangeToVisible_ = sel_registerName("scrollRangeToVisible:");
        sel_scrollRectToVisible_ = sel_registerName("scrollRectToVisible:");
        sel_scrollRowToVisible_ = sel_registerName("scrollRowToVisible:");
        sel_scrollToPoint_ = sel_registerName("scrollToPoint:");
        sel_scrollWheel_ = sel_registerName("scrollWheel:");
        sel_scrollerWidth = sel_registerName("scrollerWidth");
        sel_secondOfMinute = sel_registerName("secondOfMinute");
        sel_secondarySelectedControlColor = sel_registerName("secondarySelectedControlColor");
        sel_selectAll_ = sel_registerName("selectAll:");
        sel_selectItem_ = sel_registerName("selectItem:");
        sel_selectItemAtIndex_ = sel_registerName("selectItemAtIndex:");
        sel_selectRow_byExtendingSelection_ = sel_registerName("selectRow:byExtendingSelection:");
        sel_selectRowIndexes_byExtendingSelection_ = sel_registerName("selectRowIndexes:byExtendingSelection:");
        sel_selectTabViewItemAtIndex_ = sel_registerName("selectTabViewItemAtIndex:");
        sel_selectedControlTextColor = sel_registerName("selectedControlTextColor");
        sel_selectedRange = sel_registerName("selectedRange");
        sel_selectedRow = sel_registerName("selectedRow");
        sel_selectedRowIndexes = sel_registerName("selectedRowIndexes");
        sel_selectedTabViewItem = sel_registerName("selectedTabViewItem");
        sel_selectedTextBackgroundColor = sel_registerName("selectedTextBackgroundColor");
        sel_selectedTextColor = sel_registerName("selectedTextColor");
        sel_sendAction_to_ = sel_registerName("sendAction:to:");
        sel_sendEvent_ = sel_registerName("sendEvent:");
        sel_separatorItem = sel_registerName("separatorItem");
        sel_set = sel_registerName("set");
        sel_setAcceptsMouseMovedEvents_ = sel_registerName("setAcceptsMouseMovedEvents:");
        sel_setAction_ = sel_registerName("setAction:");
        sel_setAlertStyle_ = sel_registerName("setAlertStyle:");
        sel_setAlignment_ = sel_registerName("setAlignment:");
        sel_setAllowsColumnReordering_ = sel_registerName("setAllowsColumnReordering:");
        sel_setAllowsFloats_ = sel_registerName("setAllowsFloats:");
        sel_setAllowsMixedState_ = sel_registerName("setAllowsMixedState:");
        sel_setAllowsMultipleSelection_ = sel_registerName("setAllowsMultipleSelection:");
        sel_setAlphaValue_ = sel_registerName("setAlphaValue:");
        sel_setApplicationIconImage_ = sel_registerName("setApplicationIconImage:");
        sel_setApplicationNameForUserAgent_ = sel_registerName("setApplicationNameForUserAgent:");
        sel_setAttributedStringValue_ = sel_registerName("setAttributedStringValue:");
        sel_setAttributedTitle_ = sel_registerName("setAttributedTitle:");
        sel_setAutoenablesItems_ = sel_registerName("setAutoenablesItems:");
        sel_setAutohidesScrollers_ = sel_registerName("setAutohidesScrollers:");
        sel_setAutoresizesOutlineColumn_ = sel_registerName("setAutoresizesOutlineColumn:");
        sel_setAutoresizesSubviews_ = sel_registerName("setAutoresizesSubviews:");
        sel_setAutoresizingMask_ = sel_registerName("setAutoresizingMask:");
        sel_setAutosaveExpandedItems_ = sel_registerName("setAutosaveExpandedItems:");
        sel_setBackgroundColor_ = sel_registerName("setBackgroundColor:");
        sel_setBezelStyle_ = sel_registerName("setBezelStyle:");
        sel_setBorderType_ = sel_registerName("setBorderType:");
        sel_setBorderWidth_ = sel_registerName("setBorderWidth:");
        sel_setBordered_ = sel_registerName("setBordered:");
        sel_setBoxType_ = sel_registerName("setBoxType:");
        sel_setButtonType_ = sel_registerName("setButtonType:");
        sel_setCacheMode_ = sel_registerName("setCacheMode:");
        sel_setCanChooseDirectories_ = sel_registerName("setCanChooseDirectories:");
        sel_setCanChooseFiles_ = sel_registerName("setCanChooseFiles:");
        sel_setCellClass_ = sel_registerName("setCellClass:");
        sel_setClip = sel_registerName("setClip");
        sel_setColor_ = sel_registerName("setColor:");
        sel_setColumnAutoresizingStyle_ = sel_registerName("setColumnAutoresizingStyle:");
        sel_setCompositingOperation_ = sel_registerName("setCompositingOperation:");
        sel_setContainerSize_ = sel_registerName("setContainerSize:");
        sel_setContentView_ = sel_registerName("setContentView:");
        sel_setContentViewMargins_ = sel_registerName("setContentViewMargins:");
        sel_setCurrentContext_ = sel_registerName("setCurrentContext:");
        sel_setCurrentOperation_ = sel_registerName("setCurrentOperation:");
        sel_setData_forType_ = sel_registerName("setData:forType:");
        sel_setDataCell_ = sel_registerName("setDataCell:");
        sel_setDataSource_ = sel_registerName("setDataSource:");
        sel_setDatePickerElements_ = sel_registerName("setDatePickerElements:");
        sel_setDatePickerStyle_ = sel_registerName("setDatePickerStyle:");
        sel_setDateValue_ = sel_registerName("setDateValue:");
        sel_setDefaultFlatness_ = sel_registerName("setDefaultFlatness:");
        sel_setDefaultTabInterval_ = sel_registerName("setDefaultTabInterval:");
        sel_setDelegate_ = sel_registerName("setDelegate:");
        sel_setDestination_allowOverwrite_ = sel_registerName("setDestination:allowOverwrite:");
        sel_setDirectory_ = sel_registerName("setDirectory:");
        sel_setDocumentView_ = sel_registerName("setDocumentView:");
        sel_setDoubleAction_ = sel_registerName("setDoubleAction:");
        sel_setDoubleValue_ = sel_registerName("setDoubleValue:");
        sel_setDownloadDelegate_ = sel_registerName("setDownloadDelegate:");
        sel_setDrawsBackground_ = sel_registerName("setDrawsBackground:");
        sel_setEditable_ = sel_registerName("setEditable:");
        sel_setEnabled_ = sel_registerName("setEnabled:");
        sel_setFill = sel_registerName("setFill");
        sel_setFireDate_ = sel_registerName("setFireDate:");
        sel_setFirstLineHeadIndent_ = sel_registerName("setFirstLineHeadIndent:");
        sel_setFloatValue_knobProportion_ = sel_registerName("setFloatValue:knobProportion:");
        sel_setFocusRingType_ = sel_registerName("setFocusRingType:");
        sel_setFont_ = sel_registerName("setFont:");
        sel_setFormatter_ = sel_registerName("setFormatter:");
        sel_setFrame_ = sel_registerName("setFrame:");
        sel_setFrame_display_ = sel_registerName("setFrame:display:");
        sel_setFrameLoadDelegate_ = sel_registerName("setFrameLoadDelegate:");
        sel_setFrameOrigin_ = sel_registerName("setFrameOrigin:");
        sel_setFrameSize_ = sel_registerName("setFrameSize:");
        sel_setHasHorizontalScroller_ = sel_registerName("setHasHorizontalScroller:");
        sel_setHasShadow_ = sel_registerName("setHasShadow:");
        sel_setHasVerticalScroller_ = sel_registerName("setHasVerticalScroller:");
        sel_setHeaderCell_ = sel_registerName("setHeaderCell:");
        sel_setHeaderView_ = sel_registerName("setHeaderView:");
        sel_setHidden_ = sel_registerName("setHidden:");
        sel_setHiddenUntilMouseMoves_ = sel_registerName("setHiddenUntilMouseMoves:");
        sel_setHighlightMode_ = sel_registerName("setHighlightMode:");
        sel_setHighlighted_ = sel_registerName("setHighlighted:");
        sel_setHorizontalScroller_ = sel_registerName("setHorizontalScroller:");
        sel_setHorizontallyResizable_ = sel_registerName("setHorizontallyResizable:");
        sel_setIdentifier_ = sel_registerName("setIdentifier:");
        sel_setImage_ = sel_registerName("setImage:");
        sel_setImageAlignment_ = sel_registerName("setImageAlignment:");
        sel_setImageInterpolation_ = sel_registerName("setImageInterpolation:");
        sel_setImagePosition_ = sel_registerName("setImagePosition:");
        sel_setImageScaling_ = sel_registerName("setImageScaling:");
        sel_setIncrement_ = sel_registerName("setIncrement:");
        sel_setIndentationPerLevel_ = sel_registerName("setIndentationPerLevel:");
        sel_setIndeterminate_ = sel_registerName("setIndeterminate:");
        sel_setJavaEnabled_ = sel_registerName("setJavaEnabled:");
        sel_setJobDisposition_ = sel_registerName("setJobDisposition:");
        sel_setJobTitle_ = sel_registerName("setJobTitle:");
        sel_setKeyEquivalent_ = sel_registerName("setKeyEquivalent:");
        sel_setKeyEquivalentModifierMask_ = sel_registerName("setKeyEquivalentModifierMask:");
        sel_setLabel_ = sel_registerName("setLabel:");
        sel_setLeaf_ = sel_registerName("setLeaf:");
        sel_setLength_ = sel_registerName("setLength:");
        sel_setLevel_ = sel_registerName("setLevel:");
        sel_setLineBreakMode_ = sel_registerName("setLineBreakMode:");
        sel_setLineCapStyle_ = sel_registerName("setLineCapStyle:");
        sel_setLineDash_count_phase_ = sel_registerName("setLineDash:count:phase:");
        sel_setLineFragmentPadding_ = sel_registerName("setLineFragmentPadding:");
        sel_setLineFragmentRect_forGlyphRange_usedRect_ = sel_registerName("setLineFragmentRect:forGlyphRange:usedRect:");
        sel_setLineJoinStyle_ = sel_registerName("setLineJoinStyle:");
        sel_setLineSpacing_ = sel_registerName("setLineSpacing:");
        sel_setLineWidth_ = sel_registerName("setLineWidth:");
        sel_setMarkedText_selectedRange_ = sel_registerName("setMarkedText:selectedRange:");
        sel_setMaxSize_ = sel_registerName("setMaxSize:");
        sel_setMaxValue_ = sel_registerName("setMaxValue:");
        sel_setMaximum_ = sel_registerName("setMaximum:");
        sel_setMaximumFractionDigits_ = sel_registerName("setMaximumFractionDigits:");
        sel_setMaximumIntegerDigits_ = sel_registerName("setMaximumIntegerDigits:");
        sel_setMenu_ = sel_registerName("setMenu:");
        sel_setMinSize_ = sel_registerName("setMinSize:");
        sel_setMinValue_ = sel_registerName("setMinValue:");
        sel_setMinWidth_ = sel_registerName("setMinWidth:");
        sel_setMinimum_ = sel_registerName("setMinimum:");
        sel_setMinimumFractionDigits_ = sel_registerName("setMinimumFractionDigits:");
        sel_setMinimumIntegerDigits_ = sel_registerName("setMinimumIntegerDigits:");
        sel_setMiterLimit_ = sel_registerName("setMiterLimit:");
        sel_setNeedsDisplay_ = sel_registerName("setNeedsDisplay:");
        sel_setNeedsDisplayInRect_ = sel_registerName("setNeedsDisplayInRect:");
        sel_setNumberOfVisibleItems_ = sel_registerName("setNumberOfVisibleItems:");
        sel_setNumberStyle_ = sel_registerName("setNumberStyle:");
        sel_setObject_forKey_ = sel_registerName("setObject:forKey:");
        sel_setOnMouseEntered_ = sel_registerName("setOnMouseEntered:");
        sel_setOpaque_ = sel_registerName("setOpaque:");
        sel_setOptions_ = sel_registerName("setOptions:");
        sel_setOutlineTableColumn_ = sel_registerName("setOutlineTableColumn:");
        sel_setPanelFont_isMultiple_ = sel_registerName("setPanelFont:isMultiple:");
        sel_setPartialStringValidationEnabled_ = sel_registerName("setPartialStringValidationEnabled:");
        sel_setPatternPhase_ = sel_registerName("setPatternPhase:");
        sel_setPixelFormat_ = sel_registerName("setPixelFormat:");
        sel_setPolicyDelegate_ = sel_registerName("setPolicyDelegate:");
        sel_setPrinter_ = sel_registerName("setPrinter:");
        sel_setPropertyList_forType_ = sel_registerName("setPropertyList:forType:");
        sel_setPullsDown_ = sel_registerName("setPullsDown:");
        sel_setReleasedWhenClosed_ = sel_registerName("setReleasedWhenClosed:");
        sel_setResizingMask_ = sel_registerName("setResizingMask:");
        sel_setResourceLoadDelegate_ = sel_registerName("setResourceLoadDelegate:");
        sel_setRichText_ = sel_registerName("setRichText:");
        sel_setRowHeight_ = sel_registerName("setRowHeight:");
        sel_setSelectable_ = sel_registerName("setSelectable:");
        sel_setSelectedRange_ = sel_registerName("setSelectedRange:");
        sel_setShouldAntialias_ = sel_registerName("setShouldAntialias:");
        sel_setShowsPrintPanel_ = sel_registerName("setShowsPrintPanel:");
        sel_setShowsProgressPanel_ = sel_registerName("setShowsProgressPanel:");
        sel_setSize_ = sel_registerName("setSize:");
        sel_setState_ = sel_registerName("setState:");
        sel_setString_ = sel_registerName("setString:");
        sel_setString_forType_ = sel_registerName("setString:forType:");
        sel_setStringValue_ = sel_registerName("setStringValue:");
        sel_setStroke = sel_registerName("setStroke");
        sel_setSubmenu_ = sel_registerName("setSubmenu:");
        sel_setTabStops_ = sel_registerName("setTabStops:");
        sel_setTabViewType_ = sel_registerName("setTabViewType:");
        sel_setTarget_ = sel_registerName("setTarget:");
        sel_setTextColor_ = sel_registerName("setTextColor:");
        sel_setTitle_ = sel_registerName("setTitle:");
        sel_setTitleFont_ = sel_registerName("setTitleFont:");
        sel_setTitlePosition_ = sel_registerName("setTitlePosition:");
        sel_setToolTip_ = sel_registerName("setToolTip:");
        sel_setTransformStruct_ = sel_registerName("setTransformStruct:");
        sel_setUIDelegate_ = sel_registerName("setUIDelegate:");
        sel_setURL_ = sel_registerName("setURL:");
        sel_setUpPrintOperationDefaultValues = sel_registerName("setUpPrintOperationDefaultValues");
        sel_setUsesAlternatingRowBackgroundColors_ = sel_registerName("setUsesAlternatingRowBackgroundColors:");
        sel_setUsesThreadedAnimation_ = sel_registerName("setUsesThreadedAnimation:");
        sel_setValue_forKey_ = sel_registerName("setValue:forKey:");
        sel_setValueWraps_ = sel_registerName("setValueWraps:");
        sel_setVerticalScroller_ = sel_registerName("setVerticalScroller:");
        sel_setView_ = sel_registerName("setView:");
        sel_setWidth_ = sel_registerName("setWidth:");
        sel_setWidthTracksTextView_ = sel_registerName("setWidthTracksTextView:");
        sel_setWindingRule_ = sel_registerName("setWindingRule:");
        sel_setWorksWhenModal_ = sel_registerName("setWorksWhenModal:");
        sel_setWraps_ = sel_registerName("setWraps:");
        sel_sharedApplication = sel_registerName("sharedApplication");
        sel_sharedColorPanel = sel_registerName("sharedColorPanel");
        sel_sharedFontManager = sel_registerName("sharedFontManager");
        sel_sharedFontPanel = sel_registerName("sharedFontPanel");
        sel_sharedHTTPCookieStorage = sel_registerName("sharedHTTPCookieStorage");
        sel_sharedPrintInfo = sel_registerName("sharedPrintInfo");
        sel_sharedWorkspace = sel_registerName("sharedWorkspace");
        sel_shiftKey = sel_registerName("shiftKey");
        sel_size = sel_registerName("size");
        sel_sizeToFit = sel_registerName("sizeToFit");
        sel_sizeValue = sel_registerName("sizeValue");
        sel_skipDescendents = sel_registerName("skipDescendents");
        sel_smallSystemFontSize = sel_registerName("smallSystemFontSize");
        sel_sortIndicatorRectForBounds_ = sel_registerName("sortIndicatorRectForBounds:");
        sel_standardPreferences = sel_registerName("standardPreferences");
        sel_startAnimation_ = sel_registerName("startAnimation:");
        sel_state = sel_registerName("state");
        sel_statusItemWithLength_ = sel_registerName("statusItemWithLength:");
        sel_stop_ = sel_registerName("stop:");
        sel_stopLoading_ = sel_registerName("stopLoading:");
        sel_string = sel_registerName("string");
        sel_stringByAddingPercentEscapesUsingEncoding_ = sel_registerName("stringByAddingPercentEscapesUsingEncoding:");
        sel_stringByAppendingPathComponent_ = sel_registerName("stringByAppendingPathComponent:");
        sel_stringByAppendingString_ = sel_registerName("stringByAppendingString:");
        sel_stringByDeletingLastPathComponent = sel_registerName("stringByDeletingLastPathComponent");
        sel_stringByDeletingPathExtension = sel_registerName("stringByDeletingPathExtension");
        sel_stringByEvaluatingJavaScriptFromString_ = sel_registerName("stringByEvaluatingJavaScriptFromString:");
        sel_stringByReplacingOccurrencesOfString_withString_ = sel_registerName("stringByReplacingOccurrencesOfString:withString:");
        sel_stringForObjectValue_ = sel_registerName("stringForObjectValue:");
        sel_stringForType_ = sel_registerName("stringForType:");
        sel_stringValue = sel_registerName("stringValue");
        sel_stringWithCharacters_length_ = sel_registerName("stringWithCharacters:length:");
        sel_stringWithUTF8String_ = sel_registerName("stringWithUTF8String:");
        sel_stroke = sel_registerName("stroke");
        sel_strokeRect_ = sel_registerName("strokeRect:");
        sel_styleMask = sel_registerName("styleMask");
        sel_submenu = sel_registerName("submenu");
        sel_subviews = sel_registerName("subviews");
        sel_superclass = sel_registerName("superclass");
        sel_superview = sel_registerName("superview");
        sel_systemFontOfSize_ = sel_registerName("systemFontOfSize:");
        sel_systemFontSize = sel_registerName("systemFontSize");
        sel_systemFontSizeForControlSize_ = sel_registerName("systemFontSizeForControlSize:");
        sel_systemStatusBar = sel_registerName("systemStatusBar");
        sel_systemVersion = sel_registerName("systemVersion");
        sel_tabStopType = sel_registerName("tabStopType");
        sel_tabStops = sel_registerName("tabStops");
        sel_tabView_didSelectTabViewItem_ = sel_registerName("tabView:didSelectTabViewItem:");
        sel_tabView_willSelectTabViewItem_ = sel_registerName("tabView:willSelectTabViewItem:");
        sel_tabViewItemAtPoint_ = sel_registerName("tabViewItemAtPoint:");
        sel_tableColumns = sel_registerName("tableColumns");
        sel_tableView_didClickTableColumn_ = sel_registerName("tableView:didClickTableColumn:");
        sel_tableView_objectValueForTableColumn_row_ = sel_registerName("tableView:objectValueForTableColumn:row:");
        sel_tableView_setObjectValue_forTableColumn_row_ = sel_registerName("tableView:setObjectValue:forTableColumn:row:");
        sel_tableView_shouldEditTableColumn_row_ = sel_registerName("tableView:shouldEditTableColumn:row:");
        sel_tableView_willDisplayCell_forTableColumn_row_ = sel_registerName("tableView:willDisplayCell:forTableColumn:row:");
        sel_tableViewColumnDidMove_ = sel_registerName("tableViewColumnDidMove:");
        sel_tableViewColumnDidResize_ = sel_registerName("tableViewColumnDidResize:");
        sel_tableViewSelectionDidChange_ = sel_registerName("tableViewSelectionDidChange:");
        sel_target = sel_registerName("target");
        sel_terminate_ = sel_registerName("terminate:");
        sel_textBackgroundColor = sel_registerName("textBackgroundColor");
        sel_textColor = sel_registerName("textColor");
        sel_textContainer = sel_registerName("textContainer");
        sel_textDidChange_ = sel_registerName("textDidChange:");
        sel_textStorage = sel_registerName("textStorage");
        sel_textView_clickedOnLink_atIndex_ = sel_registerName("textView:clickedOnLink:atIndex:");
        sel_textView_willChangeSelectionFromCharacterRange_toCharacterRange_ = sel_registerName("textView:willChangeSelectionFromCharacterRange:toCharacterRange:");
        sel_textViewDidChangeSelection_ = sel_registerName("textViewDidChangeSelection:");
        sel_threadDictionary = sel_registerName("threadDictionary");
        sel_tile = sel_registerName("tile");
        sel_timeZone = sel_registerName("timeZone");
        sel_title = sel_registerName("title");
        sel_titleCell = sel_registerName("titleCell");
        sel_titleOfSelectedItem = sel_registerName("titleOfSelectedItem");
        sel_titleRectForBounds_ = sel_registerName("titleRectForBounds:");
        sel_transform = sel_registerName("transform");
        sel_transformPoint_ = sel_registerName("transformPoint:");
        sel_transformSize_ = sel_registerName("transformSize:");
        sel_transformStruct = sel_registerName("transformStruct");
        sel_transformUsingAffineTransform_ = sel_registerName("transformUsingAffineTransform:");
        sel_translateXBy_yBy_ = sel_registerName("translateXBy:yBy:");
        sel_type = sel_registerName("type");
        sel_types = sel_registerName("types");
        sel_typesetter = sel_registerName("typesetter");
        sel_unarchiveObjectWithData_ = sel_registerName("unarchiveObjectWithData:");
        sel_unhideAllApplications_ = sel_registerName("unhideAllApplications:");
        sel_unmarkText = sel_registerName("unmarkText");
        sel_unregisterDraggedTypes = sel_registerName("unregisterDraggedTypes");
        sel_use = sel_registerName("use");
        sel_usedRectForTextContainer_ = sel_registerName("usedRectForTextContainer:");
        sel_userInfo = sel_registerName("userInfo");
        sel_usesAlternatingRowBackgroundColors = sel_registerName("usesAlternatingRowBackgroundColors");
        sel_validAttributesForMarkedText = sel_registerName("validAttributesForMarkedText");
        sel_valueForKey_ = sel_registerName("valueForKey:");
        sel_valueWithPoint_ = sel_registerName("valueWithPoint:");
        sel_valueWithRange_ = sel_registerName("valueWithRange:");
        sel_valueWithRect_ = sel_registerName("valueWithRect:");
        sel_valueWithSize_ = sel_registerName("valueWithSize:");
        sel_visibleFrame = sel_registerName("visibleFrame");
        sel_visibleRect = sel_registerName("visibleRect");
        sel_wantsPeriodicDraggingUpdates = sel_registerName("wantsPeriodicDraggingUpdates");
        sel_wantsToHandleMouseEvents = sel_registerName("wantsToHandleMouseEvents");
        sel_webFrame = sel_registerName("webFrame");
        sel_webView_contextMenuItemsForElement_defaultMenuItems_ = sel_registerName("webView:contextMenuItemsForElement:defaultMenuItems:");
        sel_webView_createWebViewWithRequest_ = sel_registerName("webView:createWebViewWithRequest:");
        sel_webView_decidePolicyForMIMEType_request_frame_decisionListener_ = sel_registerName("webView:decidePolicyForMIMEType:request:frame:decisionListener:");
        sel_webView_decidePolicyForNavigationAction_request_frame_decisionListener_ = sel_registerName("webView:decidePolicyForNavigationAction:request:frame:decisionListener:");
        sel_webView_decidePolicyForNewWindowAction_request_newFrameName_decisionListener_ = sel_registerName("webView:decidePolicyForNewWindowAction:request:newFrameName:decisionListener:");
        sel_webView_didChangeLocationWithinPageForFrame_ = sel_registerName("webView:didChangeLocationWithinPageForFrame:");
        sel_webView_didCommitLoadForFrame_ = sel_registerName("webView:didCommitLoadForFrame:");
        sel_webView_didFailProvisionalLoadWithError_forFrame_ = sel_registerName("webView:didFailProvisionalLoadWithError:forFrame:");
        sel_webView_didFinishLoadForFrame_ = sel_registerName("webView:didFinishLoadForFrame:");
        sel_webView_didReceiveTitle_forFrame_ = sel_registerName("webView:didReceiveTitle:forFrame:");
        sel_webView_didStartProvisionalLoadForFrame_ = sel_registerName("webView:didStartProvisionalLoadForFrame:");
        sel_webView_identifierForInitialRequest_fromDataSource_ = sel_registerName("webView:identifierForInitialRequest:fromDataSource:");
        sel_webView_mouseDidMoveOverElement_modifierFlags_ = sel_registerName("webView:mouseDidMoveOverElement:modifierFlags:");
        sel_webView_printFrameView_ = sel_registerName("webView:printFrameView:");
        sel_webView_resource_didFailLoadingWithError_fromDataSource_ = sel_registerName("webView:resource:didFailLoadingWithError:fromDataSource:");
        sel_webView_resource_didFinishLoadingFromDataSource_ = sel_registerName("webView:resource:didFinishLoadingFromDataSource:");
        sel_webView_resource_willSendRequest_redirectResponse_fromDataSource_ = sel_registerName("webView:resource:willSendRequest:redirectResponse:fromDataSource:");
        sel_webView_runJavaScriptAlertPanelWithMessage_ = sel_registerName("webView:runJavaScriptAlertPanelWithMessage:");
        sel_webView_runJavaScriptConfirmPanelWithMessage_ = sel_registerName("webView:runJavaScriptConfirmPanelWithMessage:");
        sel_webView_runOpenPanelForFileButtonWithResultListener_ = sel_registerName("webView:runOpenPanelForFileButtonWithResultListener:");
        sel_webView_setFrame_ = sel_registerName("webView:setFrame:");
        sel_webView_setResizable_ = sel_registerName("webView:setResizable:");
        sel_webView_setStatusBarVisible_ = sel_registerName("webView:setStatusBarVisible:");
        sel_webView_setStatusText_ = sel_registerName("webView:setStatusText:");
        sel_webView_setToolbarsVisible_ = sel_registerName("webView:setToolbarsVisible:");
        sel_webView_unableToImplementPolicyWithError_frame_ = sel_registerName("webView:unableToImplementPolicyWithError:frame:");
        sel_webViewClose_ = sel_registerName("webViewClose:");
        sel_webViewFocus_ = sel_registerName("webViewFocus:");
        sel_webViewShow_ = sel_registerName("webViewShow:");
        sel_webViewUnfocus_ = sel_registerName("webViewUnfocus:");
        sel_wheelDelta = sel_registerName("wheelDelta");
        sel_width = sel_registerName("width");
        sel_window = sel_registerName("window");
        sel_windowBackgroundColor = sel_registerName("windowBackgroundColor");
        sel_windowDidBecomeKey_ = sel_registerName("windowDidBecomeKey:");
        sel_windowDidMove_ = sel_registerName("windowDidMove:");
        sel_windowDidResignKey_ = sel_registerName("windowDidResignKey:");
        sel_windowDidResize_ = sel_registerName("windowDidResize:");
        sel_windowFrameColor = sel_registerName("windowFrameColor");
        sel_windowFrameTextColor = sel_registerName("windowFrameTextColor");
        sel_windowNumber = sel_registerName("windowNumber");
        sel_windowShouldClose_ = sel_registerName("windowShouldClose:");
        sel_windowWillClose_ = sel_registerName("windowWillClose:");
        sel_windows = sel_registerName("windows");
        sel_worksWhenModal = sel_registerName("worksWhenModal");
        sel_wraps = sel_registerName("wraps");
        sel_writeToPasteboard_ = sel_registerName("writeToPasteboard:");
        sel_yearOfCommonEra = sel_registerName("yearOfCommonEra");
        
        NSAccessibilityButtonRole = new NSString (NSAccessibilityButtonRole_);
        NSAccessibilityCheckBoxRole = new NSString (NSAccessibilityCheckBoxRole_);
        NSAccessibilityChildrenAttribute = new NSString (NSAccessibilityChildrenAttribute_);
        NSAccessibilityColumnRole = new NSString (NSAccessibilityColumnRole_);
        NSAccessibilityComboBoxRole = new NSString (NSAccessibilityComboBoxRole_);
        NSAccessibilityConfirmAction = new NSString (NSAccessibilityConfirmAction_);
        NSAccessibilityContentsAttribute = new NSString (NSAccessibilityContentsAttribute_);
        NSAccessibilityDescriptionAttribute = new NSString (NSAccessibilityDescriptionAttribute_);
        NSAccessibilityDialogSubrole = new NSString (NSAccessibilityDialogSubrole_);
        NSAccessibilityEnabledAttribute = new NSString (NSAccessibilityEnabledAttribute_);
        NSAccessibilityExpandedAttribute = new NSString (NSAccessibilityExpandedAttribute_);
        NSAccessibilityFloatingWindowSubrole = new NSString (NSAccessibilityFloatingWindowSubrole_);
        NSAccessibilityFocusedAttribute = new NSString (NSAccessibilityFocusedAttribute_);
        NSAccessibilityFocusedUIElementChangedNotification = new NSString (NSAccessibilityFocusedUIElementChangedNotification_);
        NSAccessibilityGridRole = new NSString (NSAccessibilityGridRole_);
        NSAccessibilityGroupRole = new NSString (NSAccessibilityGroupRole_);
        NSAccessibilityHelpAttribute = new NSString (NSAccessibilityHelpAttribute_);
        NSAccessibilityHelpTagRole = new NSString (NSAccessibilityHelpTagRole_);
        NSAccessibilityHorizontalOrientationValue = new NSString (NSAccessibilityHorizontalOrientationValue_);
        NSAccessibilityHorizontalScrollBarAttribute = new NSString (NSAccessibilityHorizontalScrollBarAttribute_);
        NSAccessibilityImageRole = new NSString (NSAccessibilityImageRole_);
        NSAccessibilityIncrementorRole = new NSString (NSAccessibilityIncrementorRole_);
        NSAccessibilityInsertionPointLineNumberAttribute = new NSString (NSAccessibilityInsertionPointLineNumberAttribute_);
        NSAccessibilityLabelValueAttribute = new NSString (NSAccessibilityLabelValueAttribute_);
        NSAccessibilityLineForIndexParameterizedAttribute = new NSString (NSAccessibilityLineForIndexParameterizedAttribute_);
        NSAccessibilityLinkRole = new NSString (NSAccessibilityLinkRole_);
        NSAccessibilityLinkTextAttribute = new NSString (NSAccessibilityLinkTextAttribute_);
        NSAccessibilityListRole = new NSString (NSAccessibilityListRole_);
        NSAccessibilityMaxValueAttribute = new NSString (NSAccessibilityMaxValueAttribute_);
        NSAccessibilityMenuBarRole = new NSString (NSAccessibilityMenuBarRole_);
        NSAccessibilityMenuButtonRole = new NSString (NSAccessibilityMenuButtonRole_);
        NSAccessibilityMenuItemRole = new NSString (NSAccessibilityMenuItemRole_);
        NSAccessibilityMenuRole = new NSString (NSAccessibilityMenuRole_);
        NSAccessibilityMinValueAttribute = new NSString (NSAccessibilityMinValueAttribute_);
        NSAccessibilityNextContentsAttribute = new NSString (NSAccessibilityNextContentsAttribute_);
        NSAccessibilityNumberOfCharactersAttribute = new NSString (NSAccessibilityNumberOfCharactersAttribute_);
        NSAccessibilityOrientationAttribute = new NSString (NSAccessibilityOrientationAttribute_);
        NSAccessibilityOutlineRole = new NSString (NSAccessibilityOutlineRole_);
        NSAccessibilityOutlineRowSubrole = new NSString (NSAccessibilityOutlineRowSubrole_);
        NSAccessibilityParentAttribute = new NSString (NSAccessibilityParentAttribute_);
        NSAccessibilityPopUpButtonRole = new NSString (NSAccessibilityPopUpButtonRole_);
        NSAccessibilityPositionAttribute = new NSString (NSAccessibilityPositionAttribute_);
        NSAccessibilityPressAction = new NSString (NSAccessibilityPressAction_);
        NSAccessibilityPreviousContentsAttribute = new NSString (NSAccessibilityPreviousContentsAttribute_);
        NSAccessibilityProgressIndicatorRole = new NSString (NSAccessibilityProgressIndicatorRole_);
        NSAccessibilityRTFForRangeParameterizedAttribute = new NSString (NSAccessibilityRTFForRangeParameterizedAttribute_);
        NSAccessibilityRadioButtonRole = new NSString (NSAccessibilityRadioButtonRole_);
        NSAccessibilityRadioGroupRole = new NSString (NSAccessibilityRadioGroupRole_);
        NSAccessibilityRangeForIndexParameterizedAttribute = new NSString (NSAccessibilityRangeForIndexParameterizedAttribute_);
        NSAccessibilityRangeForLineParameterizedAttribute = new NSString (NSAccessibilityRangeForLineParameterizedAttribute_);
        NSAccessibilityRangeForPositionParameterizedAttribute = new NSString (NSAccessibilityRangeForPositionParameterizedAttribute_);
        NSAccessibilityRoleAttribute = new NSString (NSAccessibilityRoleAttribute_);
        NSAccessibilityRoleDescriptionAttribute = new NSString (NSAccessibilityRoleDescriptionAttribute_);
        NSAccessibilityRowRole = new NSString (NSAccessibilityRowRole_);
        NSAccessibilityScrollAreaRole = new NSString (NSAccessibilityScrollAreaRole_);
        NSAccessibilityScrollBarRole = new NSString (NSAccessibilityScrollBarRole_);
        NSAccessibilitySelectedAttribute = new NSString (NSAccessibilitySelectedAttribute_);
        NSAccessibilitySelectedChildrenAttribute = new NSString (NSAccessibilitySelectedChildrenAttribute_);
        NSAccessibilitySelectedChildrenChangedNotification = new NSString (NSAccessibilitySelectedChildrenChangedNotification_);
        NSAccessibilitySelectedTextAttribute = new NSString (NSAccessibilitySelectedTextAttribute_);
        NSAccessibilitySelectedTextChangedNotification = new NSString (NSAccessibilitySelectedTextChangedNotification_);
        NSAccessibilitySelectedTextRangeAttribute = new NSString (NSAccessibilitySelectedTextRangeAttribute_);
        NSAccessibilitySelectedTextRangesAttribute = new NSString (NSAccessibilitySelectedTextRangesAttribute_);
        NSAccessibilitySizeAttribute = new NSString (NSAccessibilitySizeAttribute_);
        NSAccessibilitySliderRole = new NSString (NSAccessibilitySliderRole_);
        NSAccessibilitySortButtonRole = new NSString (NSAccessibilitySortButtonRole_);
        NSAccessibilitySplitterRole = new NSString (NSAccessibilitySplitterRole_);
        NSAccessibilityStandardWindowSubrole = new NSString (NSAccessibilityStandardWindowSubrole_);
        NSAccessibilityStaticTextRole = new NSString (NSAccessibilityStaticTextRole_);
        NSAccessibilityStringForRangeParameterizedAttribute = new NSString (NSAccessibilityStringForRangeParameterizedAttribute_);
        NSAccessibilityStyleRangeForIndexParameterizedAttribute = new NSString (NSAccessibilityStyleRangeForIndexParameterizedAttribute_);
        NSAccessibilitySubroleAttribute = new NSString (NSAccessibilitySubroleAttribute_);
        NSAccessibilitySystemDialogSubrole = new NSString (NSAccessibilitySystemDialogSubrole_);
        NSAccessibilityTabGroupRole = new NSString (NSAccessibilityTabGroupRole_);
        NSAccessibilityTableRole = new NSString (NSAccessibilityTableRole_);
        NSAccessibilityTableRowSubrole = new NSString (NSAccessibilityTableRowSubrole_);
        NSAccessibilityTabsAttribute = new NSString (NSAccessibilityTabsAttribute_);
        NSAccessibilityTextAreaRole = new NSString (NSAccessibilityTextAreaRole_);
        NSAccessibilityTextFieldRole = new NSString (NSAccessibilityTextFieldRole_);
        NSAccessibilityTextLinkSubrole = new NSString (NSAccessibilityTextLinkSubrole_);
        NSAccessibilityTitleAttribute = new NSString (NSAccessibilityTitleAttribute_);
        NSAccessibilityTitleUIElementAttribute = new NSString (NSAccessibilityTitleUIElementAttribute_);
        NSAccessibilityToolbarRole = new NSString (NSAccessibilityToolbarRole_);
        NSAccessibilityTopLevelUIElementAttribute = new NSString (NSAccessibilityTopLevelUIElementAttribute_);
        NSAccessibilityUnknownRole = new NSString (NSAccessibilityUnknownRole_);
        NSAccessibilityUnknownSubrole = new NSString (NSAccessibilityUnknownSubrole_);
        NSAccessibilityValueAttribute = new NSString (NSAccessibilityValueAttribute_);
        NSAccessibilityValueChangedNotification = new NSString (NSAccessibilityValueChangedNotification_);
        NSAccessibilityValueDescriptionAttribute = new NSString (NSAccessibilityValueDescriptionAttribute_);
        NSAccessibilityValueIndicatorRole = new NSString (NSAccessibilityValueIndicatorRole_);
        NSAccessibilityVerticalOrientationValue = new NSString (NSAccessibilityVerticalOrientationValue_);
        NSAccessibilityVerticalScrollBarAttribute = new NSString (NSAccessibilityVerticalScrollBarAttribute_);
        NSAccessibilityVisibleCharacterRangeAttribute = new NSString (NSAccessibilityVisibleCharacterRangeAttribute_);
        NSAccessibilityVisibleChildrenAttribute = new NSString (NSAccessibilityVisibleChildrenAttribute_);
        NSAccessibilityWindowAttribute = new NSString (NSAccessibilityWindowAttribute_);
        NSAccessibilityWindowRole = new NSString (NSAccessibilityWindowRole_);
        NSBackgroundColorAttributeName = new NSString (NSBackgroundColorAttributeName_);
        NSBaselineOffsetAttributeName = new NSString (NSBaselineOffsetAttributeName_);
        NSCalibratedRGBColorSpace = new NSString (NSCalibratedRGBColorSpace_);
        NSDeviceRGBColorSpace = new NSString (NSDeviceRGBColorSpace_);
        NSDeviceResolution = new NSString (NSDeviceResolution_);
        NSDragPboard = new NSString (NSDragPboard_);
        NSFilenamesPboardType = new NSString (NSFilenamesPboardType_);
        NSFontAttributeName = new NSString (NSFontAttributeName_);
        NSForegroundColorAttributeName = new NSString (NSForegroundColorAttributeName_);
        NSHTMLPboardType = new NSString (NSHTMLPboardType_);
        NSLinkAttributeName = new NSString (NSLinkAttributeName_);
        NSParagraphStyleAttributeName = new NSString (NSParagraphStyleAttributeName_);
        NSPrintAllPages = new NSString (NSPrintAllPages_);
        NSPrintCopies = new NSString (NSPrintCopies_);
        NSPrintFirstPage = new NSString (NSPrintFirstPage_);
        NSPrintJobDisposition = new NSString (NSPrintJobDisposition_);
        NSPrintLastPage = new NSString (NSPrintLastPage_);
        NSPrintMustCollate = new NSString (NSPrintMustCollate_);
        NSPrintPreviewJob = new NSString (NSPrintPreviewJob_);
        NSPrintSaveJob = new NSString (NSPrintSaveJob_);
        NSPrintSavePath = new NSString (NSPrintSavePath_);
        NSPrintSpoolJob = new NSString (NSPrintSpoolJob_);
        NSRTFPboardType = new NSString (NSRTFPboardType_);
        NSStrikethroughColorAttributeName = new NSString (NSStrikethroughColorAttributeName_);
        NSStrikethroughStyleAttributeName = new NSString (NSStrikethroughStyleAttributeName_);
        NSStringPboardType = new NSString (NSStringPboardType_);
        NSTIFFPboardType = new NSString (NSTIFFPboardType_);
        NSURLPboardType = new NSString (NSURLPboardType_);
        NSUnderlineColorAttributeName = new NSString (NSUnderlineColorAttributeName_);
        NSUnderlineStyleAttributeName = new NSString (NSUnderlineStyleAttributeName_);
        NSDefaultRunLoopMode = new NSString (NSDefaultRunLoopMode_);
        NSErrorFailingURLStringKey = new NSString (NSErrorFailingURLStringKey_);
    }
    
	public static const int gestaltSystemVersion = ('s'<<24) + ('y'<<16) + ('s'<<8) + 'v';
	public static const int noErr = 0;
	alias Carbon.ProcessApplicationTransformState.kProcessTransformToForegroundApplication kProcessTransformToForegroundApplication;
	public static const int kAlertCautionIcon = ('c'<<24) + ('a'<<16) + ('u'<<8) + 't';
	public static const int kAlertNoteIcon = ('n'<<24) + ('o'<<16) + ('t'<<8) + 'e';
	public static const int kAlertStopIcon = ('s'<<24) + ('t'<<16) + ('o'<<8) + 'p';
        
    public static const objc.SEL sel_sendSelection;
    public static const objc.SEL sel_sendDoubleSelection;
    public static const objc.SEL sel_sendVerticalSelection;
    public static const objc.SEL sel_sendHorizontalSelection;
    public static const objc.SEL sel_timerProc_;
    public static const objc.SEL sel_handleNotification_;

/** JNI natives */

/** @method flags=jni */
public static void* NewGlobalRef (Object object)
{
    return cast(void*) object;
}
/**
 * @method flags=jni
 * @param globalRef cast=(jobject)
 */
//public static final void DeleteGlobalRef(void* globalRef){}
/** @method flags=no_gen */
public static Object JNIGetObject (void* globalRef)
{
    return cast(Object) globalRef;
}

/** Carbon calls */

alias Carbon.Gestalt Gestalt;
/** @param psn cast=(ProcessSerialNumber *) */
alias Carbon.GetCurrentProcess GetCurrentProcess;
/** @param psn cast=(ProcessSerialNumber *) */
alias Carbon.SetFrontProcess SetFrontProcess;
/** @param psn cast=(ProcessSerialNumber *) */
alias Carbon.TransformProcessType TransformProcessType;
alias Carbon.CPSSetProcessName CPSSetProcessName;
/** @method flags=dynamic */
alias Carbon.SetThemeCursor SetThemeCursor;
/** @method flags=dynamic */
alias Carbon.GetCurrentButtonState GetCurrentButtonState;

alias Carbon.ThemeCursor ThemeCursor;

public static const ThemeCursor kThemeCopyArrowCursor = ThemeCursor.kThemeCopyArrowCursor;
public static const ThemeCursor kThemeNotAllowedCursor = ThemeCursor.kThemeNotAllowedCursor;
public static const ThemeCursor kThemeAliasArrowCursor = ThemeCursor.kThemeAliasArrowCursor;

/** C calls */

alias unistd.getpid getpid;

/** QuickDraw calls */

/** @method flags=dynamic */
alias Carbon.NewRgn NewRgn;
/** @method flags=dynamic */
alias Carbon.RectRgn RectRgn;
/** @method flags=dynamic */
alias Carbon.OpenRgn OpenRgn;
/** @method flags=dynamic */
alias Carbon.OffsetRgn OffsetRgn;
/** @method flags=dynamic */
alias Carbon.MoveTo MoveTo;
/** @method flags=dynamic */
alias Carbon.LineTo LineTo;
/** @method flags=dynamic */
alias Carbon.UnionRgn UnionRgn;
/** @method flags=dynamic */
alias Carbon.CloseRgn CloseRgn;
/** @method flags=dynamic */
alias Carbon.DisposeRgn DisposeRgn;
/** @method flags=dynamic */
alias Carbon.PtInRgn PtInRgn;
/** @method flags=dynamic */
alias Carbon.GetRegionBounds GetRegionBounds;
/** @method flags=dynamic */
alias Carbon.SectRgn SectRgn;
/** @method flags=dynamic */
alias Carbon.EmptyRgn EmptyRgn;
/** @method flags=dynamic */
alias Carbon.DiffRgn DiffRgn;
/** @method flags=dynamic */
alias Carbon.RectInRgn RectInRgn;
/** @method flags=dynamic */
alias Carbon.QDRegionToRects QDRegionToRects;
/** @method flags=dynamic */
alias Carbon.CopyRgn CopyRgn;
/** @method flags=dynamic */
alias Carbon.SetRect SetRect;
alias Carbon.kQDParseRegionFromTop kQDParseRegionFromTop;
alias Carbon.kQDParseRegionFromBottom kQDParseRegionFromBottom;
alias Carbon.kQDParseRegionFromLeft kQDParseRegionFromLeft;
alias Carbon.kQDParseRegionFromRight kQDParseRegionFromRight;
alias Carbon.kQDParseRegionFromTopLeft kQDParseRegionFromTopLeft;
alias Carbon.kQDRegionToRectsMsgParse kQDRegionToRectsMsgParse;

/** Custom callbacks */

/** @method flags=no_gen */
alias custom.drawRect_CALLBACK drawRect_CALLBACK;
/** @method flags=no_gen */
alias custom.drawInteriorWithFrame_inView_CALLBACK drawInteriorWithFrame_inView_CALLBACK;
/** @method flags=no_gen */
alias custom.setFrame_CALLBACK setFrame_CALLBACK;
/** @method flags=no_gen */
alias custom.setFrameOrigin_CALLBACK setFrameOrigin_CALLBACK;
/** @method flags=no_gen */
alias custom.setFrameSize_CALLBACK setFrameSize_CALLBACK;
/** @method flags=no_gen */
alias custom.hitTest_CALLBACK hitTest_CALLBACK;
/** @method flags=no_gen */
alias custom.webView_setFrame_CALLBACK webView_setFrame_CALLBACK;
/** @method flags=no_gen */
alias custom.markedRange_CALLBACK markedRange_CALLBACK;
/** @method flags=no_gen */
alias custom.selectedRange_CALLBACK selectedRange_CALLBACK;
/** @method flags=no_gen */
alias custom.highlightSelectionInClipRect_CALLBACK highlightSelectionInClipRect_CALLBACK;
/** @method flags=no_gen */
alias custom.attributedSubstringFromRange_CALLBACK attributedSubstringFromRange_CALLBACK;
/** @method flags=no_gen */
alias custom.setMarkedText_selectedRange_CALLBACK setMarkedText_selectedRange_CALLBACK;
/** @method flags=no_gen */
alias custom.characterIndexForPoint_CALLBACK characterIndexForPoint_CALLBACK;
/** @method flags=no_gen */
alias custom.firstRectForCharacterRange_CALLBACK firstRectForCharacterRange_CALLBACK;
/** @method flags=no_gen */
alias custom.textView_willChangeSelectionFromCharacterRange_toCharacterRange_CALLBACK textView_willChangeSelectionFromCharacterRange_toCharacterRange_CALLBACK;
/** @method flags=no_gen */
alias custom.draggedImage_movedTo_CALLBACK draggedImage_movedTo_CALLBACK;
/** @method flags=no_gen */
alias custom.draggedImage_beganAt_CALLBACK draggedImage_beganAt_CALLBACK;
/** @method flags=no_gen */
alias custom.draggedImage_endedAt_operation_CALLBACK draggedImage_endedAt_operation_CALLBACK;
/** @method flags=no_gen */
alias custom.accessibilityHitTest_CALLBACK accessibilityHitTest_CALLBACK;
/** @method flags=no_gen */
alias custom.dragSelectionWithEvent_offset_slideBack_CALLBACK dragSelectionWithEvent_offset_slideBack_CALLBACK;
/** Custom structure return */

/** @method flags=no_gen */
alias Cocoa.NSIntersectionRect NSIntersectionRect;

/** Objective-C runtime */

/** @param cls cast=(Class) */
alias objc.class_addIvar class_addIvar;
/**
 * @param cls cast=(Class)
 * @param name cast=(SEL)
 * @param imp cast=(IMP)
 */
alias objc.class_addMethod class_addMethod;
/**
 * @param cls cast=(Class)
 * @param protocol cast=(Protocol *)
 */
alias objc.class_addProtocol class_addProtocol;
/**
 * @param cls cast=(Class)
 * @param name cast=(SEL)
 */
alias objc.class_getMethodImplementation class_getMethodImplementation;
/** @method flags=no_gen */
alias objc.class_getName class_getName;
/** @method flags=dynamic */
alias objc.instrumentObjcMessageSends instrumentObjcMessageSends;
/** @param superclass cast=(Class) */
alias objc.objc_allocateClassPair objc_allocateClassPair;
alias objc.objc_getClass objc_getClass;
alias objc.objc_getProtocol objc_getProtocol;
alias objc.objc_lookUpClass objc_lookUpClass;
/** @method flags=cast */
alias objc.objc_msgSendSuper objc_msgSendSuper;
/** @param cls cast=(Class) */
alias objc.objc_registerClassPair objc_registerClassPair;
/** @param obj cast=(id) */
alias objc.object_getClassName object_getClassName;
/** @param obj cast=(id) */
alias objc.object_getClass object_getClass;

/**
 * @param obj cast=(id)
 * @param outValue cast=(void **)
 */
alias objc.object_getInstanceVariable object_getInstanceVariable;
/**
 * @param obj cast=(id)
 * @param value cast=(void *)
 */
alias objc.object_setInstanceVariable object_setInstanceVariable;
/**
 * @param obj cast=(id)
 * @param clazz cast=(Class) 
 */
alias objc.object_setClass object_setClass;
alias objc.sel_registerName sel_registerName;
size_t objc_super_sizeof ()
{
    return objc.objc_super.sizeof;
}


/** This section is auto generated */

/** Classes */
public static const objc.id class_DOMDocument;
public static const objc.id class_DOMEvent;
public static const objc.id class_DOMKeyboardEvent;
public static const objc.id class_DOMMouseEvent;
public static const objc.id class_DOMUIEvent;
public static const objc.id class_DOMWheelEvent;
public static const objc.id class_NSActionCell;
public static const objc.id class_NSAffineTransform;
public static const objc.id class_NSAlert;
public static const objc.id class_NSAppleEventDescriptor;
public static const objc.id class_NSApplication;
public static const objc.id class_NSArray;
public static const objc.id class_NSAttributedString;
public static const objc.id class_NSAutoreleasePool;
public static const objc.id class_NSBezierPath;
public static const objc.id class_NSBitmapImageRep;
public static const objc.id class_NSBox;
public static const objc.id class_NSBrowserCell;
public static const objc.id class_NSBundle;
public static const objc.id class_NSButton;
public static const objc.id class_NSButtonCell;
public static const objc.id class_NSCalendarDate;
public static const objc.id class_NSCell;
public static const objc.id class_NSCharacterSet;
public static const objc.id class_NSClipView;
public static const objc.id class_NSCoder;
public static const objc.id class_NSColor;
public static const objc.id class_NSColorPanel;
public static const objc.id class_NSColorSpace;
public static const objc.id class_NSComboBox;
public static const objc.id class_NSControl;
public static const objc.id class_NSCursor;
public static const objc.id class_NSData;
public static const objc.id class_NSDate;
public static const objc.id class_NSDatePicker;
public static const objc.id class_NSDictionary;
public static const objc.id class_NSDirectoryEnumerator;
public static const objc.id class_NSEnumerator;
public static const objc.id class_NSError;
public static const objc.id class_NSEvent;
public static const objc.id class_NSFileManager;
public static const objc.id class_NSFont;
public static const objc.id class_NSFontManager;
public static const objc.id class_NSFontPanel;
public static const objc.id class_NSFormatter;
public static const objc.id class_NSGradient;
public static const objc.id class_NSGraphicsContext;
public static const objc.id class_NSHTTPCookie;
public static const objc.id class_NSHTTPCookieStorage;
public static const objc.id class_NSImage;
public static const objc.id class_NSImageRep;
public static const objc.id class_NSImageView;
public static const objc.id class_NSIndexSet;
public static const objc.id class_NSInputManager;
public static const objc.id class_NSKeyedArchiver;
public static const objc.id class_NSKeyedUnarchiver;
public static const objc.id class_NSLayoutManager;
public static const objc.id class_NSMenu;
public static const objc.id class_NSMenuItem;
public static const objc.id class_NSMutableArray;
public static const objc.id class_NSMutableAttributedString;
public static const objc.id class_NSMutableDictionary;
public static const objc.id class_NSMutableIndexSet;
public static const objc.id class_NSMutableParagraphStyle;
public static const objc.id class_NSMutableSet;
public static const objc.id class_NSMutableString;
public static const objc.id class_NSMutableURLRequest;
public static const objc.id class_NSNotification;
public static const objc.id class_NSNotificationCenter;
public static const objc.id class_NSNumber;
public static const objc.id class_NSNumberFormatter;
public static const objc.id class_NSObject;
public static const objc.id class_NSOpenGLContext;
public static const objc.id class_NSOpenGLPixelFormat;
public static const objc.id class_NSOpenGLView;
public static const objc.id class_NSOpenPanel;
public static const objc.id class_NSOutlineView;
public static const objc.id class_NSPanel;
public static const objc.id class_NSParagraphStyle;
public static const objc.id class_NSPasteboard;
public static const objc.id class_NSPopUpButton;
public static const objc.id class_NSPrintInfo;
public static const objc.id class_NSPrintOperation;
public static const objc.id class_NSPrintPanel;
public static const objc.id class_NSPrinter;
public static const objc.id class_NSProgressIndicator;
public static const objc.id class_NSResponder;
public static const objc.id class_NSRunLoop;
public static const objc.id class_NSSavePanel;
public static const objc.id class_NSScreen;
public static const objc.id class_NSScrollView;
public static const objc.id class_NSScroller;
public static const objc.id class_NSSearchField;
public static const objc.id class_NSSecureTextField;
public static const objc.id class_NSSet;
public static const objc.id class_NSSlider;
public static const objc.id class_NSStatusBar;
public static const objc.id class_NSStatusItem;
public static const objc.id class_NSStepper;
public static const objc.id class_NSString;
public static const objc.id class_NSTabView;
public static const objc.id class_NSTabViewItem;
public static const objc.id class_NSTableColumn;
public static const objc.id class_NSTableHeaderCell;
public static const objc.id class_NSTableHeaderView;
public static const objc.id class_NSTableView;
public static const objc.id class_NSText;
public static const objc.id class_NSTextContainer;
public static const objc.id class_NSTextField;
public static const objc.id class_NSTextFieldCell;
public static const objc.id class_NSTextStorage;
public static const objc.id class_NSTextTab;
public static const objc.id class_NSTextView;
public static const objc.id class_NSThread;
public static const objc.id class_NSTimeZone;
public static const objc.id class_NSTimer;
public static const objc.id class_NSTypesetter;
public static const objc.id class_NSURL;
public static const objc.id class_NSURLDownload;
public static const objc.id class_NSURLRequest;
public static const objc.id class_NSValue;
public static const objc.id class_NSView;
public static const objc.id class_NSWindow;
public static const objc.id class_NSWorkspace;
public static const objc.id class_WebDataSource;
public static const objc.id class_WebFrame;
public static const objc.id class_WebFrameView;
public static const objc.id class_WebPreferences;
public static const objc.id class_WebView;

/** Protocols */
public static const objc.Protocol* protocol_NSAccessibility;
public static const objc.Protocol* protocol_NSAccessibilityAdditions;
public static const objc.Protocol* protocol_NSApplicationDelegate;
public static const objc.Protocol* protocol_NSApplicationNotifications;
public static const objc.Protocol* protocol_NSColorPanelResponderMethod;
public static const objc.Protocol* protocol_NSComboBoxNotifications;
public static const objc.Protocol* protocol_NSDraggingDestination;
public static const objc.Protocol* protocol_NSDraggingSource;
public static const objc.Protocol* protocol_NSFontManagerResponderMethod;
public static const objc.Protocol* protocol_NSMenuDelegate;
public static const objc.Protocol* protocol_NSOutlineViewDataSource;
public static const objc.Protocol* protocol_NSOutlineViewDelegate;
public static const objc.Protocol* protocol_NSOutlineViewNotifications;
public static const objc.Protocol* protocol_NSPasteboardOwner;
public static const objc.Protocol* protocol_NSTabViewDelegate;
public static const objc.Protocol* protocol_NSTableDataSource;
public static const objc.Protocol* protocol_NSTableViewDelegate;
public static const objc.Protocol* protocol_NSTableViewNotifications;
public static const objc.Protocol* protocol_NSTextDelegate;
public static const objc.Protocol* protocol_NSTextInput;
public static const objc.Protocol* protocol_NSTextViewDelegate;
public static const objc.Protocol* protocol_NSURLDownloadDelegate;
public static const objc.Protocol* protocol_NSWindowDelegate;
public static const objc.Protocol* protocol_NSWindowNotifications;
public static const objc.Protocol* protocol_WebDocumentRepresentation;
public static const objc.Protocol* protocol_WebFrameLoadDelegate;
public static const objc.Protocol* protocol_WebOpenPanelResultListener;
public static const objc.Protocol* protocol_WebPolicyDecisionListener;
public static const objc.Protocol* protocol_WebPolicyDelegate;
public static const objc.Protocol* protocol_WebResourceLoadDelegate;
public static const objc.Protocol* protocol_WebUIDelegate;

/** Selectors */    
public static const objc.SEL sel_DOMDocument;
public static const objc.SEL sel_IBeamCursor;
public static const objc.SEL sel_TIFFRepresentation;
public static const objc.SEL sel_URL;
public static const objc.SEL sel_URLFromPasteboard_;
public static const objc.SEL sel_URLWithString_;
public static const objc.SEL sel_UTF8String;
public static const objc.SEL sel_absoluteString;
public static const objc.SEL sel_acceptsFirstResponder;
public static const objc.SEL sel_accessibilityActionDescription_;
public static const objc.SEL sel_accessibilityActionNames;
public static const objc.SEL sel_accessibilityAttributeNames;
public static const objc.SEL sel_accessibilityAttributeValue_;
public static const objc.SEL sel_accessibilityAttributeValue_forParameter_;
public static const objc.SEL sel_accessibilityFocusedUIElement;
public static const objc.SEL sel_accessibilityHitTest_;
public static const objc.SEL sel_accessibilityIsAttributeSettable_;
public static const objc.SEL sel_accessibilityIsIgnored;
public static const objc.SEL sel_accessibilityParameterizedAttributeNames;
public static const objc.SEL sel_accessibilityPerformAction_;
public static const objc.SEL sel_accessibilitySetOverrideValue_forAttribute_;
public static const objc.SEL sel_accessibilitySetValue_forAttribute_;
public static const objc.SEL sel_action;
public static const objc.SEL sel_activateIgnoringOtherApps_;
public static const objc.SEL sel_addAttribute_value_range_;
public static const objc.SEL sel_addClip;
public static const objc.SEL sel_addEventListener_listener_useCapture_;
public static const objc.SEL sel_addIndex_;
public static const objc.SEL sel_addItem_;
public static const objc.SEL sel_addItemWithObjectValue_;
public static const objc.SEL sel_addLayoutManager_;
public static const objc.SEL sel_addObject_;
public static const objc.SEL sel_addObjectsFromArray_;
public static const objc.SEL sel_addObserver_selector_name_object_;
public static const objc.SEL sel_addRepresentation_;
public static const objc.SEL sel_addSubview_;
public static const objc.SEL sel_addSubview_positioned_relativeTo_;
public static const objc.SEL sel_addTabStop_;
public static const objc.SEL sel_addTabViewItem_;
public static const objc.SEL sel_addTableColumn_;
public static const objc.SEL sel_addTemporaryAttribute_value_forCharacterRange_;
public static const objc.SEL sel_addTextContainer_;
public static const objc.SEL sel_addTypes_owner_;
public static const objc.SEL sel_alertWithMessageText_defaultButton_alternateButton_otherButton_informativeTextWithFormat_;
public static const objc.SEL sel_alignment;
public static const objc.SEL sel_allKeys;
public static const objc.SEL sel_alloc;
public static const objc.SEL sel_allowsFloats;
public static const objc.SEL sel_alphaComponent;
public static const objc.SEL sel_alphaValue;
public static const objc.SEL sel_altKey;
public static const objc.SEL sel_alternateSelectedControlTextColor;
public static const objc.SEL sel_alwaysShowsDecimalSeparator;
public static const objc.SEL sel_appendBezierPath_;
public static const objc.SEL sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_;
public static const objc.SEL sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_clockwise_;
public static const objc.SEL sel_appendBezierPathWithGlyphs_count_inFont_;
public static const objc.SEL sel_appendBezierPathWithOvalInRect_;
public static const objc.SEL sel_appendBezierPathWithRect_;
public static const objc.SEL sel_appendBezierPathWithRoundedRect_xRadius_yRadius_;
public static const objc.SEL sel_appendString_;
public static const objc.SEL sel_applicationShouldTerminate_;
public static const objc.SEL sel_applicationWillFinishLaunching_;
public static const objc.SEL sel_applicationWillResignActive_;
public static const objc.SEL sel_applicationWillTerminate_;
public static const objc.SEL sel_archivedDataWithRootObject_;
public static const objc.SEL sel_array;
public static const objc.SEL sel_arrayWithCapacity_;
public static const objc.SEL sel_arrayWithObject_;
public static const objc.SEL sel_arrowCursor;
public static const objc.SEL sel_ascender;
public static const objc.SEL sel_attributedSubstringFromRange_;
public static const objc.SEL sel_attributesAtIndex_longestEffectiveRange_inRange_;
public static const objc.SEL sel_autorelease;
public static const objc.SEL sel_availableFontFamilies;
public static const objc.SEL sel_availableFonts;
public static const objc.SEL sel_availableMembersOfFontFamily_;
public static const objc.SEL sel_availableTypeFromArray_;
public static const objc.SEL sel_baselineOffsetInLayoutManager_glyphIndex_;
public static const objc.SEL sel_becomeFirstResponder;
public static const objc.SEL sel_beginDocument;
public static const objc.SEL sel_beginEditing;
public static const objc.SEL sel_beginPageInRect_atPlacement_;
public static const objc.SEL sel_bestRepresentationForDevice_;
public static const objc.SEL sel_bezierPath;
public static const objc.SEL sel_bezierPathByFlatteningPath;
public static const objc.SEL sel_bezierPathWithRect_;
public static const objc.SEL sel_bitmapData;
public static const objc.SEL sel_bitsPerPixel;
public static const objc.SEL sel_bitsPerSample;
public static const objc.SEL sel_blackColor;
public static const objc.SEL sel_blueComponent;
public static const objc.SEL sel_borderWidth;
public static const objc.SEL sel_boundingRectForGlyphRange_inTextContainer_;
public static const objc.SEL sel_bounds;
public static const objc.SEL sel_bundleIdentifier;
public static const objc.SEL sel_bundlePath;
public static const objc.SEL sel_bundleWithPath_;
public static const objc.SEL sel_button;
public static const objc.SEL sel_buttonNumber;
public static const objc.SEL sel_bytes;
public static const objc.SEL sel_bytesPerPlane;
public static const objc.SEL sel_bytesPerRow;
public static const objc.SEL sel_calendarDate;
public static const objc.SEL sel_canBecomeKeyWindow;
public static const objc.SEL sel_canGoBack;
public static const objc.SEL sel_canGoForward;
public static const objc.SEL sel_canShowMIMEType_;
public static const objc.SEL sel_cancel;
public static const objc.SEL sel_cancelTracking;
public static const objc.SEL sel_cascadeTopLeftFromPoint_;
public static const objc.SEL sel_cell;
public static const objc.SEL sel_cellClass;
public static const objc.SEL sel_cellSizeForBounds_;
public static const objc.SEL sel_changeColor_;
public static const objc.SEL sel_changeFont_;
public static const objc.SEL sel_charCode;
public static const objc.SEL sel_characterAtIndex_;
public static const objc.SEL sel_characterIndexForGlyphAtIndex_;
public static const objc.SEL sel_characterIndexForPoint_;
public static const objc.SEL sel_characterIsMember_;
public static const objc.SEL sel_characters;
public static const objc.SEL sel_charactersIgnoringModifiers;
public static const objc.SEL sel_chooseFilename_;
public static const objc.SEL sel_className;
public static const objc.SEL sel_cleanUpOperation;
public static const objc.SEL sel_clearColor;
public static const objc.SEL sel_clearCurrentContext;
public static const objc.SEL sel_clearGLContext;
public static const objc.SEL sel_clickCount;
public static const objc.SEL sel_clientX;
public static const objc.SEL sel_clientY;
public static const objc.SEL sel_close;
public static const objc.SEL sel_closePath;
public static const objc.SEL sel_code;
public static const objc.SEL sel_collapseItem_;
public static const objc.SEL sel_color;
public static const objc.SEL sel_colorUsingColorSpace_;
public static const objc.SEL sel_colorUsingColorSpaceName_;
public static const objc.SEL sel_colorWithDeviceRed_green_blue_alpha_;
public static const objc.SEL sel_colorWithPatternImage_;
public static const objc.SEL sel_columnAtPoint_;
public static const objc.SEL sel_columnAutoresizingStyle;
public static const objc.SEL sel_columnIndexesInRect_;
public static const objc.SEL sel_columnWithIdentifier_;
public static const objc.SEL sel_comboBoxSelectionDidChange_;
public static const objc.SEL sel_concat;
public static const objc.SEL sel_conformsToProtocol_;
public static const objc.SEL sel_containerSize;
public static const objc.SEL sel_containsObject_;
public static const objc.SEL sel_containsPoint_;
public static const objc.SEL sel_contentRect;
public static const objc.SEL sel_contentRectForFrameRect_;
public static const objc.SEL sel_contentSize;
public static const objc.SEL sel_contentSizeForFrameSize_hasHorizontalScroller_hasVerticalScroller_borderType_;
public static const objc.SEL sel_contentView;
public static const objc.SEL sel_contentViewMargins;
public static const objc.SEL sel_context;
public static const objc.SEL sel_controlDarkShadowColor;
public static const objc.SEL sel_controlHighlightColor;
public static const objc.SEL sel_controlLightHighlightColor;
public static const objc.SEL sel_controlPointBounds;
public static const objc.SEL sel_controlShadowColor;
public static const objc.SEL sel_controlTextColor;
public static const objc.SEL sel_convertBaseToScreen_;
public static const objc.SEL sel_convertPoint_fromView_;
public static const objc.SEL sel_convertPoint_toView_;
public static const objc.SEL sel_convertPointFromBase_;
public static const objc.SEL sel_convertPointToBase_;
public static const objc.SEL sel_convertRect_fromView_;
public static const objc.SEL sel_convertRect_toView_;
public static const objc.SEL sel_convertRectFromBase_;
public static const objc.SEL sel_convertRectToBase_;
public static const objc.SEL sel_convertScreenToBase_;
public static const objc.SEL sel_convertSize_fromView_;
public static const objc.SEL sel_convertSize_toView_;
public static const objc.SEL sel_convertSizeFromBase_;
public static const objc.SEL sel_convertSizeToBase_;
public static const objc.SEL sel_cookies;
public static const objc.SEL sel_copy;
public static const objc.SEL sel_copy_;
public static const objc.SEL sel_count;
public static const objc.SEL sel_createContext;
public static const objc.SEL sel_createFileAtPath_contents_attributes_;
public static const objc.SEL sel_crosshairCursor;
public static const objc.SEL sel_ctrlKey;
public static const objc.SEL sel_currentContext;
public static const objc.SEL sel_currentEditor;
public static const objc.SEL sel_currentEvent;
public static const objc.SEL sel_currentInputManager;
public static const objc.SEL sel_currentPoint;
public static const objc.SEL sel_currentRunLoop;
public static const objc.SEL sel_currentThread;
public static const objc.SEL sel_curveToPoint_controlPoint1_controlPoint2_;
public static const objc.SEL sel_cut_;
public static const objc.SEL sel_dataForType_;
public static const objc.SEL sel_dataSource;
public static const objc.SEL sel_dataWithBytes_length_;
public static const objc.SEL sel_dateValue;
public static const objc.SEL sel_dateWithCalendarFormat_timeZone_;
public static const objc.SEL sel_dateWithTimeIntervalSinceNow_;
public static const objc.SEL sel_dateWithYear_month_day_hour_minute_second_timeZone_;
public static const objc.SEL sel_dayOfMonth;
public static const objc.SEL sel_decimalDigitCharacterSet;
public static const objc.SEL sel_decimalSeparator;
public static const objc.SEL sel_declareTypes_owner_;
public static const objc.SEL sel_defaultCenter;
public static const objc.SEL sel_defaultFlatness;
public static const objc.SEL sel_defaultLineHeightForFont_;
public static const objc.SEL sel_defaultManager;
public static const objc.SEL sel_defaultPrinter;
public static const objc.SEL sel_defaultTimeZone;
public static const objc.SEL sel_deleteCookie_;
public static const objc.SEL sel_deliverResult;
public static const objc.SEL sel_deltaX;
public static const objc.SEL sel_deltaY;
public static const objc.SEL sel_depth;
public static const objc.SEL sel_descender;
public static const objc.SEL sel_description;
public static const objc.SEL sel_deselectAll_;
public static const objc.SEL sel_deselectItemAtIndex_;
public static const objc.SEL sel_deselectRow_;
public static const objc.SEL sel_destroyContext;
public static const objc.SEL sel_detail;
public static const objc.SEL sel_deviceDescription;
public static const objc.SEL sel_deviceRGBColorSpace;
public static const objc.SEL sel_dictionary;
public static const objc.SEL sel_dictionaryWithCapacity_;
public static const objc.SEL sel_dictionaryWithObject_forKey_;
public static const objc.SEL sel_disableCursorRects;
public static const objc.SEL sel_disabledControlTextColor;
public static const objc.SEL sel_displayIfNeeded;
public static const objc.SEL sel_distantFuture;
public static const objc.SEL sel_doCommandBySelector_;
public static const objc.SEL sel_documentSource;
public static const objc.SEL sel_documentView;
public static const objc.SEL sel_documentViewShouldHandlePrint;
public static const objc.SEL sel_documentVisibleRect;
public static const objc.SEL sel_doubleClickAtIndex_;
public static const objc.SEL sel_doubleValue;
public static const objc.SEL sel_download;
public static const objc.SEL sel_download_decideDestinationWithSuggestedFilename_;
public static const objc.SEL sel_dragImage_at_offset_event_pasteboard_source_slideBack_;
public static const objc.SEL sel_draggedImage;
public static const objc.SEL sel_draggedImage_beganAt_;
public static const objc.SEL sel_draggedImage_endedAt_operation_;
public static const objc.SEL sel_draggedImageLocation;
public static const objc.SEL sel_draggingDestinationWindow;
public static const objc.SEL sel_draggingEnded_;
public static const objc.SEL sel_draggingEntered_;
public static const objc.SEL sel_draggingExited_;
public static const objc.SEL sel_draggingLocation;
public static const objc.SEL sel_draggingPasteboard;
public static const objc.SEL sel_draggingSequenceNumber;
public static const objc.SEL sel_draggingSource;
public static const objc.SEL sel_draggingSourceOperationMask;
public static const objc.SEL sel_draggingSourceOperationMaskForLocal_;
public static const objc.SEL sel_draggingUpdated_;
public static const objc.SEL sel_drawAtPoint_;
public static const objc.SEL sel_drawAtPoint_fromRect_operation_fraction_;
public static const objc.SEL sel_drawBackgroundForGlyphRange_atPoint_;
public static const objc.SEL sel_drawFromPoint_toPoint_options_;
public static const objc.SEL sel_drawGlyphsForGlyphRange_atPoint_;
public static const objc.SEL sel_drawInRect_;
public static const objc.SEL sel_drawInRect_angle_;
public static const objc.SEL sel_drawInRect_fromRect_operation_fraction_;
public static const objc.SEL sel_drawInteriorWithFrame_inView_;
public static const objc.SEL sel_drawRect_;
public static const objc.SEL sel_drawSortIndicatorWithFrame_inView_ascending_priority_;
public static const objc.SEL sel_drawStatusBarBackgroundInRect_withHighlight_;
public static const objc.SEL sel_drawingRectForBounds_;
public static const objc.SEL sel_elementAtIndex_associatedPoints_;
public static const objc.SEL sel_elementCount;
public static const objc.SEL sel_enableFreedObjectCheck_;
public static const objc.SEL sel_endDocument;
public static const objc.SEL sel_endEditing;
public static const objc.SEL sel_endPage;
public static const objc.SEL sel_enumeratorAtPath_;
public static const objc.SEL sel_expandItem_;
public static const objc.SEL sel_familyName;
public static const objc.SEL sel_fieldEditor_forObject_;
public static const objc.SEL sel_fileURLWithPath_;
public static const objc.SEL sel_filename;
public static const objc.SEL sel_filenames;
public static const objc.SEL sel_fill;
public static const objc.SEL sel_fillRect_;
public static const objc.SEL sel_finishLaunching;
public static const objc.SEL sel_firstIndex;
public static const objc.SEL sel_firstRectForCharacterRange_;
public static const objc.SEL sel_firstResponder;
public static const objc.SEL sel_flagsChanged_;
public static const objc.SEL sel_flushBuffer;
public static const objc.SEL sel_flushGraphics;
public static const objc.SEL sel_font;
public static const objc.SEL sel_fontName;
public static const objc.SEL sel_fontWithName_size_;
public static const objc.SEL sel_frame;
public static const objc.SEL sel_frameOfCellAtColumn_row_;
public static const objc.SEL sel_frameRectForContentRect_;
public static const objc.SEL sel_frameSizeForContentSize_hasHorizontalScroller_hasVerticalScroller_borderType_;
public static const objc.SEL sel_fullPathForApplication_;
public static const objc.SEL sel_generalPasteboard;
public static const objc.SEL sel_getBytes_;
public static const objc.SEL sel_getBytes_length_;
public static const objc.SEL sel_getCharacters_;
public static const objc.SEL sel_getCharacters_range_;
public static const objc.SEL sel_getComponents_;
public static const objc.SEL sel_getGlyphs_range_;
public static const objc.SEL sel_getIndexes_maxCount_inIndexRange_;
public static const objc.SEL sel_getInfoForFile_application_type_;
public static const objc.SEL sel_glyphIndexForCharacterAtIndex_;
public static const objc.SEL sel_glyphIndexForPoint_inTextContainer_fractionOfDistanceThroughGlyph_;
public static const objc.SEL sel_glyphRangeForTextContainer_;
public static const objc.SEL sel_goBack;
public static const objc.SEL sel_goForward;
public static const objc.SEL sel_graphicsContext;
public static const objc.SEL sel_graphicsContextWithBitmapImageRep_;
public static const objc.SEL sel_graphicsContextWithWindow_;
public static const objc.SEL sel_greenComponent;
public static const objc.SEL sel_handleEvent_;
public static const objc.SEL sel_handleMouseEvent_;
public static const objc.SEL sel_hasAlpha;
public static const objc.SEL sel_hasMarkedText;
public static const objc.SEL sel_headerCell;
public static const objc.SEL sel_headerRectOfColumn_;
public static const objc.SEL sel_headerView;
public static const objc.SEL sel_helpRequested_;
public static const objc.SEL sel_hide_;
public static const objc.SEL sel_hideOtherApplications_;
public static const objc.SEL sel_highlightColorInView_;
public static const objc.SEL sel_highlightSelectionInClipRect_;
public static const objc.SEL sel_hitPart;
public static const objc.SEL sel_hitTest_;
public static const objc.SEL sel_hourOfDay;
public static const objc.SEL sel_iconForFile_;
public static const objc.SEL sel_iconForFileType_;
public static const objc.SEL sel_ignore;
public static const objc.SEL sel_ignoreModifierKeysWhileDragging;
public static const objc.SEL sel_imageInterpolation;
public static const objc.SEL sel_imageablePageBounds;
public static const objc.SEL sel_increment;
public static const objc.SEL sel_indentationPerLevel;
public static const objc.SEL sel_indexOfSelectedItem;
public static const objc.SEL sel_infoDictionary;
public static const objc.SEL sel_init;
public static const objc.SEL sel_initByReferencingFile_;
public static const objc.SEL sel_initListDescriptor;
public static const objc.SEL sel_initWithAttributes_;
public static const objc.SEL sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bitmapFormat_bytesPerRow_bitsPerPixel_;
public static const objc.SEL sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_;
public static const objc.SEL sel_initWithContainerSize_;
public static const objc.SEL sel_initWithContentRect_styleMask_backing_defer_;
public static const objc.SEL sel_initWithContentRect_styleMask_backing_defer_screen_;
public static const objc.SEL sel_initWithData_;
public static const objc.SEL sel_initWithDictionary_;
public static const objc.SEL sel_initWithFrame_;
public static const objc.SEL sel_initWithFrame_frameName_groupName_;
public static const objc.SEL sel_initWithFrame_pixelFormat_;
public static const objc.SEL sel_initWithFrame_pullsDown_;
public static const objc.SEL sel_initWithIdentifier_;
public static const objc.SEL sel_initWithImage_hotSpot_;
public static const objc.SEL sel_initWithIndex_;
public static const objc.SEL sel_initWithIndexesInRange_;
public static const objc.SEL sel_initWithSize_;
public static const objc.SEL sel_initWithStartingColor_endingColor_;
public static const objc.SEL sel_initWithString_;
public static const objc.SEL sel_initWithString_attributes_;
public static const objc.SEL sel_initWithTitle_;
public static const objc.SEL sel_initWithTitle_action_keyEquivalent_;
public static const objc.SEL sel_initWithTransform_;
public static const objc.SEL sel_initWithType_location_;
public static const objc.SEL sel_initWithURL_;
public static const objc.SEL sel_insertItem_atIndex_;
public static const objc.SEL sel_insertItemWithObjectValue_atIndex_;
public static const objc.SEL sel_insertTabViewItem_atIndex_;
public static const objc.SEL sel_insertText_;
public static const objc.SEL sel_intValue;
public static const objc.SEL sel_intercellSpacing;
public static const objc.SEL sel_interpretKeyEvents_;
public static const objc.SEL sel_invalidate;
public static const objc.SEL sel_invert;
public static const objc.SEL sel_isEmpty;
public static const objc.SEL sel_isEqual_;
public static const objc.SEL sel_isEqualTo_;
public static const objc.SEL sel_isEqualToString_;
public static const objc.SEL sel_isFilePackageAtPath_;
public static const objc.SEL sel_isFlipped;
public static const objc.SEL sel_isHidden;
public static const objc.SEL sel_isKeyWindow;
public static const objc.SEL sel_isKindOfClass_;
public static const objc.SEL sel_isMainThread;
public static const objc.SEL sel_isOpaque;
public static const objc.SEL sel_isPlanar;
public static const objc.SEL sel_isRowSelected_;
public static const objc.SEL sel_isRunning;
public static const objc.SEL sel_isSessionOnly;
public static const objc.SEL sel_isVisible;
public static const objc.SEL sel_itemArray;
public static const objc.SEL sel_itemAtIndex_;
public static const objc.SEL sel_itemAtRow_;
public static const objc.SEL sel_itemObjectValueAtIndex_;
public static const objc.SEL sel_itemTitleAtIndex_;
public static const objc.SEL sel_jobDisposition;
public static const objc.SEL sel_keyCode;
public static const objc.SEL sel_keyDown_;
public static const objc.SEL sel_keyEquivalent;
public static const objc.SEL sel_keyEquivalentModifierMask;
public static const objc.SEL sel_keyUp_;
public static const objc.SEL sel_keyWindow;
public static const objc.SEL sel_lastPathComponent;
public static const objc.SEL sel_leading;
public static const objc.SEL sel_length;
public static const objc.SEL sel_levelForItem_;
public static const objc.SEL sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_;
public static const objc.SEL sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_withoutAdditionalLayout_;
public static const objc.SEL sel_lineToPoint_;
public static const objc.SEL sel_loadHTMLString_baseURL_;
public static const objc.SEL sel_loadNibFile_externalNameTable_withZone_;
public static const objc.SEL sel_loadRequest_;
public static const objc.SEL sel_localizedDescription;
public static const objc.SEL sel_location;
public static const objc.SEL sel_locationForGlyphAtIndex_;
public static const objc.SEL sel_locationInWindow;
public static const objc.SEL sel_lowercaseString;
public static const objc.SEL sel_mainFrame;
public static const objc.SEL sel_mainMenu;
public static const objc.SEL sel_mainRunLoop;
public static const objc.SEL sel_mainScreen;
public static const objc.SEL sel_makeCurrentContext;
public static const objc.SEL sel_makeFirstResponder_;
public static const objc.SEL sel_makeKeyAndOrderFront_;
public static const objc.SEL sel_markedRange;
public static const objc.SEL sel_markedTextAttributes;
public static const objc.SEL sel_maxValue;
public static const objc.SEL sel_maximum;
public static const objc.SEL sel_maximumFractionDigits;
public static const objc.SEL sel_maximumIntegerDigits;
public static const objc.SEL sel_menu;
public static const objc.SEL sel_menu_willHighlightItem_;
public static const objc.SEL sel_menuDidClose_;
public static const objc.SEL sel_menuForEvent_;
public static const objc.SEL sel_menuNeedsUpdate_;
public static const objc.SEL sel_menuWillOpen_;
public static const objc.SEL sel_metaKey;
public static const objc.SEL sel_minValue;
public static const objc.SEL sel_minimum;
public static const objc.SEL sel_minimumSize;
public static const objc.SEL sel_minuteOfHour;
public static const objc.SEL sel_modifierFlags;
public static const objc.SEL sel_monthOfYear;
public static const objc.SEL sel_mouseDown_;
public static const objc.SEL sel_mouseDragged_;
public static const objc.SEL sel_mouseEntered_;
public static const objc.SEL sel_mouseExited_;
public static const objc.SEL sel_mouseLocation;
public static const objc.SEL sel_mouseLocationOutsideOfEventStream;
public static const objc.SEL sel_mouseMoved_;
public static const objc.SEL sel_mouseUp_;
public static const objc.SEL sel_moveColumn_toColumn_;
public static const objc.SEL sel_moveToBeginningOfParagraph_;
public static const objc.SEL sel_moveToEndOfParagraph_;
public static const objc.SEL sel_moveToPoint_;
public static const objc.SEL sel_moveUp_;
public static const objc.SEL sel_mutableString;
public static const objc.SEL sel_name;
public static const objc.SEL sel_namesOfPromisedFilesDroppedAtDestination_;
public static const objc.SEL sel_nextEventMatchingMask_untilDate_inMode_dequeue_;
public static const objc.SEL sel_nextObject;
public static const objc.SEL sel_nextWordFromIndex_forward_;
public static const objc.SEL sel_noteNumberOfRowsChanged;
public static const objc.SEL sel_numberOfColumns;
public static const objc.SEL sel_numberOfComponents;
public static const objc.SEL sel_numberOfGlyphs;
public static const objc.SEL sel_numberOfItems;
public static const objc.SEL sel_numberOfRows;
public static const objc.SEL sel_numberOfRowsInTableView_;
public static const objc.SEL sel_numberOfSelectedRows;
public static const objc.SEL sel_numberOfVisibleItems;
public static const objc.SEL sel_numberWithBool_;
public static const objc.SEL sel_numberWithInt_;
public static const objc.SEL sel_numberWithInteger_;
public static const objc.SEL sel_object;
public static const objc.SEL sel_objectAtIndex_;
public static const objc.SEL sel_objectEnumerator;
public static const objc.SEL sel_objectForInfoDictionaryKey_;
public static const objc.SEL sel_objectForKey_;
public static const objc.SEL sel_openFile_withApplication_;
public static const objc.SEL sel_openGLContext;
public static const objc.SEL sel_openPanel;
public static const objc.SEL sel_openURL_;
public static const objc.SEL sel_openURLs_withAppBundleIdentifier_options_additionalEventParamDescriptor_launchIdentifiers_;
public static const objc.SEL sel_options;
public static const objc.SEL sel_orderFront_;
public static const objc.SEL sel_orderFrontRegardless;
public static const objc.SEL sel_orderFrontStandardAboutPanel_;
public static const objc.SEL sel_orderOut_;
public static const objc.SEL sel_orderedWindows;
public static const objc.SEL sel_otherEventWithType_location_modifierFlags_timestamp_windowNumber_context_subtype_data1_data2_;
public static const objc.SEL sel_otherMouseDown_;
public static const objc.SEL sel_otherMouseDragged_;
public static const objc.SEL sel_otherMouseUp_;
public static const objc.SEL sel_outlineTableColumn;
public static const objc.SEL sel_outlineView_child_ofItem_;
public static const objc.SEL sel_outlineView_didClickTableColumn_;
public static const objc.SEL sel_outlineView_isItemExpandable_;
public static const objc.SEL sel_outlineView_numberOfChildrenOfItem_;
public static const objc.SEL sel_outlineView_objectValueForTableColumn_byItem_;
public static const objc.SEL sel_outlineView_setObjectValue_forTableColumn_byItem_;
public static const objc.SEL sel_outlineView_shouldCollapseItem_;
public static const objc.SEL sel_outlineView_shouldExpandItem_;
public static const objc.SEL sel_outlineView_willDisplayCell_forTableColumn_item_;
public static const objc.SEL sel_outlineViewColumnDidMove_;
public static const objc.SEL sel_outlineViewColumnDidResize_;
public static const objc.SEL sel_outlineViewItemDidExpand_;
public static const objc.SEL sel_outlineViewSelectionDidChange_;
public static const objc.SEL sel_pageDown_;
public static const objc.SEL sel_pageTitle;
public static const objc.SEL sel_pageUp_;
public static const objc.SEL sel_panelConvertFont_;
public static const objc.SEL sel_paperSize;
public static const objc.SEL sel_paragraphs;
public static const objc.SEL sel_paste_;
public static const objc.SEL sel_pasteboard_provideDataForType_;
public static const objc.SEL sel_pasteboardWithName_;
public static const objc.SEL sel_performDragOperation_;
public static const objc.SEL sel_performSelectorOnMainThread_withObject_waitUntilDone_;
public static const objc.SEL sel_pixelsHigh;
public static const objc.SEL sel_pixelsWide;
public static const objc.SEL sel_pointSize;
public static const objc.SEL sel_pointValue;
public static const objc.SEL sel_pointingHandCursor;
public static const objc.SEL sel_popUpContextMenu_withEvent_forView_;
public static const objc.SEL sel_prependTransform_;
public static const objc.SEL sel_preventDefault;
public static const objc.SEL sel_printDocumentView;
public static const objc.SEL sel_printOperationWithPrintInfo_;
public static const objc.SEL sel_printOperationWithView_printInfo_;
public static const objc.SEL sel_printPanel;
public static const objc.SEL sel_printer;
public static const objc.SEL sel_printerNames;
public static const objc.SEL sel_printerWithName_;
public static const objc.SEL sel_propertyListForType_;
public static const objc.SEL sel_rangeValue;
public static const objc.SEL sel_recentSearches;
public static const objc.SEL sel_rectOfColumn_;
public static const objc.SEL sel_rectOfRow_;
public static const objc.SEL sel_redComponent;
public static const objc.SEL sel_reflectScrolledClipView_;
public static const objc.SEL sel_registerForDraggedTypes_;
public static const objc.SEL sel_release;
public static const objc.SEL sel_reload_;
public static const objc.SEL sel_reloadData;
public static const objc.SEL sel_reloadItem_;
public static const objc.SEL sel_reloadItem_reloadChildren_;
public static const objc.SEL sel_removeAllItems;
public static const objc.SEL sel_removeAllPoints;
public static const objc.SEL sel_removeFromSuperview;
public static const objc.SEL sel_removeItem_;
public static const objc.SEL sel_removeItemAtIndex_;
public static const objc.SEL sel_removeItemAtPath_error_;
public static const objc.SEL sel_removeObject_;
public static const objc.SEL sel_removeObjectAtIndex_;
public static const objc.SEL sel_removeObserver_;
public static const objc.SEL sel_removeStatusItem_;
public static const objc.SEL sel_removeTabViewItem_;
public static const objc.SEL sel_removeTableColumn_;
public static const objc.SEL sel_removeTemporaryAttribute_forCharacterRange_;
public static const objc.SEL sel_replaceCharactersInRange_withString_;
public static const objc.SEL sel_representation;
public static const objc.SEL sel_request;
public static const objc.SEL sel_requestWithURL_;
public static const objc.SEL sel_resignFirstResponder;
public static const objc.SEL sel_resizeDownCursor;
public static const objc.SEL sel_resizeLeftCursor;
public static const objc.SEL sel_resizeLeftRightCursor;
public static const objc.SEL sel_resizeRightCursor;
public static const objc.SEL sel_resizeUpCursor;
public static const objc.SEL sel_resizeUpDownCursor;
public static const objc.SEL sel_resizingMask;
public static const objc.SEL sel_respondsToSelector_;
public static const objc.SEL sel_restoreGraphicsState;
public static const objc.SEL sel_retain;
public static const objc.SEL sel_retainCount;
public static const objc.SEL sel_rightMouseDown_;
public static const objc.SEL sel_rightMouseDragged_;
public static const objc.SEL sel_rightMouseUp_;
public static const objc.SEL sel_rotateByDegrees_;
public static const objc.SEL sel_rowAtPoint_;
public static const objc.SEL sel_rowForItem_;
public static const objc.SEL sel_rowHeight;
public static const objc.SEL sel_rowsInRect_;
public static const objc.SEL sel_run;
public static const objc.SEL sel_runModal;
public static const objc.SEL sel_runModalForWindow_;
public static const objc.SEL sel_runModalWithPrintInfo_;
public static const objc.SEL sel_runMode_beforeDate_;
public static const objc.SEL sel_runOperation;
public static const objc.SEL sel_samplesPerPixel;
public static const objc.SEL sel_saveGraphicsState;
public static const objc.SEL sel_savePanel;
public static const objc.SEL sel_scaleXBy_yBy_;
public static const objc.SEL sel_scheduledTimerWithTimeInterval_target_selector_userInfo_repeats_;
public static const objc.SEL sel_screen;
public static const objc.SEL sel_screens;
public static const objc.SEL sel_scrollColumnToVisible_;
public static const objc.SEL sel_scrollRangeToVisible_;
public static const objc.SEL sel_scrollRectToVisible_;
public static const objc.SEL sel_scrollRowToVisible_;
public static const objc.SEL sel_scrollToPoint_;
public static const objc.SEL sel_scrollWheel_;
public static const objc.SEL sel_scrollerWidth;
public static const objc.SEL sel_secondOfMinute;
public static const objc.SEL sel_secondarySelectedControlColor;
public static const objc.SEL sel_selectAll_;
public static const objc.SEL sel_selectItem_;
public static const objc.SEL sel_selectItemAtIndex_;
public static const objc.SEL sel_selectRow_byExtendingSelection_;
public static const objc.SEL sel_selectRowIndexes_byExtendingSelection_;
public static const objc.SEL sel_selectTabViewItemAtIndex_;
public static const objc.SEL sel_selectedControlTextColor;
public static const objc.SEL sel_selectedRange;
public static const objc.SEL sel_selectedRow;
public static const objc.SEL sel_selectedRowIndexes;
public static const objc.SEL sel_selectedTabViewItem;
public static const objc.SEL sel_selectedTextBackgroundColor;
public static const objc.SEL sel_selectedTextColor;
public static const objc.SEL sel_sendAction_to_;
public static const objc.SEL sel_sendEvent_;
public static const objc.SEL sel_separatorItem;
public static const objc.SEL sel_set;
public static const objc.SEL sel_setAcceptsMouseMovedEvents_;
public static const objc.SEL sel_setAction_;
public static const objc.SEL sel_setAlertStyle_;
public static const objc.SEL sel_setAlignment_;
public static const objc.SEL sel_setAllowsColumnReordering_;
public static const objc.SEL sel_setAllowsFloats_;
public static const objc.SEL sel_setAllowsMixedState_;
public static const objc.SEL sel_setAllowsMultipleSelection_;
public static const objc.SEL sel_setAlphaValue_;
public static const objc.SEL sel_setApplicationIconImage_;
public static const objc.SEL sel_setApplicationNameForUserAgent_;
public static const objc.SEL sel_setAttributedStringValue_;
public static const objc.SEL sel_setAttributedTitle_;
public static const objc.SEL sel_setAutoenablesItems_;
public static const objc.SEL sel_setAutohidesScrollers_;
public static const objc.SEL sel_setAutoresizesOutlineColumn_;
public static const objc.SEL sel_setAutoresizesSubviews_;
public static const objc.SEL sel_setAutoresizingMask_;
public static const objc.SEL sel_setAutosaveExpandedItems_;
public static const objc.SEL sel_setBackgroundColor_;
public static const objc.SEL sel_setBezelStyle_;
public static const objc.SEL sel_setBorderType_;
public static const objc.SEL sel_setBorderWidth_;
public static const objc.SEL sel_setBordered_;
public static const objc.SEL sel_setBoxType_;
public static const objc.SEL sel_setButtonType_;
public static const objc.SEL sel_setCacheMode_;
public static const objc.SEL sel_setCanChooseDirectories_;
public static const objc.SEL sel_setCanChooseFiles_;
public static const objc.SEL sel_setCellClass_;
public static const objc.SEL sel_setClip;
public static const objc.SEL sel_setColor_;
public static const objc.SEL sel_setColumnAutoresizingStyle_;
public static const objc.SEL sel_setCompositingOperation_;
public static const objc.SEL sel_setContainerSize_;
public static const objc.SEL sel_setContentView_;
public static const objc.SEL sel_setContentViewMargins_;
public static const objc.SEL sel_setCurrentContext_;
public static const objc.SEL sel_setCurrentOperation_;
public static const objc.SEL sel_setData_forType_;
public static const objc.SEL sel_setDataCell_;
public static const objc.SEL sel_setDataSource_;
public static const objc.SEL sel_setDatePickerElements_;
public static const objc.SEL sel_setDatePickerStyle_;
public static const objc.SEL sel_setDateValue_;
public static const objc.SEL sel_setDefaultFlatness_;
public static const objc.SEL sel_setDefaultTabInterval_;
public static const objc.SEL sel_setDelegate_;
public static const objc.SEL sel_setDestination_allowOverwrite_;
public static const objc.SEL sel_setDirectory_;
public static const objc.SEL sel_setDocumentView_;
public static const objc.SEL sel_setDoubleAction_;
public static const objc.SEL sel_setDoubleValue_;
public static const objc.SEL sel_setDownloadDelegate_;
public static const objc.SEL sel_setDrawsBackground_;
public static const objc.SEL sel_setEditable_;
public static const objc.SEL sel_setEnabled_;
public static const objc.SEL sel_setFill;
public static const objc.SEL sel_setFireDate_;
public static const objc.SEL sel_setFirstLineHeadIndent_;
public static const objc.SEL sel_setFloatValue_knobProportion_;
public static const objc.SEL sel_setFocusRingType_;
public static const objc.SEL sel_setFont_;
public static const objc.SEL sel_setFormatter_;
public static const objc.SEL sel_setFrame_;
public static const objc.SEL sel_setFrame_display_;
public static const objc.SEL sel_setFrameLoadDelegate_;
public static const objc.SEL sel_setFrameOrigin_;
public static const objc.SEL sel_setFrameSize_;
public static const objc.SEL sel_setHasHorizontalScroller_;
public static const objc.SEL sel_setHasShadow_;
public static const objc.SEL sel_setHasVerticalScroller_;
public static const objc.SEL sel_setHeaderCell_;
public static const objc.SEL sel_setHeaderView_;
public static const objc.SEL sel_setHidden_;
public static const objc.SEL sel_setHiddenUntilMouseMoves_;
public static const objc.SEL sel_setHighlightMode_;
public static const objc.SEL sel_setHighlighted_;
public static const objc.SEL sel_setHorizontalScroller_;
public static const objc.SEL sel_setHorizontallyResizable_;
public static const objc.SEL sel_setIdentifier_;
public static const objc.SEL sel_setImage_;
public static const objc.SEL sel_setImageAlignment_;
public static const objc.SEL sel_setImageInterpolation_;
public static const objc.SEL sel_setImagePosition_;
public static const objc.SEL sel_setImageScaling_;
public static const objc.SEL sel_setIncrement_;
public static const objc.SEL sel_setIndentationPerLevel_;
public static const objc.SEL sel_setIndeterminate_;
public static const objc.SEL sel_setJavaEnabled_;
public static const objc.SEL sel_setJobDisposition_;
public static const objc.SEL sel_setJobTitle_;
public static const objc.SEL sel_setKeyEquivalent_;
public static const objc.SEL sel_setKeyEquivalentModifierMask_;
public static const objc.SEL sel_setLabel_;
public static const objc.SEL sel_setLeaf_;
public static const objc.SEL sel_setLength_;
public static const objc.SEL sel_setLevel_;
public static const objc.SEL sel_setLineBreakMode_;
public static const objc.SEL sel_setLineCapStyle_;
public static const objc.SEL sel_setLineDash_count_phase_;
public static const objc.SEL sel_setLineFragmentPadding_;
public static const objc.SEL sel_setLineFragmentRect_forGlyphRange_usedRect_;
public static const objc.SEL sel_setLineJoinStyle_;
public static const objc.SEL sel_setLineSpacing_;
public static const objc.SEL sel_setLineWidth_;
public static const objc.SEL sel_setMarkedText_selectedRange_;
public static const objc.SEL sel_setMaxSize_;
public static const objc.SEL sel_setMaxValue_;
public static const objc.SEL sel_setMaximum_;
public static const objc.SEL sel_setMaximumFractionDigits_;
public static const objc.SEL sel_setMaximumIntegerDigits_;
public static const objc.SEL sel_setMenu_;
public static const objc.SEL sel_setMinSize_;
public static const objc.SEL sel_setMinValue_;
public static const objc.SEL sel_setMinWidth_;
public static const objc.SEL sel_setMinimum_;
public static const objc.SEL sel_setMinimumFractionDigits_;
public static const objc.SEL sel_setMinimumIntegerDigits_;
public static const objc.SEL sel_setMiterLimit_;
public static const objc.SEL sel_setNeedsDisplay_;
public static const objc.SEL sel_setNeedsDisplayInRect_;
public static const objc.SEL sel_setNumberOfVisibleItems_;
public static const objc.SEL sel_setNumberStyle_;
public static const objc.SEL sel_setObject_forKey_;
public static const objc.SEL sel_setOnMouseEntered_;
public static const objc.SEL sel_setOpaque_;
public static const objc.SEL sel_setOptions_;
public static const objc.SEL sel_setOutlineTableColumn_;
public static const objc.SEL sel_setPanelFont_isMultiple_;
public static const objc.SEL sel_setPartialStringValidationEnabled_;
public static const objc.SEL sel_setPatternPhase_;
public static const objc.SEL sel_setPixelFormat_;
public static const objc.SEL sel_setPolicyDelegate_;
public static const objc.SEL sel_setPrinter_;
public static const objc.SEL sel_setPropertyList_forType_;
public static const objc.SEL sel_setPullsDown_;
public static const objc.SEL sel_setReleasedWhenClosed_;
public static const objc.SEL sel_setResizingMask_;
public static const objc.SEL sel_setResourceLoadDelegate_;
public static const objc.SEL sel_setRichText_;
public static const objc.SEL sel_setRowHeight_;
public static const objc.SEL sel_setSelectable_;
public static const objc.SEL sel_setSelectedRange_;
public static const objc.SEL sel_setShouldAntialias_;
public static const objc.SEL sel_setShowsPrintPanel_;
public static const objc.SEL sel_setShowsProgressPanel_;
public static const objc.SEL sel_setSize_;
public static const objc.SEL sel_setState_;
public static const objc.SEL sel_setString_;
public static const objc.SEL sel_setString_forType_;
public static const objc.SEL sel_setStringValue_;
public static const objc.SEL sel_setStroke;
public static const objc.SEL sel_setSubmenu_;
public static const objc.SEL sel_setTabStops_;
public static const objc.SEL sel_setTabViewType_;
public static const objc.SEL sel_setTarget_;
public static const objc.SEL sel_setTextColor_;
public static const objc.SEL sel_setTitle_;
public static const objc.SEL sel_setTitleFont_;
public static const objc.SEL sel_setTitlePosition_;
public static const objc.SEL sel_setToolTip_;
public static const objc.SEL sel_setTransformStruct_;
public static const objc.SEL sel_setUIDelegate_;
public static const objc.SEL sel_setURL_;
public static const objc.SEL sel_setUpPrintOperationDefaultValues;
public static const objc.SEL sel_setUsesAlternatingRowBackgroundColors_;
public static const objc.SEL sel_setUsesThreadedAnimation_;
public static const objc.SEL sel_setValue_forKey_;
public static const objc.SEL sel_setValueWraps_;
public static const objc.SEL sel_setVerticalScroller_;
public static const objc.SEL sel_setView_;
public static const objc.SEL sel_setWidth_;
public static const objc.SEL sel_setWidthTracksTextView_;
public static const objc.SEL sel_setWindingRule_;
public static const objc.SEL sel_setWorksWhenModal_;
public static const objc.SEL sel_setWraps_;
public static const objc.SEL sel_sharedApplication;
public static const objc.SEL sel_sharedColorPanel;
public static const objc.SEL sel_sharedFontManager;
public static const objc.SEL sel_sharedFontPanel;
public static const objc.SEL sel_sharedHTTPCookieStorage;
public static const objc.SEL sel_sharedPrintInfo;
public static const objc.SEL sel_sharedWorkspace;
public static const objc.SEL sel_shiftKey;
public static const objc.SEL sel_size;
public static const objc.SEL sel_sizeToFit;
public static const objc.SEL sel_sizeValue;
public static const objc.SEL sel_skipDescendents;
public static const objc.SEL sel_smallSystemFontSize;
public static const objc.SEL sel_sortIndicatorRectForBounds_;
public static const objc.SEL sel_standardPreferences;
public static const objc.SEL sel_startAnimation_;
public static const objc.SEL sel_state;
public static const objc.SEL sel_statusItemWithLength_;
public static const objc.SEL sel_stop_;
public static const objc.SEL sel_stopLoading_;
public static const objc.SEL sel_string;
public static const objc.SEL sel_stringByAddingPercentEscapesUsingEncoding_;
public static const objc.SEL sel_stringByAppendingPathComponent_;
public static const objc.SEL sel_stringByAppendingString_;
public static const objc.SEL sel_stringByDeletingLastPathComponent;
public static const objc.SEL sel_stringByDeletingPathExtension;
public static const objc.SEL sel_stringByEvaluatingJavaScriptFromString_;
public static const objc.SEL sel_stringByReplacingOccurrencesOfString_withString_;
public static const objc.SEL sel_stringForObjectValue_;
public static const objc.SEL sel_stringForType_;
public static const objc.SEL sel_stringValue;
public static const objc.SEL sel_stringWithCharacters_length_;
public static const objc.SEL sel_stringWithUTF8String_;
public static const objc.SEL sel_stroke;
public static const objc.SEL sel_strokeRect_;
public static const objc.SEL sel_styleMask;
public static const objc.SEL sel_submenu;
public static const objc.SEL sel_subviews;
public static const objc.SEL sel_superclass;
public static const objc.SEL sel_superview;
public static const objc.SEL sel_systemFontOfSize_;
public static const objc.SEL sel_systemFontSize;
public static const objc.SEL sel_systemFontSizeForControlSize_;
public static const objc.SEL sel_systemStatusBar;
public static const objc.SEL sel_systemVersion;
public static const objc.SEL sel_tabStopType;
public static const objc.SEL sel_tabStops;
public static const objc.SEL sel_tabView_didSelectTabViewItem_;
public static const objc.SEL sel_tabView_willSelectTabViewItem_;
public static const objc.SEL sel_tabViewItemAtPoint_;
public static const objc.SEL sel_tableColumns;
public static const objc.SEL sel_tableView_didClickTableColumn_;
public static const objc.SEL sel_tableView_objectValueForTableColumn_row_;
public static const objc.SEL sel_tableView_setObjectValue_forTableColumn_row_;
public static const objc.SEL sel_tableView_shouldEditTableColumn_row_;
public static const objc.SEL sel_tableView_willDisplayCell_forTableColumn_row_;
public static const objc.SEL sel_tableViewColumnDidMove_;
public static const objc.SEL sel_tableViewColumnDidResize_;
public static const objc.SEL sel_tableViewSelectionDidChange_;
public static const objc.SEL sel_target;
public static const objc.SEL sel_terminate_;
public static const objc.SEL sel_textBackgroundColor;
public static const objc.SEL sel_textColor;
public static const objc.SEL sel_textContainer;
public static const objc.SEL sel_textDidChange_;
public static const objc.SEL sel_textStorage;
public static const objc.SEL sel_textView_clickedOnLink_atIndex_;
public static const objc.SEL sel_textView_willChangeSelectionFromCharacterRange_toCharacterRange_;
public static const objc.SEL sel_textViewDidChangeSelection_;
public static const objc.SEL sel_threadDictionary;
public static const objc.SEL sel_tile;
public static const objc.SEL sel_timeZone;
public static const objc.SEL sel_title;
public static const objc.SEL sel_titleCell;
public static const objc.SEL sel_titleOfSelectedItem;
public static const objc.SEL sel_titleRectForBounds_;
public static const objc.SEL sel_transform;
public static const objc.SEL sel_transformPoint_;
public static const objc.SEL sel_transformSize_;
public static const objc.SEL sel_transformStruct;
public static const objc.SEL sel_transformUsingAffineTransform_;
public static const objc.SEL sel_translateXBy_yBy_;
public static const objc.SEL sel_type;
public static const objc.SEL sel_types;
public static const objc.SEL sel_typesetter;
public static const objc.SEL sel_unarchiveObjectWithData_;
public static const objc.SEL sel_unhideAllApplications_;
public static const objc.SEL sel_unmarkText;
public static const objc.SEL sel_unregisterDraggedTypes;
public static const objc.SEL sel_use;
public static const objc.SEL sel_usedRectForTextContainer_;
public static const objc.SEL sel_userInfo;
public static const objc.SEL sel_usesAlternatingRowBackgroundColors;
public static const objc.SEL sel_validAttributesForMarkedText;
public static const objc.SEL sel_valueForKey_;
public static const objc.SEL sel_valueWithPoint_;
public static const objc.SEL sel_valueWithRange_;
public static const objc.SEL sel_valueWithRect_;
public static const objc.SEL sel_valueWithSize_;
public static const objc.SEL sel_visibleFrame;
public static const objc.SEL sel_visibleRect;
public static const objc.SEL sel_wantsPeriodicDraggingUpdates;
public static const objc.SEL sel_wantsToHandleMouseEvents;
public static const objc.SEL sel_webFrame;
public static const objc.SEL sel_webView_contextMenuItemsForElement_defaultMenuItems_;
public static const objc.SEL sel_webView_createWebViewWithRequest_;
public static const objc.SEL sel_webView_decidePolicyForMIMEType_request_frame_decisionListener_;
public static const objc.SEL sel_webView_decidePolicyForNavigationAction_request_frame_decisionListener_;
public static const objc.SEL sel_webView_decidePolicyForNewWindowAction_request_newFrameName_decisionListener_;
public static const objc.SEL sel_webView_didChangeLocationWithinPageForFrame_;
public static const objc.SEL sel_webView_didCommitLoadForFrame_;
public static const objc.SEL sel_webView_didFailProvisionalLoadWithError_forFrame_;
public static const objc.SEL sel_webView_didFinishLoadForFrame_;
public static const objc.SEL sel_webView_didReceiveTitle_forFrame_;
public static const objc.SEL sel_webView_didStartProvisionalLoadForFrame_;
public static const objc.SEL sel_webView_identifierForInitialRequest_fromDataSource_;
public static const objc.SEL sel_webView_mouseDidMoveOverElement_modifierFlags_;
public static const objc.SEL sel_webView_printFrameView_;
public static const objc.SEL sel_webView_resource_didFailLoadingWithError_fromDataSource_;
public static const objc.SEL sel_webView_resource_didFinishLoadingFromDataSource_;
public static const objc.SEL sel_webView_resource_willSendRequest_redirectResponse_fromDataSource_;
public static const objc.SEL sel_webView_runJavaScriptAlertPanelWithMessage_;
public static const objc.SEL sel_webView_runJavaScriptConfirmPanelWithMessage_;
public static const objc.SEL sel_webView_runOpenPanelForFileButtonWithResultListener_;
public static const objc.SEL sel_webView_setFrame_;
public static const objc.SEL sel_webView_setResizable_;
public static const objc.SEL sel_webView_setStatusBarVisible_;
public static const objc.SEL sel_webView_setStatusText_;
public static const objc.SEL sel_webView_setToolbarsVisible_;
public static const objc.SEL sel_webView_unableToImplementPolicyWithError_frame_;
public static const objc.SEL sel_webViewClose_;
public static const objc.SEL sel_webViewFocus_;
public static const objc.SEL sel_webViewShow_;
public static const objc.SEL sel_webViewUnfocus_;
public static const objc.SEL sel_wheelDelta;
public static const objc.SEL sel_width;
public static const objc.SEL sel_window;
public static const objc.SEL sel_windowBackgroundColor;
public static const objc.SEL sel_windowDidBecomeKey_;
public static const objc.SEL sel_windowDidMove_;
public static const objc.SEL sel_windowDidResignKey_;
public static const objc.SEL sel_windowDidResize_;
public static const objc.SEL sel_windowFrameColor;
public static const objc.SEL sel_windowFrameTextColor;
public static const objc.SEL sel_windowNumber;
public static const objc.SEL sel_windowShouldClose_;
public static const objc.SEL sel_windowWillClose_;
public static const objc.SEL sel_windows;
public static const objc.SEL sel_worksWhenModal;
public static const objc.SEL sel_wraps;
public static const objc.SEL sel_writeToPasteboard_;
public static const objc.SEL sel_yearOfCommonEra;

/** Constants */
public static const int NSAWTEventType = 16;
public static const int NSAboveBottom = 4;
public static const int NSAboveTop = 1;
public static const int NSAddTraitFontAction = 2;
public static const int NSAdobeCNS1CharacterCollection = 1;
public static const int NSAdobeGB1CharacterCollection = 2;
public static const int NSAdobeJapan1CharacterCollection = 3;
public static const int NSAdobeJapan2CharacterCollection = 4;
public static const int NSAdobeKorea1CharacterCollection = 5;
public static const Cocoa.NSInteger NSAlertAlternateReturn = 0;
public static const Cocoa.NSInteger NSAlertDefaultReturn = 1;
public static const Cocoa.NSInteger NSAlertErrorReturn = -2;
public static const Cocoa.NSInteger NSAlertFirstButtonReturn = 1000;
public static const Cocoa.NSInteger NSAlertOtherReturn = -1;
public static const Cocoa.NSInteger NSAlertSecondButtonReturn = 1001;
public static const Cocoa.NSInteger NSAlertThirdButtonReturn = 1002;
public static const int NSAllScrollerParts = 2;
alias Cocoa.NSBitmapFormat.NSAlphaFirstBitmapFormat NSAlphaFirstBitmapFormat;
alias Cocoa.NSBitmapFormat.NSAlphaNonpremultipliedBitmapFormat NSAlphaNonpremultipliedBitmapFormat;
public static const int NSAlphaShiftKeyMask = 65536;
public static const Cocoa.NSUInteger NSAlternateKeyMask = 524288;
public static const int NSAnimationBlocking = 0;
public static const int NSAnimationEaseIn = 1;
public static const int NSAnimationEaseInOut = 0;
public static const int NSAnimationEaseOut = 2;
public static const int NSAnimationEffectDisappearingItemDefault = 0;
public static const int NSAnimationEffectPoof = 10;
public static const int NSAnimationLinear = 3;
public static const int NSAnimationNonblocking = 1;
public static const int NSAnimationNonblockingThreaded = 2;
public static const int NSAnyEventMask = -1;
public static const int NSAnyType = 0;
alias Cocoa.NSEventType.NSAppKitDefined NSAppKitDefined;
public static const int NSAppKitDefinedMask = 8192;
public static const int NSAppKitVersionNumber10_0 = 577;
public static const int NSAppKitVersionNumber10_1 = 620;
public static const int NSAppKitVersionNumber10_2 = 663;
public static const double NSAppKitVersionNumber10_2_3 = 663.60000000000002;
public static const int NSAppKitVersionNumber10_3 = 743;
public static const double NSAppKitVersionNumber10_3_2 = 743.13999999999999;
public static const double NSAppKitVersionNumber10_3_3 = 743.20000000000005;
public static const double NSAppKitVersionNumber10_3_5 = 743.24000000000001;
public static const double NSAppKitVersionNumber10_3_7 = 743.33000000000004;
public static const double NSAppKitVersionNumber10_3_9 = 743.36000000000001;
public static const int NSAppKitVersionNumber10_4 = 824;
public static const double NSAppKitVersionNumberWithColumnResizingBrowser = 685.00000000000000;
public static const double NSAppKitVersionNumberWithContinuousScrollingBrowser = 680.00000000000000;
public static const double NSAppKitVersionNumberWithCursorSizeSupport = 682.00000000000000;
public static const double NSAppKitVersionNumberWithCustomSheetPosition = 686.00000000000000;
public static const double NSAppKitVersionNumberWithDirectionalTabs = 631.00000000000000;
public static const double NSAppKitVersionNumberWithPatternColorLeakFix = 641.00000000000000;
public static const int NSApplicationActivatedEventType = 1;
public static const int NSApplicationDeactivatedEventType = 2;
alias Cocoa.NSEventType.NSApplicationDefined NSApplicationDefined;
public static const int NSApplicationDefinedMask = 32768;
public static const int NSApplicationDelegateReplyCancel = 1;
public static const int NSApplicationDelegateReplyFailure = 2;
public static const int NSApplicationDelegateReplySuccess = 0;
public static const int NSAscendingPageOrder = 1;
public static const int NSAtBottom = 5;
alias Cocoa.NSTitlePosition.NSAtTop NSAtTop;
public static const int NSAttachmentCharacter = 65532;
public static const int NSAutoPagination = 0;
public static const int NSAutosaveOperation = 3;
public static const int NSBMPFileType = 1;
public static const int NSBackTabCharacter = 25;
public static const int NSBackgroundStyleDark = 1;
public static const int NSBackgroundStyleLight = 0;
public static const int NSBackgroundStyleLowered = 3;
public static const int NSBackgroundStyleRaised = 2;
public static const int NSBackgroundTab = 1;
alias Cocoa.NSBackingStoreType.NSBackingStoreBuffered NSBackingStoreBuffered;
public static const int NSBackingStoreNonretained = 1;
public static const int NSBackingStoreRetained = 0;
public static const int NSBackspaceCharacter = 8;
public static const int NSBacktabTextMovement = 18;
public static const int NSBeginFunctionKey = 63274;
public static const int NSBelowBottom = 6;
public static const int NSBelowTop = 3;
alias Cocoa.NSLineJoinStyle.NSBevelLineJoinStyle NSBevelLineJoinStyle;
alias NSBorderType.NSBezelBorder NSBezelBorder;
public static const int NSBlueControlTint = 1;
public static const int NSBoldFontMask = 2;
alias Cocoa.NSBorderlessWindowMask NSBorderlessWindowMask;
alias NSTabViewType.NSBottomTabsBezelBorder NSBottomTabsBezelBorder;
public static const int NSBoxCustom = 4;
public static const int NSBoxOldStyle = 3;
public static const int NSBoxPrimary = 0;
public static const int NSBoxSecondary = 1;
public static const NSBoxType NSBoxSeparator = 2;
public static const int NSBreakFunctionKey = 63282;
public static const int NSBrowserAutoColumnResizing = 1;
public static const int NSBrowserDropAbove = 1;
public static const int NSBrowserDropOn = 0;
public static const int NSBrowserNoColumnResizing = 0;
public static const int NSBrowserUserColumnResizing = 2;
alias Cocoa.NSLineCapStyle.NSButtLineCapStyle NSButtLineCapStyle;
public static const int NSCMYKColorSpaceModel = 2;
public static const int NSCMYKModeColorPanel = 2;
public static const int NSCancelButton = 0;
public static const int NSCancelTextMovement = 23;
public static const int NSCarriageReturnCharacter = 13;
public static const int NSCellAllowsMixedState = 16;
public static const int NSCellChangesContents = 14;
public static const int NSCellDisabled = 0;
public static const int NSCellEditable = 3;
public static const int NSCellHasImageHorizontal = 12;
public static const int NSCellHasImageOnLeftOrBottom = 13;
public static const int NSCellHasOverlappingImage = 11;
public static const int NSCellHighlighted = 5;
public static const int NSCellHitContentArea = 1;
public static const int NSCellHitEditableTextArea = 2;
public static const int NSCellHitNone = 0;
public static const int NSCellHitTrackableArea = 4;
public static const int NSCellIsBordered = 10;
public static const int NSCellIsInsetButton = 15;
public static const int NSCellLightsByBackground = 9;
public static const int NSCellLightsByContents = 6;
public static const int NSCellLightsByGray = 7;
public static const int NSCellState = 1;
public static const int NSCenterTabStopType = 2;
alias Cocoa.NSTextAlignment.NSCenterTextAlignment NSCenterTextAlignment;
public static const int NSChangeAutosaved = 4;
public static const int NSChangeBackgroundCell = 8;
public static const int NSChangeBackgroundCellMask = 8;
public static const int NSChangeCleared = 2;
public static const int NSChangeDone = 0;
public static const int NSChangeGrayCell = 4;
public static const int NSChangeGrayCellMask = 4;
public static const int NSChangeReadOtherContents = 3;
public static const int NSChangeRedone = 5;
public static const int NSChangeUndone = 1;
public static const int NSCircularBezelStyle = 7;
public static const int NSCircularSlider = 1;
public static const int NSClearControlTint = 7;
public static const int NSClearDisplayFunctionKey = 63290;
public static const int NSClearLineFunctionKey = 63289;
public static const int NSClipPagination = 2;
alias NSDatePickerStyle.NSClockAndCalendarDatePickerStyle NSClockAndCalendarDatePickerStyle;
public static const int NSClosableWindowMask = 2;
alias Cocoa.NSBezierPathElement.NSClosePathBezierPathElement NSClosePathBezierPathElement;
public static const int NSColorListModeColorPanel = 5;
public static const int NSColorPanelAllModesMask = 65535;
public static const int NSColorPanelCMYKModeMask = 4;
public static const int NSColorPanelColorListModeMask = 32;
public static const int NSColorPanelCrayonModeMask = 128;
public static const int NSColorPanelCustomPaletteModeMask = 16;
public static const int NSColorPanelGrayModeMask = 1;
public static const int NSColorPanelHSBModeMask = 8;
public static const int NSColorPanelRGBModeMask = 2;
public static const int NSColorPanelWheelModeMask = 64;
public static const int NSColorRenderingIntentAbsoluteColorimetric = 1;
public static const int NSColorRenderingIntentDefault = 0;
public static const int NSColorRenderingIntentPerceptual = 3;
public static const int NSColorRenderingIntentRelativeColorimetric = 2;
public static const int NSColorRenderingIntentSaturation = 4;
public static const Cocoa.NSUInteger NSCommandKeyMask = 1048576;
alias Cocoa.NSCompositingOperation.NSCompositeClear NSCompositeClear;
public static const int NSCompositeCopy = 1;
public static const int NSCompositeDestinationAtop = 9;
public static const int NSCompositeDestinationIn = 7;
public static const int NSCompositeDestinationOut = 8;
public static const int NSCompositeDestinationOver = 6;
public static const int NSCompositeHighlight = 12;
public static const int NSCompositePlusDarker = 11;
public static const int NSCompositePlusLighter = 13;
public static const int NSCompositeSourceAtop = 5;
public static const int NSCompositeSourceIn = 3;
public static const int NSCompositeSourceOut = 4;
alias Cocoa.NSCompositingOperation.NSCompositeSourceOver NSCompositeSourceOver;
alias Cocoa.NSCompositingOperation.NSCompositeXOR NSCompositeXOR;
public static const int NSCompressedFontMask = 512;
public static const int NSCondensedFontMask = 64;
public static const int NSContentsCellMask = 1;
public static const int NSContinuousCapacityLevelIndicatorStyle = 1;
public static const int NSControlGlyph = 16777215;
public static const Cocoa.NSUInteger NSControlKeyMask = 262144;
public static const int NSCrayonModeColorPanel = 7;
alias Cocoa.NSAlertStyle.NSCriticalAlertStyle NSCriticalAlertStyle;
public static const int NSCriticalRequest = 0;
public static const int NSCursorPointingDevice = 2;
alias Cocoa.NSEventType.NSCursorUpdate NSCursorUpdate;
public static const int NSCursorUpdateMask = 131072;
alias Cocoa.NSBezierPathElement.NSCurveToBezierPathElement NSCurveToBezierPathElement;
public static const int NSCustomPaletteModeColorPanel = 4;
public static const int NSDecimalTabStopType = 3;
public static const int NSDefaultControlTint = 0;
public static const int NSDefaultTokenStyle = 0;
public static const int NSDeleteCharFunctionKey = 63294;
public static const int NSDeleteCharacter = 127;
public static const int NSDeleteFunctionKey = 63272;
public static const int NSDeleteLineFunctionKey = 63292;
public static const int NSDescendingPageOrder = -1;
public static const int NSDeviceIndependentModifierFlagsMask = -65536;
public static const int NSDeviceNColorSpaceModel = 4;
public static const int NSDirectSelection = 0;
public static const int NSDisclosureBezelStyle = 5;
public static const int NSDiscreteCapacityLevelIndicatorStyle = 2;
public static const int NSDisplayWindowRunLoopOrdering = 600000;
public static const int NSDocModalWindowMask = 64;
public static const int NSDockWindowLevel = 20;
public static const int NSDoubleType = 6;
public static const wchar NSDownArrowFunctionKey = 63233;
public static const int NSDownTextMovement = 22;
alias Cocoa.NSDragOperation.NSDragOperationAll_Obsolete NSDragOperationAll;
alias Cocoa.NSDragOperation.NSDragOperationAll_Obsolete NSDragOperationAll_Obsolete;
alias Cocoa.NSDragOperation.NSDragOperationCopy NSDragOperationCopy;
alias Cocoa.NSDragOperation.NSDragOperationDelete NSDragOperationDelete;
alias Cocoa.NSDragOperation.NSDragOperationEvery NSDragOperationEvery;
alias Cocoa.NSDragOperation.NSDragOperationGeneric NSDragOperationGeneric;
alias Cocoa.NSDragOperation.NSDragOperationLink NSDragOperationLink;
alias Cocoa.NSDragOperation.NSDragOperationMove NSDragOperationMove;
alias Cocoa.NSDragOperation.NSDragOperationNone NSDragOperationNone;
alias Cocoa.NSDragOperation.NSDragOperationPrivate NSDragOperationPrivate;
public static const int NSDrawerClosedState = 0;
public static const int NSDrawerClosingState = 3;
public static const int NSDrawerOpenState = 2;
public static const int NSDrawerOpeningState = 1;
public static const int NSEndFunctionKey = 63275;
public static const wchar NSEnterCharacter = 3;
public static const int NSEraDatePickerElementFlag = 256;
public static const int NSEraserPointingDevice = 3;
alias Cocoa.NSWindingRule.NSEvenOddWindingRule NSEvenOddWindingRule;
public static const int NSExclude10_4ElementsIconCreationOption = 4;
public static const int NSExcludeQuickDrawElementsIconCreationOption = 2;
public static const int NSExecuteFunctionKey = 63298;
public static const int NSExpandedFontMask = 32;
public static const int NSF10FunctionKey = 63245;
public static const int NSF11FunctionKey = 63246;
public static const int NSF12FunctionKey = 63247;
public static const int NSF13FunctionKey = 63248;
public static const int NSF14FunctionKey = 63249;
public static const int NSF15FunctionKey = 63250;
public static const int NSF16FunctionKey = 63251;
public static const int NSF17FunctionKey = 63252;
public static const int NSF18FunctionKey = 63253;
public static const int NSF19FunctionKey = 63254;
public static const int NSF1FunctionKey = 63236;
public static const int NSF20FunctionKey = 63255;
public static const int NSF21FunctionKey = 63256;
public static const int NSF22FunctionKey = 63257;
public static const int NSF23FunctionKey = 63258;
public static const int NSF24FunctionKey = 63259;
public static const int NSF25FunctionKey = 63260;
public static const int NSF26FunctionKey = 63261;
public static const int NSF27FunctionKey = 63262;
public static const int NSF28FunctionKey = 63263;
public static const int NSF29FunctionKey = 63264;
public static const int NSF2FunctionKey = 63237;
public static const int NSF30FunctionKey = 63265;
public static const int NSF31FunctionKey = 63266;
public static const int NSF32FunctionKey = 63267;
public static const int NSF33FunctionKey = 63268;
public static const int NSF34FunctionKey = 63269;
public static const int NSF35FunctionKey = 63270;
public static const int NSF3FunctionKey = 63238;
public static const int NSF4FunctionKey = 63239;
public static const int NSF5FunctionKey = 63240;
public static const int NSF6FunctionKey = 63241;
public static const int NSF7FunctionKey = 63242;
public static const int NSF8FunctionKey = 63243;
public static const int NSF9FunctionKey = 63244;
public static const int NSFPCurrentField = 134;
public static const int NSFPPreviewButton = 131;
public static const int NSFPPreviewField = 128;
public static const int NSFPRevertButton = 130;
public static const int NSFPSetButton = 132;
public static const int NSFPSizeField = 129;
public static const int NSFPSizeTitle = 133;
public static const int NSFileHandlingPanelCancelButton = 0;
public static const Cocoa.NSInteger NSFileHandlingPanelOKButton = 1;
public static const int NSFindFunctionKey = 63301;
public static const int NSFindPanelActionNext = 2;
public static const int NSFindPanelActionPrevious = 3;
public static const int NSFindPanelActionReplace = 5;
public static const int NSFindPanelActionReplaceAll = 4;
public static const int NSFindPanelActionReplaceAllInSelection = 8;
public static const int NSFindPanelActionReplaceAndFind = 6;
public static const int NSFindPanelActionSelectAll = 9;
public static const int NSFindPanelActionSelectAllInSelection = 10;
public static const int NSFindPanelActionSetFindString = 7;
public static const int NSFindPanelActionShowFindPanel = 1;
public static const int NSFindPanelSubstringMatchTypeContains = 0;
public static const int NSFindPanelSubstringMatchTypeEndsWith = 3;
public static const int NSFindPanelSubstringMatchTypeFullWord = 2;
public static const int NSFindPanelSubstringMatchTypeStartsWith = 1;
public static const int NSFitPagination = 1;
public static const int NSFixedPitchFontMask = 1024;
alias Cocoa.NSEventType.NSFlagsChanged NSFlagsChanged;
public static const int NSFlagsChangedMask = 4096;
public static const int NSFloatType = 3;
public static const int NSFloatingPointSamplesBitmapFormat = 4;
public static const int NSFloatingWindowLevel = 3;
public static const int NSFocusRingAbove = 2;
public static const int NSFocusRingBelow = 1;
public static const int NSFocusRingOnly = 0;
public static const int NSFocusRingTypeDefault = 0;
public static const int NSFocusRingTypeExterior = 2;
alias Cocoa.NSFocusRingType.NSFocusRingTypeNone NSFocusRingTypeNone;
public static const int NSFontAntialiasedIntegerAdvancementsRenderingMode = 3;
public static const int NSFontAntialiasedRenderingMode = 1;
public static const int NSFontBoldTrait = 2;
public static const int NSFontClarendonSerifsClass = 1073741824;
public static const int NSFontCollectionApplicationOnlyMask = 1;
public static const int NSFontCondensedTrait = 64;
public static const int NSFontDefaultRenderingMode = 0;
public static const int NSFontExpandedTrait = 32;
public static const int NSFontFamilyClassMask = -268435456;
public static const int NSFontFreeformSerifsClass = 1879048192;
public static const int NSFontIntegerAdvancementsRenderingMode = 2;
public static const int NSFontItalicTrait = 1;
public static const int NSFontModernSerifsClass = 805306368;
public static const int NSFontMonoSpaceTrait = 1024;
public static const int NSFontOldStyleSerifsClass = 268435456;
public static const int NSFontOrnamentalsClass = -1879048192;
public static const int NSFontPanelAllEffectsModeMask = 1048320;
public static const int NSFontPanelAllModesMask = -1;
public static const int NSFontPanelCollectionModeMask = 4;
public static const int NSFontPanelDocumentColorEffectModeMask = 2048;
public static const int NSFontPanelFaceModeMask = 1;
public static const int NSFontPanelShadowEffectModeMask = 4096;
public static const int NSFontPanelSizeModeMask = 2;
public static const int NSFontPanelStandardModesMask = 65535;
public static const int NSFontPanelStrikethroughEffectModeMask = 512;
public static const int NSFontPanelTextColorEffectModeMask = 1024;
public static const int NSFontPanelUnderlineEffectModeMask = 256;
public static const int NSFontSansSerifClass = -2147483648;
public static const int NSFontScriptsClass = -1610612736;
public static const int NSFontSlabSerifsClass = 1342177280;
public static const int NSFontSymbolicClass = -1073741824;
public static const int NSFontTransitionalSerifsClass = 536870912;
public static const int NSFontUIOptimizedTrait = 4096;
public static const int NSFontUnknownClass = 0;
public static const int NSFontVerticalTrait = 2048;
public static const int NSFormFeedCharacter = 12;
public static const int NSFunctionKeyMask = 8388608;
public static const int NSGIFFileType = 2;
public static const int NSGlyphAttributeBidiLevel = 2;
public static const int NSGlyphAttributeElastic = 1;
public static const int NSGlyphAttributeInscribe = 5;
public static const int NSGlyphAttributeSoft = 0;
public static const int NSGlyphInscribeAbove = 2;
public static const int NSGlyphInscribeBase = 0;
public static const int NSGlyphInscribeBelow = 1;
public static const int NSGlyphInscribeOverBelow = 4;
public static const int NSGlyphInscribeOverstrike = 3;
public static const int NSGradientConcaveStrong = 2;
public static const int NSGradientConcaveWeak = 1;
public static const int NSGradientConvexStrong = 4;
public static const int NSGradientConvexWeak = 3;
alias Cocoa.NSGradientDrawingOptions.NSGradientDrawsAfterEndingLocation NSGradientDrawsAfterEndingLocation;
alias Cocoa.NSGradientDrawingOptions.NSGradientDrawsBeforeStartingLocation NSGradientDrawsBeforeStartingLocation;
public static const int NSGradientNone = 0;
public static const int NSGraphiteControlTint = 6;
public static const int NSGrayColorSpaceModel = 0;
public static const int NSGrayModeColorPanel = 0;
public static const int NSGrooveBorder = 3;
public static const int NSHSBModeColorPanel = 3;
public static const int NSHUDWindowMask = 8192;
public static const int NSHeavierFontAction = 5;
public static const int NSHelpButtonBezelStyle = 9;
public static const int NSHelpFunctionKey = 63302;
public static const int NSHelpKeyMask = 4194304;
public static const int NSHighlightModeMatrix = 1;
public static const int NSHomeFunctionKey = 63273;
public static const int NSHorizontalRuler = 0;
alias NSDatePickerElementFlags.NSHourMinuteDatePickerElementFlag NSHourMinuteDatePickerElementFlag;
alias NSDatePickerElementFlags.NSHourMinuteSecondDatePickerElementFlag NSHourMinuteSecondDatePickerElementFlag;
public static const int NSIdentityMappingCharacterCollection = 0;
public static const int NSIllegalTextMovement = 0;
alias Cocoa.NSCellImagePosition.NSImageAbove NSImageAbove;
alias Cocoa.NSImageAlignment.NSImageAlignBottom NSImageAlignBottom;
alias Cocoa.NSImageAlignment.NSImageAlignBottomLeft NSImageAlignBottomLeft;
alias Cocoa.NSImageAlignment.NSImageAlignBottomRight NSImageAlignBottomRight;
alias Cocoa.NSImageAlignment.NSImageAlignCenter NSImageAlignCenter;
alias Cocoa.NSImageAlignment.NSImageAlignLeft NSImageAlignLeft;
alias Cocoa.NSImageAlignment.NSImageAlignRight NSImageAlignRight;
public static const int NSImageAlignTop = 1;
public static const int NSImageAlignTopLeft = 2;
public static const int NSImageAlignTopRight = 3;
public static const int NSImageBelow = 4;
public static const int NSImageCacheAlways = 1;
public static const int NSImageCacheBySize = 2;
public static const int NSImageCacheDefault = 0;
alias Cocoa.NSImageCacheMode.NSImageCacheNever NSImageCacheNever;
public static const int NSImageCellType = 2;
public static const int NSImageFrameButton = 4;
public static const int NSImageFrameGrayBezel = 2;
public static const int NSImageFrameGroove = 3;
public static const int NSImageFrameNone = 0;
public static const int NSImageFramePhoto = 1;
alias Cocoa.NSImageInterpolation.NSImageInterpolationDefault NSImageInterpolationDefault;
alias Cocoa.NSImageInterpolation.NSImageInterpolationHigh NSImageInterpolationHigh;
alias Cocoa.NSImageInterpolation.NSImageInterpolationLow NSImageInterpolationLow;
alias Cocoa.NSImageInterpolation.NSImageInterpolationNone NSImageInterpolationNone;
alias Cocoa.NSCellImagePosition.NSImageLeft NSImageLeft;
public static const int NSImageLoadStatusCancelled = 1;
public static const int NSImageLoadStatusCompleted = 0;
public static const int NSImageLoadStatusInvalidData = 2;
public static const int NSImageLoadStatusReadError = 4;
public static const int NSImageLoadStatusUnexpectedEOF = 3;
alias Cocoa.NSCellImagePosition.NSImageOnly NSImageOnly;
alias Cocoa.NSCellImagePosition.NSImageOverlaps NSImageOverlaps;
public static const int NSImageRepLoadStatusCompleted = -6;
public static const int NSImageRepLoadStatusInvalidData = -4;
public static const int NSImageRepLoadStatusReadingHeader = -2;
public static const int NSImageRepLoadStatusUnexpectedEOF = -5;
public static const int NSImageRepLoadStatusUnknownType = -1;
public static const int NSImageRepLoadStatusWillNeedAllData = -3;
public static const int NSImageRepMatchesDevice = 0;
public static const int NSImageRight = 3;
public static const int NSImageScaleAxesIndependently = 1;
public static const int NSImageScaleNone = 2;
public static const int NSImageScaleProportionallyDown = 0;
public static const int NSImageScaleProportionallyUpOrDown = 3;
public static const int NSIndexedColorSpaceModel = 5;
alias Cocoa.NSAlertStyle.NSInformationalAlertStyle NSInformationalAlertStyle;
public static const int NSInformationalRequest = 10;
public static const int NSInsertCharFunctionKey = 63293;
public static const int NSInsertFunctionKey = 63271;
public static const int NSInsertLineFunctionKey = 63291;
public static const int NSIntType = 1;
public static const int NSItalicFontMask = 1;
public static const int NSJPEG2000FileType = 5;
public static const int NSJPEGFileType = 3;
alias Cocoa.NSTextAlignment.NSJustifiedTextAlignment NSJustifiedTextAlignment;
alias Cocoa.NSEventType.NSKeyDown NSKeyDown;
public static const int NSKeyDownMask = 1024;
alias Cocoa.NSEventType.NSKeyUp NSKeyUp;
public static const int NSKeyUpMask = 2048;
public static const int NSLABColorSpaceModel = 3;
public static const int NSLandscapeOrientation = 1;
public static const int NSLeftArrowFunctionKey = 63234;
alias Cocoa.NSEventType.NSLeftMouseDown NSLeftMouseDown;
public static const int NSLeftMouseDownMask = 2;
alias Cocoa.NSEventType.NSLeftMouseDragged NSLeftMouseDragged;
public static const int NSLeftMouseDraggedMask = 64;
alias Cocoa.NSEventType.NSLeftMouseUp NSLeftMouseUp;
public static const int NSLeftMouseUpMask = 4;
alias Cocoa.NSTextTabType.NSLeftTabStopType NSLeftTabStopType;
public static const int NSLeftTabsBezelBorder = 1;
alias Cocoa.NSTextAlignment.NSLeftTextAlignment NSLeftTextAlignment;
public static const int NSLeftTextMovement = 19;
public static const int NSLighterFontAction = 6;
public static const int NSLineBorder = 1;
public static const int NSLineBreakByCharWrapping = 1;
alias Cocoa.NSLineBreakMode.NSLineBreakByClipping NSLineBreakByClipping;
public static const int NSLineBreakByTruncatingHead = 3;
public static const int NSLineBreakByTruncatingMiddle = 5;
public static const int NSLineBreakByTruncatingTail = 4;
alias Cocoa.NSLineBreakMode.NSLineBreakByWordWrapping NSLineBreakByWordWrapping;
public static const int NSLineDoesntMove = 0;
public static const int NSLineMovesDown = 3;
public static const int NSLineMovesLeft = 1;
public static const int NSLineMovesRight = 2;
public static const int NSLineMovesUp = 4;
public static const int NSLineSeparatorCharacter = 8232;
public static const int NSLineSweepDown = 2;
public static const int NSLineSweepLeft = 0;
public static const int NSLineSweepRight = 1;
public static const int NSLineSweepUp = 3;
alias Cocoa.NSBezierPathElement.NSLineToBezierPathElement NSLineToBezierPathElement;
public static const int NSLinearSlider = 0;
public static const int NSListModeMatrix = 2;
public static const int NSMacintoshInterfaceStyle = 3;
public static const int NSMainMenuWindowLevel = 24;
public static const int NSMenuFunctionKey = 63285;
public static const int NSMiniControlSize = 2;
public static const int NSMiniaturizableWindowMask = 4;
alias Cocoa.NSLineJoinStyle.NSMiterLineJoinStyle NSMiterLineJoinStyle;
public static const int NSMixedState = -1;
public static const int NSModalPanelWindowLevel = 8;
public static const int NSModeSwitchFunctionKey = 63303;
public static const int NSMomentaryChangeButton = 5;
public static const int NSMomentaryLight = 7;
alias Cocoa.NSButtonType.NSMomentaryLightButton NSMomentaryLightButton;
public static const int NSMomentaryPushButton = 0;
public static const int NSMomentaryPushInButton = 7;
alias Cocoa.NSEventType.NSMouseEntered NSMouseEntered;
public static const int NSMouseEnteredMask = 256;
public static const int NSMouseEventSubtype = 0;
alias Cocoa.NSEventType.NSMouseExited NSMouseExited;
public static const int NSMouseExitedMask = 512;
alias Cocoa.NSEventType.NSMouseMoved NSMouseMoved;
public static const int NSMouseMovedMask = 32;
alias Cocoa.NSBezierPathElement.NSMoveToBezierPathElement NSMoveToBezierPathElement;
public static const int NSNarrowFontMask = 16;
public static const int NSNativeShortGlyphPacking = 5;
public static const int NSNaturalTextAlignment = 4;
public static const wchar NSNewlineCharacter = 10;
public static const int NSNextFunctionKey = 63296;
public static const int NSNextStepInterfaceStyle = 1;
alias NSBorderType.NSNoBorder NSNoBorder;
public static const int NSNoCellMask = 0;
public static const int NSNoFontChangeAction = 0;
alias Cocoa.NSCellImagePosition.NSNoImage NSNoImage;
public static const int NSNoInterfaceStyle = 0;
public static const int NSNoModeColorPanel = -1;
public static const int NSNoScrollerParts = 0;
public static const int NSNoTabsBezelBorder = 4;
public static const int NSNoTabsLineBorder = 5;
public static const int NSNoTabsNoBorder = 6;
alias Cocoa.NSTitlePosition.NSNoTitle NSNoTitle;
public static const int NSNoUnderlineStyle = 0;
public static const int NSNonStandardCharacterSetFontMask = 8;
alias Cocoa.NSWindingRule.NSNonZeroWindingRule NSNonZeroWindingRule;
public static const int NSNonactivatingPanelMask = 128;
public static const int NSNormalWindowLevel = 0;
public static const int NSNullCellType = 0;
public static const int NSNullGlyph = 0;
public static const int NSNumericPadKeyMask = 2097152;
public static const int NSOKButton = 1;
public static const int NSOPENGL_CURRENT_VERSION = 1;
public static const int NSOffState = 0;
public static const int NSOnOffButton = 6;
public static const int NSOnState = 1;
public static const int NSOnlyScrollerArrows = 1;
public static const int NSOpenGLCPRasterizationEnable = 221;
public static const int NSOpenGLCPStateValidation = 301;
public static const int NSOpenGLCPSurfaceOpacity = 236;
public static const int NSOpenGLCPSurfaceOrder = 235;
public static const int NSOpenGLCPSwapInterval = 222;
public static const int NSOpenGLCPSwapRectangle = 200;
public static const int NSOpenGLCPSwapRectangleEnable = 201;
public static const int NSOpenGLGOClearFormatCache = 502;
public static const int NSOpenGLGOFormatCacheSize = 501;
public static const int NSOpenGLGOResetLibrary = 504;
public static const int NSOpenGLGORetainRenderers = 503;
public static const int NSOpenGLPFAAccelerated = 73;
public static const int NSOpenGLPFAAccumSize = 14;
public static const int NSOpenGLPFAAllRenderers = 1;
public static const int NSOpenGLPFAAllowOfflineRenderers = 96;
alias Cocoa.NSOpenGLPixelFormatAttribute.NSOpenGLPFAAlphaSize NSOpenGLPFAAlphaSize;
public static const int NSOpenGLPFAAuxBuffers = 7;
public static const int NSOpenGLPFAAuxDepthStencil = 57;
public static const int NSOpenGLPFABackingStore = 76;
public static const int NSOpenGLPFAClosestPolicy = 74;
public static const int NSOpenGLPFAColorFloat = 58;
public static const int NSOpenGLPFAColorSize = 8;
public static const int NSOpenGLPFACompliant = 83;
alias Cocoa.NSOpenGLPixelFormatAttribute.NSOpenGLPFADepthSize NSOpenGLPFADepthSize;
alias Cocoa.NSOpenGLPixelFormatAttribute.NSOpenGLPFADoubleBuffer NSOpenGLPFADoubleBuffer;
public static const int NSOpenGLPFAFullScreen = 54;
public static const int NSOpenGLPFAMPSafe = 78;
public static const int NSOpenGLPFAMaximumPolicy = 52;
public static const int NSOpenGLPFAMinimumPolicy = 51;
public static const int NSOpenGLPFAMultiScreen = 81;
public static const int NSOpenGLPFAMultisample = 59;
public static const int NSOpenGLPFANoRecovery = 72;
public static const int NSOpenGLPFAOffScreen = 53;
public static const int NSOpenGLPFAPixelBuffer = 90;
public static const int NSOpenGLPFARendererID = 70;
public static const int NSOpenGLPFARobust = 75;
public static const int NSOpenGLPFASampleAlpha = 61;
alias Cocoa.NSOpenGLPixelFormatAttribute.NSOpenGLPFASampleBuffers NSOpenGLPFASampleBuffers;
alias Cocoa.NSOpenGLPixelFormatAttribute.NSOpenGLPFASamples NSOpenGLPFASamples;
public static const int NSOpenGLPFAScreenMask = 84;
public static const int NSOpenGLPFASingleRenderer = 71;
alias Cocoa.NSOpenGLPixelFormatAttribute.NSOpenGLPFAStencilSize NSOpenGLPFAStencilSize;
alias Cocoa.NSOpenGLPixelFormatAttribute.NSOpenGLPFAStereo NSOpenGLPFAStereo;
public static const int NSOpenGLPFASupersample = 60;
public static const int NSOpenGLPFAVirtualScreenCount = 128;
public static const int NSOpenGLPFAWindow = 80;
alias Cocoa.NSEventType.NSOtherMouseDown NSOtherMouseDown;
public static const int NSOtherMouseDownMask = 33554432;
alias Cocoa.NSEventType.NSOtherMouseDragged NSOtherMouseDragged;
public static const int NSOtherMouseDraggedMask = 134217728;
alias Cocoa.NSEventType.NSOtherMouseUp NSOtherMouseUp;
public static const int NSOtherMouseUpMask = 67108864;
public static const int NSOtherTextMovement = 0;
public static const int NSOutlineViewDropOnItemIndex = -1;
public static const int NSPNGFileType = 4;
public static const wchar NSPageDownFunctionKey = 63277;
public static const wchar NSPageUpFunctionKey = 63276;
public static const int NSParagraphSeparatorCharacter = 8233;
public static const int NSPathStyleNavigationBar = 1;
public static const int NSPathStylePopUp = 2;
public static const int NSPathStyleStandard = 0;
public static const int NSPatternColorSpaceModel = 6;
public static const int NSPauseFunctionKey = 63280;
public static const int NSPenLowerSideMask = 2;
public static const int NSPenPointingDevice = 1;
public static const int NSPenTipMask = 1;
public static const int NSPenUpperSideMask = 4;
alias Cocoa.NSEventType.NSPeriodic NSPeriodic;
public static const int NSPeriodicMask = 65536;
public static const int NSPlainTextTokenStyle = 1;
public static const int NSPopUpArrowAtBottom = 2;
public static const int NSPopUpArrowAtCenter = 1;
public static const int NSPopUpMenuWindowLevel = 101;
public static const int NSPopUpNoArrow = 0;
public static const int NSPortraitOrientation = 0;
public static const int NSPositiveDoubleType = 7;
public static const int NSPositiveFloatType = 4;
public static const int NSPositiveIntType = 2;
public static const int NSPosterFontMask = 256;
public static const int NSPowerOffEventType = 1;
public static const int NSPressedTab = 2;
public static const int NSPrevFunctionKey = 63295;
public static const int NSPrintFunctionKey = 63288;
public static const int NSPrintPanelShowsCopies = 1;
public static const int NSPrintPanelShowsOrientation = 8;
public static const int NSPrintPanelShowsPageRange = 2;
public static const int NSPrintPanelShowsPageSetupAccessory = 256;
public static const int NSPrintPanelShowsPaperSize = 4;
public static const int NSPrintPanelShowsPreview = 131072;
public static const int NSPrintPanelShowsScaling = 16;
public static const int NSPrintScreenFunctionKey = 63278;
public static const int NSPrinterTableError = 2;
public static const int NSPrinterTableNotFound = 1;
public static const int NSPrinterTableOK = 0;
public static const int NSPrintingCancelled = 0;
public static const int NSPrintingFailure = 3;
public static const int NSPrintingReplyLater = 2;
public static const int NSPrintingSuccess = 1;
public static const int NSProgressIndicatorBarStyle = 0;
public static const int NSProgressIndicatorPreferredAquaThickness = 12;
public static const int NSProgressIndicatorPreferredLargeThickness = 18;
public static const int NSProgressIndicatorPreferredSmallThickness = 10;
public static const int NSProgressIndicatorPreferredThickness = 14;
public static const int NSProgressIndicatorSpinningStyle = 1;
public static const int NSPushInCell = 2;
public static const int NSPushInCellMask = 2;
alias Cocoa.NSButtonType.NSPushOnPushOffButton NSPushOnPushOffButton;
public static const int NSQTMovieLoopingBackAndForthPlayback = 2;
public static const int NSQTMovieLoopingPlayback = 1;
public static const int NSQTMovieNormalPlayback = 0;
public static const int NSRGBColorSpaceModel = 1;
public static const int NSRGBModeColorPanel = 1;
alias Cocoa.NSButtonType.NSRadioButton NSRadioButton; 
public static const int NSRadioModeMatrix = 0;
public static const int NSRangeDateMode = 1;
public static const int NSRatingLevelIndicatorStyle = 3;
public static const int NSRecessedBezelStyle = 13;
public static const int NSRedoFunctionKey = 63300;
public static const int NSRegularControlSize = 0;
alias Cocoa.NSBezelStyle.NSRegularSquareBezelStyle NSRegularSquareBezelStyle;
public static const int NSRelevancyLevelIndicatorStyle = 0;
public static const int NSRemoveTraitFontAction = 7;
public static const int NSResetCursorRectsRunLoopOrdering = 700000;
public static const int NSResetFunctionKey = 63283;
public static const int NSResizableWindowMask = 8;
public static const int NSReturnTextMovement = 16;
public static const int NSRightArrowFunctionKey = 63235;
alias Cocoa.NSEventType.NSRightMouseDown NSRightMouseDown;
public static const int NSRightMouseDownMask = 8;
alias Cocoa.NSEventType.NSRightMouseDragged NSRightMouseDragged;
public static const int NSRightMouseDraggedMask = 128;
alias Cocoa.NSEventType.NSRightMouseUp NSRightMouseUp;
public static const int NSRightMouseUpMask = 16;
public static const int NSRightTabStopType = 1;
public static const int NSRightTabsBezelBorder = 3;
alias Cocoa.NSTextAlignment.NSRightTextAlignment NSRightTextAlignment;
public static const int NSRightTextMovement = 20;
alias Cocoa.NSLineCapStyle.NSRoundLineCapStyle NSRoundLineCapStyle;
alias Cocoa.NSLineJoinStyle.NSRoundLineJoinStyle NSRoundLineJoinStyle;
public static const int NSRoundRectBezelStyle = 12;
alias Cocoa.NSBezelStyle.NSRoundedBezelStyle NSRoundedBezelStyle;
public static const int NSRoundedDisclosureBezelStyle = 14;
public static const int NSRoundedTokenStyle = 2;
public static const int NSRuleEditorNestingModeCompound = 2;
public static const int NSRuleEditorNestingModeList = 1;
public static const int NSRuleEditorNestingModeSimple = 3;
public static const int NSRuleEditorNestingModeSingle = 0;
public static const int NSRuleEditorRowTypeCompound = 1;
public static const int NSRuleEditorRowTypeSimple = 0;
public static const int NSRunAbortedResponse = -1001;
public static const int NSRunContinuesResponse = -1002;
public static const int NSRunStoppedResponse = -1000;
public static const int NSSaveAsOperation = 1;
public static const int NSSaveOperation = 0;
public static const int NSSaveToOperation = 2;
alias Cocoa.NSImageScaling.NSImageScaleNone NSScaleNone;
public static const int NSScaleProportionally = 0;
public static const int NSScaleToFit = 1;
public static const int NSScreenChangedEventType = 8;
public static const int NSScreenSaverWindowLevel = 1000;
public static const int NSScrollLockFunctionKey = 63279;
alias Cocoa.NSEventType.NSScrollWheel NSScrollWheel;
public static const int NSScrollWheelMask = 4194304;
public static const int NSScrollerArrowsDefaultSetting = 0;
public static const int NSScrollerArrowsMaxEnd = 0;
public static const int NSScrollerArrowsMinEnd = 1;
public static const int NSScrollerArrowsNone = 2;
public static const int NSScrollerDecrementArrow = 1;
alias NSScrollerPart.NSScrollerDecrementLine NSScrollerDecrementLine;
alias NSScrollerPart.NSScrollerDecrementPage NSScrollerDecrementPage;
public static const int NSScrollerIncrementArrow = 0;
alias NSScrollerPart.NSScrollerIncrementLine NSScrollerIncrementLine;
alias NSScrollerPart.NSScrollerIncrementPage NSScrollerIncrementPage;
alias NSScrollerPart.NSScrollerKnob NSScrollerKnob;
public static const int NSScrollerKnobSlot = 6;
public static const int NSScrollerNoPart = 0;
public static const int NSSearchFieldClearRecentsMenuItemTag = 1002;
public static const int NSSearchFieldNoRecentsMenuItemTag = 1003;
public static const int NSSearchFieldRecentsMenuItemTag = 1001;
public static const int NSSearchFieldRecentsTitleMenuItemTag = 1000;
public static const int NSSegmentStyleAutomatic = 0;
public static const int NSSegmentStyleCapsule = 5;
public static const int NSSegmentStyleRoundRect = 3;
public static const int NSSegmentStyleRounded = 1;
public static const int NSSegmentStyleSmallSquare = 6;
public static const int NSSegmentStyleTexturedRounded = 2;
public static const int NSSegmentStyleTexturedSquare = 4;
public static const int NSSegmentSwitchTrackingMomentary = 2;
public static const int NSSegmentSwitchTrackingSelectAny = 1;
public static const int NSSegmentSwitchTrackingSelectOne = 0;
public static const int NSSelectByCharacter = 0;
public static const int NSSelectByParagraph = 2;
public static const int NSSelectByWord = 1;
public static const int NSSelectFunctionKey = 63297;
public static const int NSSelectedTab = 0;
public static const int NSSelectingNext = 1;
public static const int NSSelectingPrevious = 2;
public static const int NSSelectionAffinityDownstream = 1;
public static const int NSSelectionAffinityUpstream = 0;
public static const int NSServiceApplicationLaunchFailedError = 66561;
public static const int NSServiceApplicationNotFoundError = 66560;
public static const int NSServiceErrorMaximum = 66817;
public static const int NSServiceErrorMinimum = 66560;
public static const int NSServiceInvalidPasteboardDataError = 66563;
public static const int NSServiceMalformedServiceDictionaryError = 66564;
public static const int NSServiceMiscellaneousError = 66800;
public static const int NSServiceRequestTimedOutError = 66562;
alias Cocoa.NSBezelStyle.NSShadowlessSquareBezelStyle NSShadowlessSquareBezelStyle;
public static const Cocoa.NSUInteger NSShiftKeyMask = 131072;
public static const int NSShowControlGlyphs = 1;
public static const int NSShowInvisibleGlyphs = 2;
public static const int NSSingleDateMode = 0;
public static const int NSSingleUnderlineStyle = 1;
public static const int NSSizeDownFontAction = 4;
public static const int NSSizeUpFontAction = 3;
public static const int NSSmallCapsFontMask = 128;
public static const int NSSmallControlSize = 1;
public static const int NSSmallIconButtonBezelStyle = 2;
public static const int NSSmallSquareBezelStyle = 10;
public static const int NSSpecialPageOrder = 0;
public static const int NSSpeechImmediateBoundary = 0;
public static const int NSSpeechSentenceBoundary = 2;
public static const int NSSpeechWordBoundary = 1;
public static const int NSSpellingStateGrammarFlag = 2;
public static const int NSSpellingStateSpellingFlag = 1;
public static const int NSSplitViewDividerStyleThick = 1;
public static const int NSSplitViewDividerStyleThin = 2;
alias Cocoa.NSLineCapStyle.NSSquareLineCapStyle NSSquareLineCapStyle;
public static const int NSSquareStatusItemLength = -2;
public static const int NSStatusWindowLevel = 25;
public static const int NSStopFunctionKey = 63284;
public static const int NSStringDrawingDisableScreenFontSubstitution = 4;
public static const int NSStringDrawingOneShot = 16;
public static const int NSStringDrawingTruncatesLastVisibleLine = 32;
public static const int NSStringDrawingUsesDeviceMetrics = 8;
public static const int NSStringDrawingUsesFontLeading = 2;
public static const int NSStringDrawingUsesLineFragmentOrigin = 1;
public static const int NSSubmenuWindowLevel = 3;
alias Cocoa.NSButtonType.NSSwitchButton NSSwitchButton;
public static const int NSSysReqFunctionKey = 63281;
alias Cocoa.NSEventType.NSSystemDefined NSSystemDefined;
public static const int NSSystemDefinedMask = 16384;
public static const int NSSystemFunctionKey = 63287;
public static const int NSTIFFCompressionCCITTFAX3 = 3;
public static const int NSTIFFCompressionCCITTFAX4 = 4;
public static const int NSTIFFCompressionJPEG = 6;
public static const int NSTIFFCompressionLZW = 5;
public static const int NSTIFFCompressionNEXT = 32766;
public static const int NSTIFFCompressionNone = 1;
public static const int NSTIFFCompressionOldJPEG = 32865;
public static const int NSTIFFCompressionPackBits = 32773;
public static const int NSTIFFFileType = 0;
public static const int NSTabCharacter = 9;
public static const int NSTabTextMovement = 17;
public static const int NSTableColumnAutoresizingMask = 1;
public static const int NSTableColumnNoResizing = 0;
public static const int NSTableColumnUserResizingMask = 2;
public static const int NSTableViewDropAbove = 1;
public static const int NSTableViewDropOn = 0;
public static const int NSTableViewFirstColumnOnlyAutoresizingStyle = 5;
public static const int NSTableViewGridNone = 0;
public static const int NSTableViewLastColumnOnlyAutoresizingStyle = 4;
alias NSTableViewColumnAutoresizingStyle.NSTableViewNoColumnAutoresizing NSTableViewNoColumnAutoresizing;
public static const int NSTableViewReverseSequentialColumnAutoresizingStyle = 3;
public static const int NSTableViewSelectionHighlightStyleRegular = 0;
public static const int NSTableViewSelectionHighlightStyleSourceList = 1;
public static const int NSTableViewSequentialColumnAutoresizingStyle = 2;
public static const int NSTableViewSolidHorizontalGridLineMask = 2;
public static const int NSTableViewSolidVerticalGridLineMask = 1;
public static const int NSTableViewUniformColumnAutoresizingStyle = 1;
alias Cocoa.NSEventType.NSTabletPoint NSTabletPoint;
public static const int NSTabletPointEventSubtype = 1;
public static const int NSTabletPointMask = 8388608;
alias Cocoa.NSEventType.NSTabletProximity NSTabletProximity;
public static const int NSTabletProximityEventSubtype = 2;
public static const int NSTabletProximityMask = 16777216;
alias Cocoa.NSApplicationTerminateReply.NSTerminateCancel NSTerminateCancel;
alias Cocoa.NSApplicationTerminateReply.NSTerminateLater NSTerminateLater;
alias Cocoa.NSApplicationTerminateReply.NSTerminateNow NSTerminateNow;
public static const int NSTextBlockAbsoluteValueType = 0;
public static const int NSTextBlockBaselineAlignment = 3;
public static const int NSTextBlockBorder = 0;
public static const int NSTextBlockBottomAlignment = 2;
public static const int NSTextBlockHeight = 4;
public static const int NSTextBlockMargin = 1;
public static const int NSTextBlockMaximumHeight = 6;
public static const int NSTextBlockMaximumWidth = 2;
public static const int NSTextBlockMiddleAlignment = 1;
public static const int NSTextBlockMinimumHeight = 5;
public static const int NSTextBlockMinimumWidth = 1;
public static const int NSTextBlockPadding = -1;
public static const int NSTextBlockPercentageValueType = 1;
public static const int NSTextBlockTopAlignment = 0;
public static const int NSTextBlockWidth = 0;
public static const int NSTextCellType = 1;
alias NSDatePickerStyle.NSTextFieldAndStepperDatePickerStyle NSTextFieldAndStepperDatePickerStyle;
public static const int NSTextFieldDatePickerStyle = 2;
public static const int NSTextFieldRoundedBezel = 1;
public static const int NSTextFieldSquareBezel = 0;
public static const int NSTextListPrependEnclosingMarker = 1;
public static const int NSTextReadInapplicableDocumentTypeError = 65806;
public static const int NSTextReadWriteErrorMaximum = 66303;
public static const int NSTextReadWriteErrorMinimum = 65792;
public static const int NSTextStorageEditedAttributes = 1;
public static const int NSTextStorageEditedCharacters = 2;
public static const int NSTextTableAutomaticLayoutAlgorithm = 0;
public static const int NSTextTableFixedLayoutAlgorithm = 1;
public static const int NSTextWriteInapplicableDocumentTypeError = 66062;
public static const int NSTexturedBackgroundWindowMask = 256;
public static const int NSTexturedRoundedBezelStyle = 11;
public static const int NSTexturedSquareBezelStyle = 8;
public static const int NSThickSquareBezelStyle = 3;
public static const int NSThickerSquareBezelStyle = 4;
public static const int NSTickMarkAbove = 1;
public static const int NSTickMarkBelow = 0;
public static const int NSTickMarkLeft = 1;
public static const int NSTickMarkRight = 0;
public static const int NSTimeZoneDatePickerElementFlag = 16;
public static const int NSTitledWindowMask = 1;
public static const int NSToggleButton = 2;
public static const int NSToolbarDisplayModeDefault = 0;
public static const int NSToolbarDisplayModeIconAndLabel = 1;
public static const int NSToolbarDisplayModeIconOnly = 2;
public static const int NSToolbarDisplayModeLabelOnly = 3;
public static const int NSToolbarItemVisibilityPriorityHigh = 1000;
public static const int NSToolbarItemVisibilityPriorityLow = -1000;
public static const int NSToolbarItemVisibilityPriorityStandard = 0;
public static const int NSToolbarItemVisibilityPriorityUser = 2000;
public static const int NSToolbarSizeModeDefault = 0;
public static const int NSToolbarSizeModeRegular = 1;
public static const int NSToolbarSizeModeSmall = 2;
public static const int NSTopTabsBezelBorder = 0;
public static const int NSTornOffMenuWindowLevel = 3;
public static const int NSTrackModeMatrix = 3;
public static const int NSTrackingActiveAlways = 128;
public static const int NSTrackingActiveInActiveApp = 64;
public static const int NSTrackingActiveInKeyWindow = 32;
public static const int NSTrackingActiveWhenFirstResponder = 16;
public static const int NSTrackingAssumeInside = 256;
public static const int NSTrackingCursorUpdate = 4;
public static const int NSTrackingEnabledDuringMouseDrag = 1024;
public static const int NSTrackingInVisibleRect = 512;
public static const int NSTrackingMouseEnteredAndExited = 1;
public static const int NSTrackingMouseMoved = 2;
public static const int NSTypesetterBehavior_10_2 = 2;
public static const int NSTypesetterBehavior_10_2_WithCompatibility = 1;
public static const int NSTypesetterBehavior_10_3 = 3;
public static const int NSTypesetterBehavior_10_4 = 4;
public static const int NSTypesetterContainerBreakAction = 32;
public static const int NSTypesetterHorizontalTabAction = 4;
public static const int NSTypesetterLatestBehavior = -1;
public static const int NSTypesetterLineBreakAction = 8;
public static const int NSTypesetterOriginalBehavior = 0;
public static const int NSTypesetterParagraphBreakAction = 16;
public static const int NSTypesetterWhitespaceAction = 2;
public static const int NSTypesetterZeroAdvancementAction = 1;
public static const int NSUnboldFontMask = 4;
public static const int NSUnderlinePatternDash = 512;
public static const int NSUnderlinePatternDashDot = 768;
public static const int NSUnderlinePatternDashDotDot = 1024;
public static const int NSUnderlinePatternDot = 256;
public static const int NSUnderlinePatternSolid = 0;
public static const int NSUnderlineStyleDouble = 9;
public static const int NSUnderlineStyleNone = 0;
public static const int NSUnderlineStyleSingle = 1;
public static const int NSUnderlineStyleThick = 2;
public static const int NSUndoFunctionKey = 63299;
public static const int NSUnifiedTitleAndToolbarWindowMask = 4096;
public static const int NSUnitalicFontMask = 16777216;
public static const int NSUnknownColorSpaceModel = -1;
public static const int NSUnknownPageOrder = 2;
public static const int NSUnknownPointingDevice = 0;
public static const int NSUnscaledWindowMask = 2048;
public static const wchar NSUpArrowFunctionKey = 63232;
public static const int NSUpTextMovement = 21;
public static const int NSUpdateWindowsRunLoopOrdering = 500000;
public static const int NSUserFunctionKey = 63286;
public static const int NSUtilityWindowMask = 16;
public static const int NSVariableStatusItemLength = -1;
public static const int NSVerticalRuler = 1;
public static const int NSViaPanelFontAction = 1;
public static const int NSViewHeightSizable = 16;
public static const int NSViewMaxXMargin = 4;
public static const int NSViewMaxYMargin = 32;
public static const int NSViewMinXMargin = 1;
public static const int NSViewMinYMargin = 8;
public static const int NSViewNotSizable = 0;
public static const int NSViewWidthSizable = 2;
public static const int NSWantsBidiLevels = 4;
alias Cocoa.NSAlertStyle.NSWarningAlertStyle NSWarningAlertStyle;
public static const int NSWheelModeColorPanel = 6;
alias Cocoa.NSWindowOrderingMode.NSWindowAbove NSWindowAbove;
public static const int NSWindowBackingLocationDefault = 0;
public static const int NSWindowBackingLocationMainMemory = 2;
public static const int NSWindowBackingLocationVideoMemory = 1;
alias Cocoa.NSWindowOrderingMode.NSWindowBelow NSWindowBelow;
public static const int NSWindowCloseButton = 0;
public static const int NSWindowCollectionBehaviorCanJoinAllSpaces = 1;
public static const int NSWindowCollectionBehaviorDefault = 0;
public static const int NSWindowCollectionBehaviorMoveToActiveSpace = 2;
public static const int NSWindowDocumentIconButton = 4;
public static const int NSWindowExposedEventType = 0;
public static const int NSWindowMiniaturizeButton = 1;
public static const int NSWindowMovedEventType = 4;
public static const int NSWindowOut = 0;
public static const int NSWindowSharingNone = 0;
public static const int NSWindowSharingReadOnly = 1;
public static const int NSWindowSharingReadWrite = 2;
public static const int NSWindowToolbarButton = 3;
public static const int NSWindowZoomButton = 2;
public static const int NSWindows95InterfaceStyle = 2;
public static const int NSWorkspaceLaunchAllowingClassicStartup = 131072;
public static const int NSWorkspaceLaunchAndHide = 1048576;
public static const int NSWorkspaceLaunchAndHideOthers = 2097152;
public static const int NSWorkspaceLaunchAndPrint = 2;
public static const int NSWorkspaceLaunchAsync = 65536;
public static const int NSWorkspaceLaunchDefault = 196608;
public static const int NSWorkspaceLaunchInhibitingBackgroundOnly = 128;
public static const int NSWorkspaceLaunchNewInstance = 524288;
public static const int NSWorkspaceLaunchPreferringClassic = 262144;
public static const int NSWorkspaceLaunchWithoutActivation = 512;
public static const int NSWorkspaceLaunchWithoutAddingToRecents = 256;
public static const int NSWritingDirectionLeftToRight = 0;
public static const int NSWritingDirectionNatural = -1;
public static const int NSWritingDirectionRightToLeft = 1;
alias NSDatePickerElementFlags.NSYearMonthDatePickerElementFlag NSYearMonthDatePickerElementFlag;
alias NSDatePickerElementFlags.NSYearMonthDayDatePickerElementFlag NSYearMonthDayDatePickerElementFlag;
public static const int kCFStringEncodingUTF8 = 134217984;
public static const int NSASCIIStringEncoding = 1;
public static const int NSAdminApplicationDirectory = 4;
public static const int NSAggregateExpressionType = 14;
public static const int NSAllApplicationsDirectory = 100;
public static const int NSAllDomainsMask = 65535;
public static const int NSAllLibrariesDirectory = 101;
public static const int NSAllPredicateModifier = 1;
public static const int NSAnchoredSearch = 8;
public static const int NSAndPredicateType = 1;
public static const int NSAnyPredicateModifier = 2;
public static const int NSApplicationDirectory = 1;
public static const int NSApplicationSupportDirectory = 14;
public static const int NSArgumentEvaluationScriptError = 3;
public static const int NSArgumentsWrongScriptError = 6;
public static const int NSAtomicWrite = 1;
public static const int NSBackwardsSearch = 4;
public static const int NSBeginsWithComparison = 5;
public static const int NSBeginsWithPredicateOperatorType = 8;
public static const int NSBetweenPredicateOperatorType = 100;
public static const int NSBundleExecutableArchitectureI386 = 7;
public static const int NSBundleExecutableArchitecturePPC = 18;
public static const int NSBundleExecutableArchitecturePPC64 = 16777234;
public static const int NSBundleExecutableArchitectureX86_64 = 16777223;
public static const int NSCachesDirectory = 13;
public static const int NSCalculationDivideByZero = 4;
public static const int NSCalculationLossOfPrecision = 1;
public static const int NSCalculationNoError = 0;
public static const int NSCalculationOverflow = 3;
public static const int NSCalculationUnderflow = 2;
public static const int NSCannotCreateScriptCommandError = 10;
public static const int NSCaseInsensitivePredicateOption = 1;
public static const int NSCaseInsensitiveSearch = 1;
public static const int NSCollectorDisabledOption = 2;
public static const int NSConstantValueExpressionType = 0;
public static const int NSContainerSpecifierError = 2;
public static const int NSContainsComparison = 7;
public static const int NSContainsPredicateOperatorType = 99;
public static const int NSCoreServiceDirectory = 10;
public static const int NSCustomSelectorPredicateOperatorType = 11;
public static const int NSDateFormatterBehavior10_0 = 1000;
public static const int NSDateFormatterBehavior10_4 = 1040;
public static const int NSDateFormatterBehaviorDefault = 0;
public static const int NSDateFormatterFullStyle = 4;
public static const int NSDateFormatterLongStyle = 3;
public static const int NSDateFormatterMediumStyle = 2;
public static const int NSDateFormatterNoStyle = 0;
public static const int NSDateFormatterShortStyle = 1;
public static const int NSDayCalendarUnit = 16;
public static const int NSDecimalMaxSize = 8;
public static const int NSDecimalNoScale = 32767;
public static const int NSDemoApplicationDirectory = 2;
public static const int NSDesktopDirectory = 12;
public static const int NSDeveloperApplicationDirectory = 3;
public static const int NSDeveloperDirectory = 6;
public static const int NSDiacriticInsensitivePredicateOption = 2;
public static const int NSDiacriticInsensitiveSearch = 128;
public static const int NSDirectPredicateModifier = 0;
public static const int NSDocumentDirectory = 9;
public static const int NSDocumentationDirectory = 8;
public static const int NSDownloadsDirectory = 15;
public static const int NSEndsWithComparison = 6;
public static const int NSEndsWithPredicateOperatorType = 9;
public static const int NSEqualToComparison = 0;
public static const int NSEqualToPredicateOperatorType = 4;
public static const int NSEraCalendarUnit = 2;
public static const int NSEvaluatedObjectExpressionType = 1;
public static const int NSEverySubelement = 1;
public static const int NSExecutableArchitectureMismatchError = 3585;
public static const int NSExecutableErrorMaximum = 3839;
public static const int NSExecutableErrorMinimum = 3584;
public static const int NSExecutableLinkError = 3588;
public static const int NSExecutableLoadError = 3587;
public static const int NSExecutableNotLoadableError = 3584;
public static const int NSExecutableRuntimeMismatchError = 3586;
public static const int NSFileErrorMaximum = 1023;
public static const int NSFileErrorMinimum = 0;
public static const int NSFileLockingError = 255;
public static const int NSFileNoSuchFileError = 4;
public static const int NSFileReadCorruptFileError = 259;
public static const int NSFileReadInapplicableStringEncodingError = 261;
public static const int NSFileReadInvalidFileNameError = 258;
public static const int NSFileReadNoPermissionError = 257;
public static const int NSFileReadNoSuchFileError = 260;
public static const int NSFileReadTooLargeError = 263;
public static const int NSFileReadUnknownError = 256;
public static const int NSFileReadUnknownStringEncodingError = 264;
public static const int NSFileReadUnsupportedSchemeError = 262;
public static const int NSFileWriteInapplicableStringEncodingError = 517;
public static const int NSFileWriteInvalidFileNameError = 514;
public static const int NSFileWriteNoPermissionError = 513;
public static const int NSFileWriteOutOfSpaceError = 640;
public static const int NSFileWriteUnknownError = 512;
public static const int NSFileWriteUnsupportedSchemeError = 518;
public static const int NSForcedOrderingSearch = 512;
public static const int NSFormattingError = 2048;
public static const int NSFormattingErrorMaximum = 2559;
public static const int NSFormattingErrorMinimum = 2048;
public static const double NSFoundationVersionNumber10_0 = 397.39999999999998;
public static const double NSFoundationVersionNumber10_1 = 425.00000000000000;
public static const double NSFoundationVersionNumber10_1_1 = 425.00000000000000;
public static const double NSFoundationVersionNumber10_1_2 = 425.00000000000000;
public static const double NSFoundationVersionNumber10_1_3 = 425.00000000000000;
public static const double NSFoundationVersionNumber10_1_4 = 425.00000000000000;
public static const double NSFoundationVersionNumber10_2 = 462.00000000000000;
public static const double NSFoundationVersionNumber10_2_1 = 462.00000000000000;
public static const double NSFoundationVersionNumber10_2_2 = 462.00000000000000;
public static const double NSFoundationVersionNumber10_2_3 = 462.00000000000000;
public static const double NSFoundationVersionNumber10_2_4 = 462.00000000000000;
public static const double NSFoundationVersionNumber10_2_5 = 462.00000000000000;
public static const double NSFoundationVersionNumber10_2_6 = 462.00000000000000;
public static const double NSFoundationVersionNumber10_2_7 = 462.69999999999999;
public static const double NSFoundationVersionNumber10_2_8 = 462.69999999999999;
public static const double NSFoundationVersionNumber10_3 = 500.00000000000000;
public static const double NSFoundationVersionNumber10_3_1 = 500.00000000000000;
public static const double NSFoundationVersionNumber10_3_2 = 500.30000000000001;
public static const double NSFoundationVersionNumber10_3_3 = 500.54000000000002;
public static const double NSFoundationVersionNumber10_3_4 = 500.56000000000000;
public static const double NSFoundationVersionNumber10_3_5 = 500.56000000000000;
public static const double NSFoundationVersionNumber10_3_6 = 500.56000000000000;
public static const double NSFoundationVersionNumber10_3_7 = 500.56000000000000;
public static const double NSFoundationVersionNumber10_3_8 = 500.56000000000000;
public static const double NSFoundationVersionNumber10_3_9 = 500.57999999999998;
public static const double NSFoundationVersionNumber10_4 = 567.00000000000000;
public static const double NSFoundationVersionNumber10_4_1 = 567.00000000000000;
public static const double NSFoundationVersionNumber10_4_10 = 567.28999999999996;
public static const double NSFoundationVersionNumber10_4_11 = 567.36000000000001;
public static const double NSFoundationVersionNumber10_4_2 = 567.12000000000000;
public static const double NSFoundationVersionNumber10_4_3 = 567.21000000000004;
public static const double NSFoundationVersionNumber10_4_4_Intel = 567.23000000000002;
public static const double NSFoundationVersionNumber10_4_4_PowerPC = 567.21000000000004;
public static const double NSFoundationVersionNumber10_4_5 = 567.25000000000000;
public static const double NSFoundationVersionNumber10_4_6 = 567.25999999999999;
public static const double NSFoundationVersionNumber10_4_7 = 567.26999999999998;
public static const double NSFoundationVersionNumber10_4_8 = 567.27999999999997;
public static const double NSFoundationVersionNumber10_4_9 = 567.28999999999996;
public static const int NSFoundationVersionWithFileManagerResourceForkSupport = 412;
public static const int NSFunctionExpressionType = 4;
public static const int NSGreaterThanComparison = 4;
public static const int NSGreaterThanOrEqualToComparison = 3;
public static const int NSGreaterThanOrEqualToPredicateOperatorType = 3;
public static const int NSGreaterThanPredicateOperatorType = 2;
public static const int NSHPUXOperatingSystem = 4;
public static const int NSHTTPCookieAcceptPolicyAlways = 0;
public static const int NSHTTPCookieAcceptPolicyNever = 1;
public static const int NSHTTPCookieAcceptPolicyOnlyFromMainDocumentDomain = 2;
public static const int NSHashTableCopyIn = 65536;
public static const int NSHashTableObjectPointerPersonality = 512;
public static const int NSHashTableStrongMemory = 0;
public static const int NSHashTableZeroingWeakMemory = 1;
public static const int NSHourCalendarUnit = 32;
public static const int NSINTEGER_DEFINED = 1;
public static const int NSISO2022JPStringEncoding = 21;
public static const int NSISOLatin1StringEncoding = 5;
public static const int NSISOLatin2StringEncoding = 9;
public static const int NSInPredicateOperatorType = 10;
public static const int NSIndexSubelement = 0;
public static const int NSIntegerMax = 2147483647;
public static const int NSIntegerMin = -2147483648;
public static const int NSInternalScriptError = 8;
public static const int NSInternalSpecifierError = 5;
public static const int NSIntersectSetExpressionType = 6;
public static const int NSInvalidIndexSpecifierError = 4;
public static const int NSJapaneseEUCStringEncoding = 3;
public static const int NSKeyPathExpressionType = 3;
public static const int NSKeySpecifierEvaluationScriptError = 2;
public static const int NSKeyValueChangeInsertion = 2;
public static const int NSKeyValueChangeRemoval = 3;
public static const int NSKeyValueChangeReplacement = 4;
public static const int NSKeyValueChangeSetting = 1;
public static const int NSKeyValueIntersectSetMutation = 3;
public static const int NSKeyValueMinusSetMutation = 2;
public static const int NSKeyValueObservingOptionInitial = 4;
public static const int NSKeyValueObservingOptionNew = 1;
public static const int NSKeyValueObservingOptionOld = 2;
public static const int NSKeyValueObservingOptionPrior = 8;
public static const int NSKeyValueSetSetMutation = 4;
public static const int NSKeyValueUnionSetMutation = 1;
public static const int NSKeyValueValidationError = 1024;
public static const int NSLessThanComparison = 2;
public static const int NSLessThanOrEqualToComparison = 1;
public static const int NSLessThanOrEqualToPredicateOperatorType = 1;
public static const int NSLessThanPredicateOperatorType = 0;
public static const int NSLibraryDirectory = 5;
public static const int NSLikePredicateOperatorType = 7;
public static const int NSLiteralSearch = 2;
public static const int NSLocalDomainMask = 2;
public static const int NSMACHOperatingSystem = 5;
public static const int NSMacOSRomanStringEncoding = 30;
public static const int NSMachPortDeallocateNone = 0;
public static const int NSMachPortDeallocateReceiveRight = 2;
public static const int NSMachPortDeallocateSendRight = 1;
public static const int NSMapTableCopyIn = 65536;
public static const int NSMapTableObjectPointerPersonality = 512;
public static const int NSMapTableStrongMemory = 0;
public static const int NSMapTableZeroingWeakMemory = 1;
public static const int NSMappedRead = 1;
public static const int NSMatchesPredicateOperatorType = 6;
public static const int NSMaxXEdge = 2;
public static const int NSMaxYEdge = 3;
public static const int NSMiddleSubelement = 2;
public static const int NSMinXEdge = 0;
public static const int NSMinYEdge = 1;
public static const int NSMinusSetExpressionType = 7;
public static const int NSMinuteCalendarUnit = 64;
public static const int NSMonthCalendarUnit = 8;
public static const int NSNEXTSTEPStringEncoding = 2;
public static const int NSNetServiceNoAutoRename = 1;
public static const int NSNetServicesActivityInProgress = -72003;
public static const int NSNetServicesBadArgumentError = -72004;
public static const int NSNetServicesCancelledError = -72005;
public static const int NSNetServicesCollisionError = -72001;
public static const int NSNetServicesInvalidError = -72006;
public static const int NSNetServicesNotFoundError = -72002;
public static const int NSNetServicesTimeoutError = -72007;
public static const int NSNetServicesUnknownError = -72000;
public static const int NSNetworkDomainMask = 4;
public static const int NSNoScriptError = 0;
public static const int NSNoSpecifierError = 0;
public static const int NSNoSubelement = 4;
public static const int NSNoTopLevelContainersSpecifierError = 1;
public static const int NSNonLossyASCIIStringEncoding = 7;
public static const int NSNotEqualToPredicateOperatorType = 5;
alias Cocoa.NSNotFound NSNotFound;
public static const int NSNotPredicateType = 0;
public static const int NSNotificationCoalescingOnName = 1;
public static const int NSNotificationCoalescingOnSender = 2;
public static const int NSNotificationDeliverImmediately = 1;
public static const int NSNotificationNoCoalescing = 0;
public static const int NSNotificationPostToAllSessions = 2;
public static const int NSNotificationSuspensionBehaviorCoalesce = 2;
public static const int NSNotificationSuspensionBehaviorDeliverImmediately = 4;
public static const int NSNotificationSuspensionBehaviorDrop = 1;
public static const int NSNotificationSuspensionBehaviorHold = 3;
public static const int NSNumberFormatterBehavior10_0 = 1000;
public static const int NSNumberFormatterBehavior10_4 = 1040;
public static const int NSNumberFormatterBehaviorDefault = 0;
public static const int NSNumberFormatterCurrencyStyle = 2;
alias NSNumberFormatterStyle.NSNumberFormatterDecimalStyle NSNumberFormatterDecimalStyle;
public static const int NSNumberFormatterNoStyle = 0;
public static const int NSNumberFormatterPadAfterPrefix = 1;
public static const int NSNumberFormatterPadAfterSuffix = 3;
public static const int NSNumberFormatterPadBeforePrefix = 0;
public static const int NSNumberFormatterPadBeforeSuffix = 2;
public static const int NSNumberFormatterPercentStyle = 3;
public static const int NSNumberFormatterRoundCeiling = 0;
public static const int NSNumberFormatterRoundDown = 2;
public static const int NSNumberFormatterRoundFloor = 1;
public static const int NSNumberFormatterRoundHalfDown = 5;
public static const int NSNumberFormatterRoundHalfEven = 4;
public static const int NSNumberFormatterRoundHalfUp = 6;
public static const int NSNumberFormatterRoundUp = 3;
public static const int NSNumberFormatterScientificStyle = 4;
public static const int NSNumberFormatterSpellOutStyle = 5;
public static const int NSNumericSearch = 64;
public static const int NSOSF1OperatingSystem = 7;
public static const int NSObjCArrayType = 91;
public static const int NSObjCBitfield = 98;
public static const int NSObjCBoolType = 66;
public static const int NSObjCCharType = 99;
public static const int NSObjCDoubleType = 100;
public static const int NSObjCFloatType = 102;
public static const int NSObjCLongType = 108;
public static const int NSObjCLonglongType = 113;
public static const int NSObjCNoType = 0;
public static const int NSObjCObjectType = 64;
public static const int NSObjCPointerType = 94;
public static const int NSObjCSelectorType = 58;
public static const int NSObjCShortType = 115;
public static const int NSObjCStringType = 42;
public static const int NSObjCStructType = 123;
public static const int NSObjCUnionType = 40;
public static const int NSObjCVoidType = 118;
public static const int NSObjectAutoreleasedEvent = 3;
public static const int NSObjectExtraRefDecrementedEvent = 5;
public static const int NSObjectExtraRefIncrementedEvent = 4;
public static const int NSObjectInternalRefDecrementedEvent = 7;
public static const int NSObjectInternalRefIncrementedEvent = 6;
public static const int NSOpenStepUnicodeReservedBase = 62464;
public static const int NSOperationNotSupportedForKeyScriptError = 9;
public static const int NSOperationNotSupportedForKeySpecifierError = 6;
public static const int NSOperationQueueDefaultMaxConcurrentOperationCount = -1;
public static const int NSOperationQueuePriorityHigh = 4;
public static const int NSOperationQueuePriorityLow = -4;
public static const int NSOperationQueuePriorityNormal = 0;
public static const int NSOperationQueuePriorityVeryHigh = 8;
public static const int NSOperationQueuePriorityVeryLow = -8;
public static const int NSOrPredicateType = 2;
public static const int NSOrderedAscending = -1;
public static const int NSOrderedDescending = 1;
public static const int NSOrderedSame = 0;
public static const int NSPointerFunctionsCStringPersonality = 768;
public static const int NSPointerFunctionsCopyIn = 65536;
public static const int NSPointerFunctionsIntegerPersonality = 1280;
public static const int NSPointerFunctionsMachVirtualMemory = 4;
public static const int NSPointerFunctionsMallocMemory = 3;
public static const int NSPointerFunctionsObjectPersonality = 0;
public static const int NSPointerFunctionsObjectPointerPersonality = 512;
public static const int NSPointerFunctionsOpaqueMemory = 2;
public static const int NSPointerFunctionsOpaquePersonality = 256;
public static const int NSPointerFunctionsStrongMemory = 0;
public static const int NSPointerFunctionsStructPersonality = 1024;
public static const int NSPointerFunctionsZeroingWeakMemory = 1;
public static const int NSPositionAfter = 0;
public static const int NSPositionBefore = 1;
public static const int NSPositionBeginning = 2;
public static const int NSPositionEnd = 3;
public static const int NSPositionReplace = 4;
public static const int NSPostASAP = 2;
public static const int NSPostNow = 3;
public static const int NSPostWhenIdle = 1;
public static const int NSPropertyListBinaryFormat_v1_0 = 200;
public static const int NSPropertyListImmutable = 0;
public static const int NSPropertyListMutableContainers = 1;
public static const int NSPropertyListMutableContainersAndLeaves = 2;
public static const int NSPropertyListOpenStepFormat = 1;
public static const int NSPropertyListXMLFormat_v1_0 = 100;
public static const int NSRandomSubelement = 3;
public static const int NSReceiverEvaluationScriptError = 1;
public static const int NSReceiversCantHandleCommandScriptError = 4;
public static const int NSRelativeAfter = 0;
public static const int NSRelativeBefore = 1;
public static const int NSRequiredArgumentsMissingScriptError = 5;
public static const int NSRoundBankers = 3;
public static const int NSRoundDown = 1;
public static const int NSRoundPlain = 0;
public static const int NSRoundUp = 2;
public static const int NSSaveOptionsAsk = 2;
public static const int NSSaveOptionsNo = 1;
public static const int NSSaveOptionsYes = 0;
public static const int NSScannedOption = 1;
public static const int NSSecondCalendarUnit = 128;
public static const int NSShiftJISStringEncoding = 8;
public static const int NSSolarisOperatingSystem = 3;
public static const int NSStreamEventEndEncountered = 16;
public static const int NSStreamEventErrorOccurred = 8;
public static const int NSStreamEventHasBytesAvailable = 2;
public static const int NSStreamEventHasSpaceAvailable = 4;
public static const int NSStreamEventNone = 0;
public static const int NSStreamEventOpenCompleted = 1;
public static const int NSStreamStatusAtEnd = 5;
public static const int NSStreamStatusClosed = 6;
public static const int NSStreamStatusError = 7;
public static const int NSStreamStatusNotOpen = 0;
public static const int NSStreamStatusOpen = 2;
public static const int NSStreamStatusOpening = 1;
public static const int NSStreamStatusReading = 3;
public static const int NSStreamStatusWriting = 4;
public static const int NSStringEncodingConversionAllowLossy = 1;
public static const int NSStringEncodingConversionExternalRepresentation = 2;
public static const int NSSubqueryExpressionType = 13;
public static const int NSSunOSOperatingSystem = 6;
public static const int NSSymbolStringEncoding = 6;
public static const int NSSystemDomainMask = 8;
public static const double NSTimeIntervalSince1970 = 978307200.00000000;
public static const int NSTimeZoneNameStyleDaylightSaving = 2;
public static const int NSTimeZoneNameStyleShortDaylightSaving = 3;
public static const int NSTimeZoneNameStyleShortStandard = 1;
public static const int NSTimeZoneNameStyleStandard = 0;
public static const long NSUIntegerMax = 4294967295L;
public static const int NSURLCacheStorageAllowed = 0;
public static const int NSURLCacheStorageAllowedInMemoryOnly = 1;
public static const int NSURLCacheStorageNotAllowed = 2;
public static const int NSURLCredentialPersistenceForSession = 1;
public static const int NSURLCredentialPersistenceNone = 0;
public static const int NSURLCredentialPersistencePermanent = 2;
public static const int NSURLErrorBadServerResponse = -1011;
public static const int NSURLErrorBadURL = -1000;
public static const int NSURLErrorCancelled = -999;
public static const int NSURLErrorCannotCloseFile = -3002;
public static const int NSURLErrorCannotConnectToHost = -1004;
public static const int NSURLErrorCannotCreateFile = -3000;
public static const int NSURLErrorCannotDecodeContentData = -1016;
public static const int NSURLErrorCannotDecodeRawData = -1015;
public static const int NSURLErrorCannotFindHost = -1003;
public static const int NSURLErrorCannotLoadFromNetwork = -2000;
public static const int NSURLErrorCannotMoveFile = -3005;
public static const int NSURLErrorCannotOpenFile = -3001;
public static const int NSURLErrorCannotParseResponse = -1017;
public static const int NSURLErrorCannotRemoveFile = -3004;
public static const int NSURLErrorCannotWriteToFile = -3003;
public static const int NSURLErrorClientCertificateRejected = -1205;
public static const int NSURLErrorDNSLookupFailed = -1006;
public static const int NSURLErrorDataLengthExceedsMaximum = -1103;
public static const int NSURLErrorDownloadDecodingFailedMidStream = -3006;
public static const int NSURLErrorDownloadDecodingFailedToComplete = -3007;
public static const int NSURLErrorFileDoesNotExist = -1100;
public static const int NSURLErrorFileIsDirectory = -1101;
public static const int NSURLErrorHTTPTooManyRedirects = -1007;
public static const int NSURLErrorNetworkConnectionLost = -1005;
public static const int NSURLErrorNoPermissionsToReadFile = -1102;
public static const int NSURLErrorNotConnectedToInternet = -1009;
public static const int NSURLErrorRedirectToNonExistentLocation = -1010;
public static const int NSURLErrorResourceUnavailable = -1008;
public static const int NSURLErrorSecureConnectionFailed = -1200;
public static const int NSURLErrorServerCertificateHasBadDate = -1201;
public static const int NSURLErrorServerCertificateHasUnknownRoot = -1203;
public static const int NSURLErrorServerCertificateNotYetValid = -1204;
public static const int NSURLErrorServerCertificateUntrusted = -1202;
public static const int NSURLErrorTimedOut = -1001;
public static const int NSURLErrorUnknown = -1;
public static const int NSURLErrorUnsupportedURL = -1002;
public static const int NSURLErrorUserAuthenticationRequired = -1013;
public static const int NSURLErrorUserCancelledAuthentication = -1012;
public static const int NSURLErrorZeroByteResource = -1014;
public static const int NSURLHandleLoadFailed = 3;
public static const int NSURLHandleLoadInProgress = 2;
public static const int NSURLHandleLoadSucceeded = 1;
public static const int NSURLHandleNotLoaded = 0;
public static const int NSURLRequestReloadIgnoringCacheData = 1;
public static const int NSURLRequestReloadIgnoringLocalAndRemoteCacheData = 4;
public static const int NSURLRequestReloadIgnoringLocalCacheData = 1;
public static const int NSURLRequestReloadRevalidatingCacheData = 5;
public static const int NSURLRequestReturnCacheDataDontLoad = 3;
public static const int NSURLRequestReturnCacheDataElseLoad = 2;
public static const int NSURLRequestUseProtocolCachePolicy = 0;
public static const int NSUTF16BigEndianStringEncoding = -1879047936;
public static const int NSUTF16LittleEndianStringEncoding = -1811939072;
public static const int NSUTF16StringEncoding = 10;
public static const int NSUTF32BigEndianStringEncoding = -1744830208;
public static const int NSUTF32LittleEndianStringEncoding = -1677721344;
public static const int NSUTF32StringEncoding = -1946156800;
alias NSStringEncoding.NSUTF8StringEncoding NSUTF8StringEncoding;
public static const int NSUncachedRead = 2;
public static const int NSUndefinedDateComponent = 2147483647;
public static const int NSUndoCloseGroupingRunLoopOrdering = 350000;
public static const int NSUnicodeStringEncoding = 10;
public static const int NSUnionSetExpressionType = 5;
public static const int NSUnknownKeyScriptError = 7;
public static const int NSUnknownKeySpecifierError = 3;
public static const int NSUserCancelledError = 3072;
public static const int NSUserDirectory = 7;
public static const int NSUserDomainMask = 1;
public static const int NSValidationErrorMaximum = 2047;
public static const int NSValidationErrorMinimum = 1024;
public static const int NSVariableExpressionType = 2;
public static const int NSWeekCalendarUnit = 256;
public static const int NSWeekdayCalendarUnit = 512;
public static const int NSWeekdayOrdinalCalendarUnit = 1024;
public static const int NSWidthInsensitiveSearch = 256;
public static const int NSWindows95OperatingSystem = 2;
public static const int NSWindowsCP1250StringEncoding = 15;
public static const int NSWindowsCP1251StringEncoding = 11;
public static const int NSWindowsCP1252StringEncoding = 12;
public static const int NSWindowsCP1253StringEncoding = 13;
public static const int NSWindowsCP1254StringEncoding = 14;
public static const int NSWindowsNTOperatingSystem = 1;
public static const int NSWrapCalendarComponents = 1;
public static const int NSXMLAttributeCDATAKind = 6;
public static const int NSXMLAttributeDeclarationKind = 10;
public static const int NSXMLAttributeEntitiesKind = 11;
public static const int NSXMLAttributeEntityKind = 10;
public static const int NSXMLAttributeEnumerationKind = 14;
public static const int NSXMLAttributeIDKind = 7;
public static const int NSXMLAttributeIDRefKind = 8;
public static const int NSXMLAttributeIDRefsKind = 9;
public static const int NSXMLAttributeKind = 3;
public static const int NSXMLAttributeNMTokenKind = 12;
public static const int NSXMLAttributeNMTokensKind = 13;
public static const int NSXMLAttributeNotationKind = 15;
public static const int NSXMLCommentKind = 6;
public static const int NSXMLDTDKind = 8;
public static const int NSXMLDocumentHTMLKind = 2;
public static const int NSXMLDocumentIncludeContentTypeDeclaration = 262144;
public static const int NSXMLDocumentKind = 1;
public static const int NSXMLDocumentTextKind = 3;
public static const int NSXMLDocumentTidyHTML = 512;
public static const int NSXMLDocumentTidyXML = 1024;
public static const int NSXMLDocumentValidate = 8192;
public static const int NSXMLDocumentXHTMLKind = 1;
public static const int NSXMLDocumentXInclude = 65536;
public static const int NSXMLDocumentXMLKind = 0;
public static const int NSXMLElementDeclarationAnyKind = 18;
public static const int NSXMLElementDeclarationElementKind = 20;
public static const int NSXMLElementDeclarationEmptyKind = 17;
public static const int NSXMLElementDeclarationKind = 11;
public static const int NSXMLElementDeclarationMixedKind = 19;
public static const int NSXMLElementDeclarationUndefinedKind = 16;
public static const int NSXMLElementKind = 2;
public static const int NSXMLEntityDeclarationKind = 9;
public static const int NSXMLEntityGeneralKind = 1;
public static const int NSXMLEntityParameterKind = 4;
public static const int NSXMLEntityParsedKind = 2;
public static const int NSXMLEntityPredefined = 5;
public static const int NSXMLEntityUnparsedKind = 3;
public static const int NSXMLInvalidKind = 0;
public static const int NSXMLNamespaceKind = 4;
public static const int NSXMLNodeCompactEmptyElement = 4;
public static const int NSXMLNodeExpandEmptyElement = 2;
public static const int NSXMLNodeIsCDATA = 1;
public static const int NSXMLNodeOptionsNone = 0;
public static const int NSXMLNodePreserveAll = -1048546;
public static const int NSXMLNodePreserveAttributeOrder = 2097152;
public static const int NSXMLNodePreserveCDATA = 16777216;
public static const int NSXMLNodePreserveCharacterReferences = 134217728;
public static const int NSXMLNodePreserveDTD = 67108864;
public static const int NSXMLNodePreserveEmptyElements = 6;
public static const int NSXMLNodePreserveEntities = 4194304;
public static const int NSXMLNodePreserveNamespaceOrder = 1048576;
public static const int NSXMLNodePreservePrefixes = 8388608;
public static const int NSXMLNodePreserveQuotes = 24;
public static const int NSXMLNodePreserveWhitespace = 33554432;
public static const int NSXMLNodePrettyPrint = 131072;
public static const int NSXMLNodeUseDoubleQuotes = 16;
public static const int NSXMLNodeUseSingleQuotes = 8;
public static const int NSXMLNotationDeclarationKind = 12;
public static const int NSXMLParserAttributeHasNoValueError = 41;
public static const int NSXMLParserAttributeListNotFinishedError = 51;
public static const int NSXMLParserAttributeListNotStartedError = 50;
public static const int NSXMLParserAttributeNotFinishedError = 40;
public static const int NSXMLParserAttributeNotStartedError = 39;
public static const int NSXMLParserAttributeRedefinedError = 42;
public static const int NSXMLParserCDATANotFinishedError = 63;
public static const int NSXMLParserCharacterRefAtEOFError = 10;
public static const int NSXMLParserCharacterRefInDTDError = 13;
public static const int NSXMLParserCharacterRefInEpilogError = 12;
public static const int NSXMLParserCharacterRefInPrologError = 11;
public static const int NSXMLParserCommentContainsDoubleHyphenError = 80;
public static const int NSXMLParserCommentNotFinishedError = 45;
public static const int NSXMLParserConditionalSectionNotFinishedError = 59;
public static const int NSXMLParserConditionalSectionNotStartedError = 58;
public static const int NSXMLParserDOCTYPEDeclNotFinishedError = 61;
public static const int NSXMLParserDelegateAbortedParseError = 512;
public static const int NSXMLParserDocumentStartError = 3;
public static const int NSXMLParserElementContentDeclNotFinishedError = 55;
public static const int NSXMLParserElementContentDeclNotStartedError = 54;
public static const int NSXMLParserEmptyDocumentError = 4;
public static const int NSXMLParserEncodingNotSupportedError = 32;
public static const int NSXMLParserEntityBoundaryError = 90;
public static const int NSXMLParserEntityIsExternalError = 29;
public static const int NSXMLParserEntityIsParameterError = 30;
public static const int NSXMLParserEntityNotFinishedError = 37;
public static const int NSXMLParserEntityNotStartedError = 36;
public static const int NSXMLParserEntityRefAtEOFError = 14;
public static const int NSXMLParserEntityRefInDTDError = 17;
public static const int NSXMLParserEntityRefInEpilogError = 16;
public static const int NSXMLParserEntityRefInPrologError = 15;
public static const int NSXMLParserEntityRefLoopError = 89;
public static const int NSXMLParserEntityReferenceMissingSemiError = 23;
public static const int NSXMLParserEntityReferenceWithoutNameError = 22;
public static const int NSXMLParserEntityValueRequiredError = 84;
public static const int NSXMLParserEqualExpectedError = 75;
public static const int NSXMLParserExternalStandaloneEntityError = 82;
public static const int NSXMLParserExternalSubsetNotFinishedError = 60;
public static const int NSXMLParserExtraContentError = 86;
public static const int NSXMLParserGTRequiredError = 73;
public static const int NSXMLParserInternalError = 1;
public static const int NSXMLParserInvalidCharacterError = 9;
public static const int NSXMLParserInvalidCharacterInEntityError = 87;
public static const int NSXMLParserInvalidCharacterRefError = 8;
public static const int NSXMLParserInvalidConditionalSectionError = 83;
public static const int NSXMLParserInvalidDecimalCharacterRefError = 7;
public static const int NSXMLParserInvalidEncodingError = 81;
public static const int NSXMLParserInvalidEncodingNameError = 79;
public static const int NSXMLParserInvalidHexCharacterRefError = 6;
public static const int NSXMLParserInvalidURIError = 91;
public static const int NSXMLParserLTRequiredError = 72;
public static const int NSXMLParserLTSlashRequiredError = 74;
public static const int NSXMLParserLessThanSymbolInAttributeError = 38;
public static const int NSXMLParserLiteralNotFinishedError = 44;
public static const int NSXMLParserLiteralNotStartedError = 43;
public static const int NSXMLParserMisplacedCDATAEndStringError = 62;
public static const int NSXMLParserMisplacedXMLDeclarationError = 64;
public static const int NSXMLParserMixedContentDeclNotFinishedError = 53;
public static const int NSXMLParserMixedContentDeclNotStartedError = 52;
public static const int NSXMLParserNAMERequiredError = 68;
public static const int NSXMLParserNMTOKENRequiredError = 67;
public static const int NSXMLParserNamespaceDeclarationError = 35;
public static const int NSXMLParserNoDTDError = 94;
public static const int NSXMLParserNotWellBalancedError = 85;
public static const int NSXMLParserNotationNotFinishedError = 49;
public static const int NSXMLParserNotationNotStartedError = 48;
public static const int NSXMLParserOutOfMemoryError = 2;
public static const int NSXMLParserPCDATARequiredError = 69;
public static const int NSXMLParserParsedEntityRefAtEOFError = 18;
public static const int NSXMLParserParsedEntityRefInEpilogError = 20;
public static const int NSXMLParserParsedEntityRefInInternalError = 88;
public static const int NSXMLParserParsedEntityRefInInternalSubsetError = 21;
public static const int NSXMLParserParsedEntityRefInPrologError = 19;
public static const int NSXMLParserParsedEntityRefMissingSemiError = 25;
public static const int NSXMLParserParsedEntityRefNoNameError = 24;
public static const int NSXMLParserPrematureDocumentEndError = 5;
public static const int NSXMLParserProcessingInstructionNotFinishedError = 47;
public static const int NSXMLParserProcessingInstructionNotStartedError = 46;
public static const int NSXMLParserPublicIdentifierRequiredError = 71;
public static const int NSXMLParserSeparatorRequiredError = 66;
public static const int NSXMLParserSpaceRequiredError = 65;
public static const int NSXMLParserStandaloneValueError = 78;
public static const int NSXMLParserStringNotClosedError = 34;
public static const int NSXMLParserStringNotStartedError = 33;
public static const int NSXMLParserTagNameMismatchError = 76;
public static const int NSXMLParserURIFragmentError = 92;
public static const int NSXMLParserURIRequiredError = 70;
public static const int NSXMLParserUndeclaredEntityError = 26;
public static const int NSXMLParserUnfinishedTagError = 77;
public static const int NSXMLParserUnknownEncodingError = 31;
public static const int NSXMLParserUnparsedEntityError = 28;
public static const int NSXMLParserXMLDeclNotFinishedError = 57;
public static const int NSXMLParserXMLDeclNotStartedError = 56;
public static const int NSXMLProcessingInstructionKind = 5;
public static const int NSXMLTextKind = 7;
public static const int NSYearCalendarUnit = 4;
public static const int NS_BigEndian = 2;
public static const int NS_LittleEndian = 1;
public static const int NS_UNICHAR_IS_EIGHT_BIT = 0;
public static const int NS_UnknownByteOrder = 0;
public static const int DOM_ADDITION = 2;
public static const int DOM_ANY_TYPE = 0;
public static const int DOM_ANY_UNORDERED_NODE_TYPE = 8;
public static const int DOM_ATTRIBUTE_NODE = 2;
public static const int DOM_AT_TARGET = 2;
public static const int DOM_BAD_BOUNDARYPOINTS_ERR = 1;
public static const int DOM_BOOLEAN_TYPE = 3;
public static const int DOM_BOTH = 2;
public static const int DOM_BUBBLING_PHASE = 3;
public static const int DOM_CAPTURING_PHASE = 1;
public static const int DOM_CDATA_SECTION_NODE = 4;
public static const int DOM_CHARSET_RULE = 2;
public static const int DOM_COMMENT_NODE = 8;
public static const int DOM_CSS_ATTR = 22;
public static const int DOM_CSS_CM = 6;
public static const int DOM_CSS_COUNTER = 23;
public static const int DOM_CSS_CUSTOM = 3;
public static const int DOM_CSS_DEG = 11;
public static const int DOM_CSS_DIMENSION = 18;
public static const int DOM_CSS_EMS = 3;
public static const int DOM_CSS_EXS = 4;
public static const int DOM_CSS_GRAD = 13;
public static const int DOM_CSS_HZ = 16;
public static const int DOM_CSS_IDENT = 21;
public static const int DOM_CSS_IN = 8;
public static const int DOM_CSS_INHERIT = 0;
public static const int DOM_CSS_KHZ = 17;
public static const int DOM_CSS_MM = 7;
public static const int DOM_CSS_MS = 14;
public static const int DOM_CSS_NUMBER = 1;
public static const int DOM_CSS_PC = 10;
public static const int DOM_CSS_PERCENTAGE = 2;
public static const int DOM_CSS_PRIMITIVE_VALUE = 1;
public static const int DOM_CSS_PT = 9;
public static const int DOM_CSS_PX = 5;
public static const int DOM_CSS_RAD = 12;
public static const int DOM_CSS_RECT = 24;
public static const int DOM_CSS_RGBCOLOR = 25;
public static const int DOM_CSS_S = 15;
public static const int DOM_CSS_STRING = 19;
public static const int DOM_CSS_UNKNOWN = 0;
public static const int DOM_CSS_URI = 20;
public static const int DOM_CSS_VALUE_LIST = 2;
public static const int DOM_DOCUMENT_FRAGMENT_NODE = 11;
public static const int DOM_DOCUMENT_NODE = 9;
public static const int DOM_DOCUMENT_TYPE_NODE = 10;
public static const int DOM_DOMSTRING_SIZE_ERR = 2;
public static const int DOM_ELEMENT_NODE = 1;
public static const int DOM_END_TO_END = 2;
public static const int DOM_END_TO_START = 3;
public static const int DOM_ENTITY_NODE = 6;
public static const int DOM_ENTITY_REFERENCE_NODE = 5;
public static const int DOM_FILTER_ACCEPT = 1;
public static const int DOM_FILTER_REJECT = 2;
public static const int DOM_FILTER_SKIP = 3;
public static const int DOM_FIRST_ORDERED_NODE_TYPE = 9;
public static const int DOM_FONT_FACE_RULE = 5;
public static const int DOM_HIERARCHY_REQUEST_ERR = 3;
public static const int DOM_HORIZONTAL = 0;
public static const int DOM_IMPORT_RULE = 3;
public static const int DOM_INDEX_SIZE_ERR = 1;
public static const int DOM_INUSE_ATTRIBUTE_ERR = 10;
public static const int DOM_INVALID_ACCESS_ERR = 15;
public static const int DOM_INVALID_CHARACTER_ERR = 5;
public static const int DOM_INVALID_EXPRESSION_ERR = 51;
public static const int DOM_INVALID_MODIFICATION_ERR = 13;
public static const int DOM_INVALID_NODE_TYPE_ERR = 2;
public static const int DOM_INVALID_STATE_ERR = 11;
public static const int DOM_KEY_LOCATION_LEFT = 1;
public static const int DOM_KEY_LOCATION_NUMPAD = 3;
public static const int DOM_KEY_LOCATION_RIGHT = 2;
public static const int DOM_KEY_LOCATION_STANDARD = 0;
public static const int DOM_MEDIA_RULE = 4;
public static const int DOM_MODIFICATION = 1;
public static const int DOM_NAMESPACE_ERR = 14;
public static const int DOM_NODE_AFTER = 1;
public static const int DOM_NODE_BEFORE = 0;
public static const int DOM_NODE_BEFORE_AND_AFTER = 2;
public static const int DOM_NODE_INSIDE = 3;
public static const int DOM_NOTATION_NODE = 12;
public static const int DOM_NOT_FOUND_ERR = 8;
public static const int DOM_NOT_SUPPORTED_ERR = 9;
public static const int DOM_NO_DATA_ALLOWED_ERR = 6;
public static const int DOM_NO_MODIFICATION_ALLOWED_ERR = 7;
public static const int DOM_NUMBER_TYPE = 1;
public static const int DOM_ORDERED_NODE_ITERATOR_TYPE = 5;
public static const int DOM_ORDERED_NODE_SNAPSHOT_TYPE = 7;
public static const int DOM_PAGE_RULE = 6;
public static const int DOM_PROCESSING_INSTRUCTION_NODE = 7;
public static const int DOM_REMOVAL = 3;
public static const int DOM_SHOW_ALL = -1;
public static const int DOM_SHOW_ATTRIBUTE = 2;
public static const int DOM_SHOW_CDATA_SECTION = 8;
public static const int DOM_SHOW_COMMENT = 128;
public static const int DOM_SHOW_DOCUMENT = 256;
public static const int DOM_SHOW_DOCUMENT_FRAGMENT = 1024;
public static const int DOM_SHOW_DOCUMENT_TYPE = 512;
public static const int DOM_SHOW_ELEMENT = 1;
public static const int DOM_SHOW_ENTITY = 32;
public static const int DOM_SHOW_ENTITY_REFERENCE = 16;
public static const int DOM_SHOW_NOTATION = 2048;
public static const int DOM_SHOW_PROCESSING_INSTRUCTION = 64;
public static const int DOM_SHOW_TEXT = 4;
public static const int DOM_START_TO_END = 1;
public static const int DOM_START_TO_START = 0;
public static const int DOM_STRING_TYPE = 2;
public static const int DOM_STYLE_RULE = 1;
public static const int DOM_SYNTAX_ERR = 12;
public static const int DOM_TEXT_NODE = 3;
public static const int DOM_TYPE_ERR = 52;
public static const int DOM_UNKNOWN_RULE = 0;
public static const int DOM_UNORDERED_NODE_ITERATOR_TYPE = 4;
public static const int DOM_UNORDERED_NODE_SNAPSHOT_TYPE = 6;
public static const int DOM_UNSPECIFIED_EVENT_TYPE_ERR = 0;
public static const int DOM_VERTICAL = 1;
public static const int DOM_WRONG_DOCUMENT_ERR = 4;
public static const int WebCacheModelDocumentBrowser = 1;
public static const int WebCacheModelDocumentViewer = 0;
public static const int WebCacheModelPrimaryWebBrowser = 2;
public static const int WebDragDestinationActionAny = -1;
public static const int WebDragDestinationActionDHTML = 1;
public static const int WebDragDestinationActionEdit = 2;
public static const int WebDragDestinationActionLoad = 4;
public static const int WebDragDestinationActionNone = 0;
public static const int WebDragSourceActionAny = -1;
public static const int WebDragSourceActionDHTML = 1;
public static const int WebDragSourceActionImage = 2;
public static const int WebDragSourceActionLink = 4;
public static const int WebDragSourceActionNone = 0;
public static const int WebDragSourceActionSelection = 8;
public static const int WebJNIReturnTypeBoolean = 3;
public static const int WebJNIReturnTypeByte = 4;
public static const int WebJNIReturnTypeChar = 5;
public static const int WebJNIReturnTypeDouble = 10;
public static const int WebJNIReturnTypeFloat = 9;
public static const int WebJNIReturnTypeInt = 7;
public static const int WebJNIReturnTypeInvalid = 0;
public static const int WebJNIReturnTypeLong = 8;
public static const int WebJNIReturnTypeObject = 2;
public static const int WebJNIReturnTypeShort = 6;
public static const int WebJNIReturnTypeVoid = 1;
public static const int WebKitErrorCannotFindPlugIn = 200;
public static const int WebKitErrorCannotLoadPlugIn = 201;
public static const int WebKitErrorCannotShowMIMEType = 100;
public static const int WebKitErrorCannotShowURL = 101;
public static const int WebKitErrorFrameLoadInterruptedByPolicyChange = 102;
public static const int WebKitErrorJavaUnavailable = 202;
public static const int WebMenuItemPDFActualSize = 24;
public static const int WebMenuItemPDFAutoSize = 27;
public static const int WebMenuItemPDFContinuous = 30;
public static const int WebMenuItemPDFFacingPages = 29;
public static const int WebMenuItemPDFNextPage = 31;
public static const int WebMenuItemPDFPreviousPage = 32;
public static const int WebMenuItemPDFSinglePage = 28;
public static const int WebMenuItemPDFZoomIn = 25;
public static const int WebMenuItemPDFZoomOut = 26;
public static const int WebMenuItemTagCopy = 8;
public static const int WebMenuItemTagCopyImageToClipboard = 6;
public static const int WebMenuItemTagCopyLinkToClipboard = 3;
public static const int WebMenuItemTagCut = 13;
public static const int WebMenuItemTagDownloadImageToDisk = 5;
public static const int WebMenuItemTagDownloadLinkToDisk = 2;
public static const int WebMenuItemTagGoBack = 9;
public static const int WebMenuItemTagGoForward = 10;
public static const int WebMenuItemTagIgnoreSpelling = 17;
public static const int WebMenuItemTagLearnSpelling = 18;
public static const int WebMenuItemTagLookUpInDictionary = 22;
public static const int WebMenuItemTagNoGuessesFound = 16;
public static const int WebMenuItemTagOpenFrameInNewWindow = 7;
public static const int WebMenuItemTagOpenImageInNewWindow = 4;
public static const int WebMenuItemTagOpenLinkInNewWindow = 1;
public static const int WebMenuItemTagOpenWithDefaultApplication = 23;
public static const int WebMenuItemTagOther = 19;
public static const int WebMenuItemTagPaste = 14;
public static const int WebMenuItemTagReload = 12;
public static const int WebMenuItemTagSearchInSpotlight = 20;
public static const int WebMenuItemTagSearchWeb = 21;
public static const int WebMenuItemTagSpellingGuess = 15;
public static const int WebMenuItemTagStop = 11;
public static const int WebNavigationTypeBackForward = 2;
public static const int WebNavigationTypeFormResubmitted = 4;
public static const int WebNavigationTypeFormSubmitted = 1;
public static const int WebNavigationTypeLinkClicked = 0;
public static const int WebNavigationTypeOther = 5;
public static const int WebNavigationTypeReload = 3;
public static const int WebViewInsertActionDropped = 2;
public static const int WebViewInsertActionPasted = 1;
public static const int WebViewInsertActionTyped = 0;

/** Globals */
/** @method flags=const */
alias Cocoa.NSAccessibilityButtonRole NSAccessibilityButtonRole_;
public static const NSString NSAccessibilityButtonRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityCheckBoxRole NSAccessibilityCheckBoxRole_;
public static const NSString NSAccessibilityCheckBoxRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityChildrenAttribute NSAccessibilityChildrenAttribute_;
public static const NSString NSAccessibilityChildrenAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityColumnRole NSAccessibilityColumnRole_;
public static const NSString NSAccessibilityColumnRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityComboBoxRole NSAccessibilityComboBoxRole_;
public static const NSString NSAccessibilityComboBoxRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityConfirmAction NSAccessibilityConfirmAction_;
public static const NSString NSAccessibilityConfirmAction;
/** @method flags=const */
alias Cocoa.NSAccessibilityContentsAttribute NSAccessibilityContentsAttribute_;
public static const NSString NSAccessibilityContentsAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityDescriptionAttribute NSAccessibilityDescriptionAttribute_;
public static const NSString NSAccessibilityDescriptionAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityDialogSubrole NSAccessibilityDialogSubrole_;
public static const NSString NSAccessibilityDialogSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityEnabledAttribute NSAccessibilityEnabledAttribute_;
public static const NSString NSAccessibilityEnabledAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityExpandedAttribute NSAccessibilityExpandedAttribute_;
public static const NSString NSAccessibilityExpandedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityFloatingWindowSubrole NSAccessibilityFloatingWindowSubrole_;
public static const NSString NSAccessibilityFloatingWindowSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityFocusedAttribute NSAccessibilityFocusedAttribute_;
public static const NSString NSAccessibilityFocusedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityFocusedUIElementChangedNotification NSAccessibilityFocusedUIElementChangedNotification_;
public static const NSString NSAccessibilityFocusedUIElementChangedNotification;
/** @method flags=const */
alias Cocoa.NSAccessibilityGridRole NSAccessibilityGridRole_;
public static const NSString NSAccessibilityGridRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityGroupRole NSAccessibilityGroupRole_;
public static const NSString NSAccessibilityGroupRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityHelpAttribute NSAccessibilityHelpAttribute_;
public static const NSString NSAccessibilityHelpAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityHelpTagRole NSAccessibilityHelpTagRole_;
public static const NSString NSAccessibilityHelpTagRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityHorizontalOrientationValue NSAccessibilityHorizontalOrientationValue_;
public static const NSString NSAccessibilityHorizontalOrientationValue;
/** @method flags=const */
alias Cocoa.NSAccessibilityHorizontalScrollBarAttribute NSAccessibilityHorizontalScrollBarAttribute_;
public static const NSString NSAccessibilityHorizontalScrollBarAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityImageRole NSAccessibilityImageRole_;
public static const NSString NSAccessibilityImageRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityIncrementorRole NSAccessibilityIncrementorRole_;
public static const NSString NSAccessibilityIncrementorRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityInsertionPointLineNumberAttribute NSAccessibilityInsertionPointLineNumberAttribute_;
public static const NSString NSAccessibilityInsertionPointLineNumberAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityLabelValueAttribute NSAccessibilityLabelValueAttribute_;
public static const NSString NSAccessibilityLabelValueAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityLineForIndexParameterizedAttribute NSAccessibilityLineForIndexParameterizedAttribute_;
public static const NSString NSAccessibilityLineForIndexParameterizedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityLinkRole NSAccessibilityLinkRole_;
public static const NSString NSAccessibilityLinkRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityLinkTextAttribute NSAccessibilityLinkTextAttribute_;
public static const NSString NSAccessibilityLinkTextAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityListRole NSAccessibilityListRole_;
public static const NSString NSAccessibilityListRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityMaxValueAttribute NSAccessibilityMaxValueAttribute_;
public static const NSString NSAccessibilityMaxValueAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuBarRole NSAccessibilityMenuBarRole_;
public static const NSString NSAccessibilityMenuBarRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuButtonRole NSAccessibilityMenuButtonRole_;
public static const NSString NSAccessibilityMenuButtonRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuItemRole NSAccessibilityMenuItemRole_;
public static const NSString NSAccessibilityMenuItemRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityMenuRole NSAccessibilityMenuRole_;
public static const NSString NSAccessibilityMenuRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityMinValueAttribute NSAccessibilityMinValueAttribute_;
public static const NSString NSAccessibilityMinValueAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityNextContentsAttribute NSAccessibilityNextContentsAttribute_;
public static const NSString NSAccessibilityNextContentsAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityNumberOfCharactersAttribute NSAccessibilityNumberOfCharactersAttribute_;
public static const NSString NSAccessibilityNumberOfCharactersAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityOrientationAttribute NSAccessibilityOrientationAttribute_;
public static const NSString NSAccessibilityOrientationAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityOutlineRole NSAccessibilityOutlineRole_;
public static const NSString NSAccessibilityOutlineRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityOutlineRowSubrole NSAccessibilityOutlineRowSubrole_;
public static const NSString NSAccessibilityOutlineRowSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityParentAttribute NSAccessibilityParentAttribute_;
public static const NSString NSAccessibilityParentAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityPopUpButtonRole NSAccessibilityPopUpButtonRole_;
public static const NSString NSAccessibilityPopUpButtonRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityPositionAttribute NSAccessibilityPositionAttribute_;
public static const NSString NSAccessibilityPositionAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityPressAction NSAccessibilityPressAction_;
public static const NSString NSAccessibilityPressAction;
/** @method flags=const */
alias Cocoa.NSAccessibilityPreviousContentsAttribute NSAccessibilityPreviousContentsAttribute_;
public static const NSString NSAccessibilityPreviousContentsAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityProgressIndicatorRole NSAccessibilityProgressIndicatorRole_;
public static const NSString NSAccessibilityProgressIndicatorRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityRTFForRangeParameterizedAttribute NSAccessibilityRTFForRangeParameterizedAttribute_;
public static const NSString NSAccessibilityRTFForRangeParameterizedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityRadioButtonRole NSAccessibilityRadioButtonRole_;
public static const NSString NSAccessibilityRadioButtonRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityRadioGroupRole NSAccessibilityRadioGroupRole_;
public static const NSString NSAccessibilityRadioGroupRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityRangeForIndexParameterizedAttribute NSAccessibilityRangeForIndexParameterizedAttribute_;
public static const NSString NSAccessibilityRangeForIndexParameterizedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityRangeForLineParameterizedAttribute NSAccessibilityRangeForLineParameterizedAttribute_;
public static const NSString NSAccessibilityRangeForLineParameterizedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityRangeForPositionParameterizedAttribute NSAccessibilityRangeForPositionParameterizedAttribute_;
public static const NSString NSAccessibilityRangeForPositionParameterizedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityRoleAttribute NSAccessibilityRoleAttribute_;
public static const NSString NSAccessibilityRoleAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityRoleDescriptionAttribute NSAccessibilityRoleDescriptionAttribute_;
public static const NSString NSAccessibilityRoleDescriptionAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityRowRole NSAccessibilityRowRole_;
public static const NSString NSAccessibilityRowRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityScrollAreaRole NSAccessibilityScrollAreaRole_;
public static const NSString NSAccessibilityScrollAreaRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityScrollBarRole NSAccessibilityScrollBarRole_;
public static const NSString NSAccessibilityScrollBarRole;
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedAttribute NSAccessibilitySelectedAttribute_;
public static const NSString NSAccessibilitySelectedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedChildrenAttribute NSAccessibilitySelectedChildrenAttribute_;
public static const NSString NSAccessibilitySelectedChildrenAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedChildrenChangedNotification NSAccessibilitySelectedChildrenChangedNotification_;
public static const NSString NSAccessibilitySelectedChildrenChangedNotification;
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextAttribute NSAccessibilitySelectedTextAttribute_;
public static const NSString NSAccessibilitySelectedTextAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextChangedNotification NSAccessibilitySelectedTextChangedNotification_;
public static const NSString NSAccessibilitySelectedTextChangedNotification;
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextRangeAttribute NSAccessibilitySelectedTextRangeAttribute_;
public static const NSString NSAccessibilitySelectedTextRangeAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySelectedTextRangesAttribute NSAccessibilitySelectedTextRangesAttribute_;
public static const NSString NSAccessibilitySelectedTextRangesAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySizeAttribute NSAccessibilitySizeAttribute_;
public static const NSString NSAccessibilitySizeAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySliderRole NSAccessibilitySliderRole_;
public static const NSString NSAccessibilitySliderRole;
/** @method flags=const */
alias Cocoa.NSAccessibilitySortButtonRole NSAccessibilitySortButtonRole_;
public static const NSString NSAccessibilitySortButtonRole;
/** @method flags=const */
alias Cocoa.NSAccessibilitySplitterRole NSAccessibilitySplitterRole_;
public static const NSString NSAccessibilitySplitterRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityStandardWindowSubrole NSAccessibilityStandardWindowSubrole_;
public static const NSString NSAccessibilityStandardWindowSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityStaticTextRole NSAccessibilityStaticTextRole_;
public static const NSString NSAccessibilityStaticTextRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityStringForRangeParameterizedAttribute NSAccessibilityStringForRangeParameterizedAttribute_;
public static const NSString NSAccessibilityStringForRangeParameterizedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityStyleRangeForIndexParameterizedAttribute NSAccessibilityStyleRangeForIndexParameterizedAttribute_;
public static const NSString NSAccessibilityStyleRangeForIndexParameterizedAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySubroleAttribute NSAccessibilitySubroleAttribute_;
public static const NSString NSAccessibilitySubroleAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilitySystemDialogSubrole NSAccessibilitySystemDialogSubrole_;
public static const NSString NSAccessibilitySystemDialogSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTabGroupRole NSAccessibilityTabGroupRole_;
public static const NSString NSAccessibilityTabGroupRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTableRole NSAccessibilityTableRole_;
public static const NSString NSAccessibilityTableRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTableRowSubrole NSAccessibilityTableRowSubrole_;
public static const NSString NSAccessibilityTableRowSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTabsAttribute NSAccessibilityTabsAttribute_;
public static const NSString NSAccessibilityTabsAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityTextAreaRole NSAccessibilityTextAreaRole_;
public static const NSString NSAccessibilityTextAreaRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTextFieldRole NSAccessibilityTextFieldRole_;
public static const NSString NSAccessibilityTextFieldRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTextLinkSubrole NSAccessibilityTextLinkSubrole_;
public static const NSString NSAccessibilityTextLinkSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTitleAttribute NSAccessibilityTitleAttribute_;
public static const NSString NSAccessibilityTitleAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityTitleUIElementAttribute NSAccessibilityTitleUIElementAttribute_;
public static const NSString NSAccessibilityTitleUIElementAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityToolbarRole NSAccessibilityToolbarRole_;
public static const NSString NSAccessibilityToolbarRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityTopLevelUIElementAttribute NSAccessibilityTopLevelUIElementAttribute_;
public static const NSString NSAccessibilityTopLevelUIElementAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityUnknownRole NSAccessibilityUnknownRole_;
public static const NSString NSAccessibilityUnknownRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityUnknownSubrole NSAccessibilityUnknownSubrole_;
public static const NSString NSAccessibilityUnknownSubrole;
/** @method flags=const */
alias Cocoa.NSAccessibilityValueAttribute NSAccessibilityValueAttribute_;
public static const NSString NSAccessibilityValueAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityValueChangedNotification NSAccessibilityValueChangedNotification_;
public static const NSString NSAccessibilityValueChangedNotification;
/** @method flags=const */
alias Cocoa.NSAccessibilityValueDescriptionAttribute NSAccessibilityValueDescriptionAttribute_;
public static const NSString NSAccessibilityValueDescriptionAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityValueIndicatorRole NSAccessibilityValueIndicatorRole_;
public static const NSString NSAccessibilityValueIndicatorRole;
/** @method flags=const */
alias Cocoa.NSAccessibilityVerticalOrientationValue NSAccessibilityVerticalOrientationValue_;
public static const NSString NSAccessibilityVerticalOrientationValue;
/** @method flags=const */
alias Cocoa.NSAccessibilityVerticalScrollBarAttribute NSAccessibilityVerticalScrollBarAttribute_;
public static const NSString NSAccessibilityVerticalScrollBarAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityVisibleCharacterRangeAttribute NSAccessibilityVisibleCharacterRangeAttribute_;
public static const NSString NSAccessibilityVisibleCharacterRangeAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityVisibleChildrenAttribute NSAccessibilityVisibleChildrenAttribute_;
public static const NSString NSAccessibilityVisibleChildrenAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityWindowAttribute NSAccessibilityWindowAttribute_;
public static const NSString NSAccessibilityWindowAttribute;
/** @method flags=const */
alias Cocoa.NSAccessibilityWindowRole NSAccessibilityWindowRole_;
public static const NSString NSAccessibilityWindowRole;
/** @method flags=const */
alias Cocoa.NSBackgroundColorAttributeName NSBackgroundColorAttributeName_;
public static const NSString NSBackgroundColorAttributeName;
/** @method flags=const */
alias Cocoa.NSBaselineOffsetAttributeName NSBaselineOffsetAttributeName_;
public static const NSString NSBaselineOffsetAttributeName;
/** @method flags=const */
alias Cocoa.NSCalibratedRGBColorSpace NSCalibratedRGBColorSpace_;
public static const NSString NSCalibratedRGBColorSpace;
/** @method flags=const */
alias Cocoa.NSDeviceRGBColorSpace NSDeviceRGBColorSpace_;
public static const NSString NSDeviceRGBColorSpace;
/** @method flags=const */
alias Cocoa.NSDeviceResolution NSDeviceResolution_;
public static const NSString NSDeviceResolution;
/** @method flags=const */
alias Cocoa.NSDragPboard NSDragPboard_;
public static const NSString NSDragPboard;
/** @method flags=const */
alias Cocoa.NSFilenamesPboardType NSFilenamesPboardType_;
public static const NSString NSFilenamesPboardType;
/** @method flags=const */
alias Cocoa.NSFontAttributeName NSFontAttributeName_;
public static const NSString NSFontAttributeName;
/** @method flags=const */
alias Cocoa.NSForegroundColorAttributeName NSForegroundColorAttributeName_;
public static const NSString NSForegroundColorAttributeName;
/** @method flags=const */
alias Cocoa.NSHTMLPboardType NSHTMLPboardType_;
public static const NSString NSHTMLPboardType;
/** @method flags=const */
alias Cocoa.NSLinkAttributeName NSLinkAttributeName_;
public static const NSString NSLinkAttributeName;
/** @method flags=const */
alias Cocoa.NSParagraphStyleAttributeName NSParagraphStyleAttributeName_;
public static const NSString NSParagraphStyleAttributeName;
/** @method flags=const */
alias Cocoa.NSPrintAllPages NSPrintAllPages_;
public static const NSString NSPrintAllPages;
/** @method flags=const */
alias Cocoa.NSPrintCopies NSPrintCopies_;
public static const NSString NSPrintCopies;
/** @method flags=const */
alias Cocoa.NSPrintFirstPage NSPrintFirstPage_;
public static const NSString NSPrintFirstPage;
/** @method flags=const */
alias Cocoa.NSPrintJobDisposition NSPrintJobDisposition_;
public static const NSString NSPrintJobDisposition;
/** @method flags=const */
alias Cocoa.NSPrintLastPage NSPrintLastPage_;
public static const NSString NSPrintLastPage;
/** @method flags=const */
alias Cocoa.NSPrintMustCollate NSPrintMustCollate_;
public static const NSString NSPrintMustCollate;
/** @method flags=const */
alias Cocoa.NSPrintPreviewJob NSPrintPreviewJob_;
public static const NSString NSPrintPreviewJob;
/** @method flags=const */
alias Cocoa.NSPrintSaveJob NSPrintSaveJob_;
public static const NSString NSPrintSaveJob;
/** @method flags=const */
alias Cocoa.NSPrintSavePath NSPrintSavePath_;
public static const NSString NSPrintSavePath;
/** @method flags=const */
alias Cocoa.NSPrintSpoolJob NSPrintSpoolJob_;
public static const NSString NSPrintSpoolJob;
/** @method flags=const */
alias Cocoa.NSRTFPboardType NSRTFPboardType_;
public static const NSString NSRTFPboardType;
/** @method flags=const */
alias Cocoa.NSStrikethroughColorAttributeName NSStrikethroughColorAttributeName_;
public static const NSString NSStrikethroughColorAttributeName;
/** @method flags=const */
alias Cocoa.NSStrikethroughStyleAttributeName NSStrikethroughStyleAttributeName_;
public static const NSString NSStrikethroughStyleAttributeName;
/** @method flags=const */
alias Cocoa.NSStringPboardType NSStringPboardType_;
public static const NSString NSStringPboardType;
/** @method flags=const */
alias Cocoa.NSTIFFPboardType NSTIFFPboardType_;
public static const NSString NSTIFFPboardType;
/** @method flags=const */
alias Cocoa.NSURLPboardType NSURLPboardType_;
public static const NSString NSURLPboardType;
/** @method flags=const */
alias Cocoa.NSUnderlineColorAttributeName NSUnderlineColorAttributeName_;
public static const NSString NSUnderlineColorAttributeName;
/** @method flags=const */
alias Cocoa.NSUnderlineStyleAttributeName NSUnderlineStyleAttributeName_;
public static const NSString NSUnderlineStyleAttributeName;
/** @method flags=const */
alias Cocoa.NSDefaultRunLoopMode NSDefaultRunLoopMode_;
public static const NSString NSDefaultRunLoopMode;
/** @method flags=const */
alias Cocoa.NSErrorFailingURLStringKey NSErrorFailingURLStringKey_;
public static const NSString NSErrorFailingURLStringKey;
/** Functions */

/**
 * @param action cast=(NSString*)
 */
alias Cocoa.NSAccessibilityActionDescription NSAccessibilityActionDescription;
/**
 * @param element cast=(id)
 * @param notification cast=(NSString*)
 */
alias Cocoa.NSAccessibilityPostNotification NSAccessibilityPostNotification;
/**
* @param element cast=(id)
* @param attribute cast=(NSString*)
* @param value cast=(id)
*/
alias Cocoa.NSAccessibilityRaiseBadArgumentException NSAccessibilityRaiseBadArgumentException;
/**
* @param role cast=(NSString*)
* @param subrole cast=(NSString*)
*/
alias Cocoa.NSAccessibilityRoleDescription NSAccessibilityRoleDescription;
/**
* @param element cast=(id)
*/
alias Cocoa.NSAccessibilityRoleDescriptionForUIElement NSAccessibilityRoleDescriptionForUIElement;
/**
* @param element cast=(id)
*/
alias Cocoa.NSAccessibilityUnignoredAncestor NSAccessibilityUnignoredAncestor;
/**
* @param originalChildren cast=(NSArray*)
*/
alias Cocoa.NSAccessibilityUnignoredChildren NSAccessibilityUnignoredChildren;
/**
* @param originalChild cast=(id)
*/
alias Cocoa.NSAccessibilityUnignoredChildrenForOnlyChild NSAccessibilityUnignoredChildrenForOnlyChild;
/**
* @param element cast=(id)
*/
alias Cocoa.NSAccessibilityUnignoredDescendant NSAccessibilityUnignoredDescendant;
alias Cocoa.NSBeep NSBeep;
/**
* @param depth cast=(NSWindowDepth)
*/
alias Cocoa.NSBitsPerPixelFromDepth NSBitsPerPixelFromDepth;
/**
* @param cf cast=(CFTypeRef)
*/
alias Carbon.CFRelease CFRelease;
/**
* @param allocator cast=(CFAllocatorRef)
* @param originalString cast=(CFStringRef)
* @param charactersToLeaveUnescaped cast=(CFStringRef)
* @param legalURLCharactersToBeEscaped cast=(CFStringRef)
* @param encoding cast=(CFStringEncoding)
*/
alias Carbon.CFURLCreateStringByAddingPercentEscapes CFURLCreateStringByAddingPercentEscapes;
/**
* @param newCursorPosition flags=struct */
alias Carbon.CGWarpMouseCursorPosition CGWarpMouseCursorPosition;
/**
* @param hfsFileTypeCode cast=(OSType)
*/
alias Cocoa.NSFileTypeForHFSTypeCode NSFileTypeForHFSTypeCode;
/**
* @param typePtr cast=(char*)
* @param sizep cast=(NSUInteger*)
* @param alignp cast=(NSUInteger*)
*/
alias Cocoa.NSGetSizeAndAlignment NSGetSizeAndAlignment;
/**
* @param directory cast=(NSSearchPathDirectory)
* @param domainMask cast=(NSSearchPathDomainMask)
* @param expandTilde cast=(BOOL)
*/
alias Cocoa.NSSearchPathForDirectoriesInDomains NSSearchPathForDirectoriesInDomains;
alias Cocoa.NSTemporaryDirectory NSTemporaryDirectory;

/** Sends */

/** @method flags=cast */
alias objc.objc_msgSend_bool objc_msgSend_bool;
/** @method flags=cast */
alias objc.objc_msgSend_fpret objc_msgSend_fpret;
/** @method flags=cast */
alias objc.objc_msgSend objc_msgSend;
/** @method flags=cast */
alias objc.objc_msgSend_stret objc_msgSend_stret;

/** Sizeof natives */


/** Memmove natives */

/**
 * @param dest cast=(void *),flags=no_in critical
 * @param src cast=(void *),flags=critical
 */
alias stdc.memmove memmove;

/** This section is auto generated */
}
